package nl.nictiz.digsig;

import java.util.Properties;


import org.apache.ws.security.components.crypto.Crypto;
import org.apache.ws.security.components.crypto.CryptoFactory;

/**
 * Class with helper methods used in both WssLibrarySignature and WssValidate.
 * Specific for working with WSS4J, not WS-S in general.
 */
public class WssCommon {

	/**
	 * Create a "Crypto" object that handles the key and algorithms for the
	 * WSS4J. This is needed for the WSS4J library itself, not WS-Security in
	 * general. 
	 * @return a WSS4J Crypto object
	 */
	public static Crypto makeWssCrypto() {

		// Initialize the crypto properties (WSS4J specific) 
		Properties cryptoProperties = new Properties();
		cryptoProperties.put("org.apache.ws.security.crypto.provider",
				"org.apache.ws.security.components.crypto.Merlin");
		cryptoProperties.put("org.apache.ws.security.crypto.merlin.keystore.type",
				SmartCard.PKCS11_PROVIDER_TYPE);
		// File and password are dummies; the library needs them to be set
		cryptoProperties.put("org.apache.ws.security.crypto.merlin.file","test.jks");
		cryptoProperties.put("org.apache.ws.security.crypto.merlin.keystore.password","");
//		properties.put("org.apache.ws.security.crypto.merlin.keystore.password","blabla");
//		properties.put("org.apache.ws.security.crypto.merlin.keystore.type","PKCS11");

		Crypto crypto = CryptoFactory.getInstance(cryptoProperties);
		return crypto;
	}

}
