<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="COCT_MT720000NL">
    <title>E_MedicationKind universal</title>
    
    <let name="gpkCs" value="'2.16.840.1.113883.2.4.4.1'"/>
    <let name="hpkCs" value="'2.16.840.1.113883.2.4.4.7'"/>
    <let name="artnrCs" value="'2.16.840.1.113883.2.4.4.8'"/>
    <let name="prkCs" value="'2.16.840.1.113883.2.4.4.10'"/>
    <let name="atcCs" value="'2.16.840.1.113883.6.73'"/>
    
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='MMAT'"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'MMAT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
        
        <assert role="error" test="not(hl7:code/@nullFlavor) or hl7:activeIngredient or hl7:otherIngredient or hl7:desc"
            >COCT_MT720000NL: als er geen gecodeerde medicatie is en ook geen ingrediënten dan moet desc een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:code">
        <extends rule="CE"/>
        
        <assert role="error" test="not(@codeSystem) or @codeSystem=$gpkCs or @codeSystem=$prkCs or
            @codeSystem=$hpkCs or @codeSystem=$artnrCs"
            >COCT_MT720000NL: medicatiecode moet komen uit codesysteem GPK, PRK, HPK, of artikelnummer</assert>
        <assert role="error" test="not(hl7:translation) or hl7:translation/@codeSystem=$gpkCs or hl7:translation/@codeSystem=$prkCs or hl7:translation/@codeSystem=$hpkCs"
            >COCT_MT720000NL: medicatiecode kan alleen translation hebben uit GPK, PRK, HPK</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem=@codeSystem)"
            >COCT_MT720000NL: medicatiecode kan geen translation hebben uit hetzelfde codesysteem</assert>
        <assert role="error" test="not(@codeSystem=$gpkCs and hl7:translation)"
            >COCT_MT720000NL: medicatiecode uit GPK kan geen translation hebben</assert>
        <assert role="error" test="not(@codeSystem=$prkCs) or (count(hl7:translation)=1 and hl7:translation/@codeSystem=$gpkCs)"
            >COCT_MT720000NL: medicatiecode uit PRK moet een translation hebben uit GPK en geen andere translations</assert>
        <assert role="error" test="(@code and @displayName) or not(@code)"
            >COCT_MT720000NL: medicatiecode moet attribuut @displayName hebben tenzij er geen code is</assert>
        <assert role="error" test="not(@nullFlavor) or @nullFlavor='OTH'"
            >COCT_MT720000NL: bij niet gecodeerde medicatie moet @nullFlavor 'OTH' bevatten</assert>
        <assert role="error" test="not(@nullFlavor) or string-length(hl7:originalText)&gt;0"
            >COCT_MT720000NL: bij magistrale receptuur moet originalText een waarde hebben</assert>
        <assert role="error" test="@nullFlavor or not(hl7:originalText)"
            >COCT_MT720000NL: bij gecodeerde medicatie mag originalText geen waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:desc">
        <extends rule="ED"/>
        <assert role="error" test="../hl7:code/@nullFlavor"
            >COCT_MT720000NL: bij gecodeerde medicatie mag desc geen waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:formCode">
        <assert role="error" test="false()"
            >COCT_MT720000NL: <value-of select="local-name(.)"/> mag niet voorkomen</assert>
        <!--extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.11'"
            >COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.2.4.4.11' (G-Standaard subtabel 0006 farmaceutische vormen)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.5.85'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/OrderableDrugForm.htm"
            >COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.5.85'</assert-->
    </rule>
    <rule context="$element/hl7:lotNumberText">
        <assert role="error" test="false()"
            >COCT_MT720000NL: <value-of select="local-name(.)"/> mag niet voorkomen</assert>
        <!--extends rule="ST"/-->
    </rule>
    
    <!-- activeIngredient -->
    <rule context="$element/hl7:activeIngredient">
        <assert role="error" test="../hl7:code/@nullFlavor"
            >COCT_MT720000NL: bij gecodeerde medicatie mag <value-of select="local-name(.)"/> geen waarde hebben</assert>
        <assert role="error" test="not(@classCode) or @classCode='ACTI'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ACTI"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'ACTI' zijn</assert>
        <assert role="error" test="hl7:quantity or hl7:activeIngredientMaterialKind"
            >COCT_MT720000NL: quantity of activeIngredientMaterialKind is verplicht</assert>
    </rule>
    <rule context="$element/hl7:activeIngredient/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <!-- hl7:activeIngredient/hl7:activeIngredientMaterialKind en hl7:otherIngredient/hl7:otherIngredientMaterialKind -->
    <rule context="$element/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']">
        <assert role="error" test="not(@classCode) or @classCode='MMAT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ACTI"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'MAT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']/hl7:code">
        <extends rule="CE"/>
        
        <assert role="error" test="not(@codeSystem) or @codeSystem=$atcCs or @codeSystem=$gpkCs or @codeSystem=$prkCs or
            @codeSystem=$hpkCs or @codeSystem=$artnrCs"
            >COCT_MT720000NL: medicatiecode moet komen uit codesysteem ATC, GPK, PRK, HPK, of artikelnummer</assert>
        <assert role="error" test="not(hl7:translation) or 
            hl7:translation/@codeSystem=$atcCs or hl7:translation/@codeSystem=$gpkCs or hl7:translation/@codeSystem=$prkCs or hl7:translation/@codeSystem=$hpkCs"
            >COCT_MT720000NL: medicatiecode kan alleen translation hebben uit ATC, GPK, PRK, of HPK</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem=@codeSystem)"
            >COCT_MT720000NL: medicatiecode kan geen translation hebben uit hetzelfde codesysteem</assert>
        <assert role="error" test="not(@codeSystem=$atcCs and hl7:translation)"
            >COCT_MT720000NL: medicatiecode uit ATC kan geen translation hebben</assert>
        <assert role="error" test="not(@codeSystem=$prkCs) or 
            (count(hl7:translation)=1 and hl7:translation/@codeSystem=$gpkCs) or 
            (count(hl7:translation)=2 and hl7:translation/@codeSystem=$gpkCs and hl7:translation/@codeSystem=$atcCs)"
            >COCT_MT720000NL: medicatiecode uit PRK moet een translation hebben uit GPK en mag een translation uit ATC hebben</assert>
        <assert role="error" test="(@code and @displayName) or not(@code)"
            >COCT_MT720000NL: medicatiecode moet attribuut @displayName hebben tenzij er geen code is</assert>
        <assert role="error" test="not(@nullFlavor) or @nullFlavor='OTH'"
            >COCT_MT720000NL: bij niet gecodeerde medicatie moet @nullFlavor 'OTH' bevatten</assert>
        <assert role="error" test="not(@nullFlavor) or string-length(hl7:originalText)&gt;0"
            >COCT_MT720000NL: bij magistrale receptuur moet originalText een waarde hebben</assert>
        <assert role="error" test="@nullFlavor or not(hl7:originalText)"
            >COCT_MT720000NL: bij gecodeerde medicatie mag originalText geen waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']/hl7:desc">
        <extends rule="ED"/>
    </rule>
    
    <!-- content -->
    <rule context="$element/hl7:content">
        <assert role="error" test="false()"
            >COCT_MT720000NL: <value-of select="local-name(.)"/> mag niet voorkomen</assert>
    </rule>
    <!-- Deze rules komen mogleijk later van pas, dus laten staan -->
    <!--rule context="$element/hl7:content">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#CONT"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
    </rule>
    <rule context="$element/hl7:content/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:content//hl7:containerKind">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#CONT"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:content//hl7:containerKind/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='1.3.160'"
            >COCT_MT720000NL: verpakkingscode moet komen uit codesysteem '1.3.160' (EAN-artikelcodes)</assert>
    </rule>
    <rule context="$element/hl7:content//hl7:containerKind/hl7:formCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.12'"
            >COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.2.4.4.12' (G-Standaard subtabel 0004 omschrijving deelverpakkingen)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.5.1060'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ContainerEntityType.htm"
            >COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.5.1060'</assert>
    </rule>
    <rule context="$element/hl7:content//hl7:containerKind/hl7:asSubContent">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#CONT"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
    </rule>
    <rule context="$element/hl7:content//hl7:containerKind/hl7:asSubContent/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule-->
    
    <!-- otherIngredient -->
    <rule context="$element/hl7:otherIngredient">
        <assert role="error" test="../hl7:code/@nullFlavor"
            >COCT_MT720000NL: bij gecodeerde medicatie mag <value-of select="local-name(.)"/> geen waarde hebben</assert>
        <assert role="error" test="not(@classCode) or @classCode='INGR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#INGR"
            >COCT_MT720000NL: @classCode moet indien aanwezig 'INGR' zijn</assert>
    </rule>
    <rule context="$element/hl7:otherIngredient/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <!-- see activeIngredient for MaterialKind -->
</pattern>
