<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="PORX_MT924000NL">
    <title>A_MedicationDispenseEvent universal</title>
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='SPLY'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SPLY"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'SPLY' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
        
            <!--  De regels met expectedUseTime dienen nog aangepast aan AORTA 7      -->
<!--        <assert role="error" test="hl7:expectedUseTime/hl7:low/@value or 
            hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime/hl7:comp[@xsi:type='IVL_TS'][string-length(hl7:low/@value)&gt;=12 and string-length(hl7:high/@value)&gt;=12]"
            >PORX_MT924000NL: expectedUseTime/low moet aanwezig zijn, of medicationadministrationRequest/effectiveTime moet een interval
            bevatten met zowel low als high tot op de minuut nauwkeurig.</assert>-->
<!--        <assert role="error" test="not(hl7:expectedUseTime and hl7:effectiveTime) or hl7:expectedUseTime/hl7:low/@value >= hl7:effectiveTime/@value"
            >PORX_MT924000NL: expectedUseTime/low moet groter zijn dan of gelijk zijn aan effectiveTime/@value</assert>
-->        
        <let name="performerIdRoot" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@root"/>
        <let name="performerIdExtension" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@extension"/>
        <let name="responsiblePartyIdRoot" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@root"/>
        <let name="responsiblePartyIdExt" value="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@extension"/>
        <assert role="error" test="not(hl7:performer and hl7:responsibleParty) or 
            ($performerIdRoot=$responsiblePartyIdRoot and $performerIdExtension=$responsiblePartyIdExt)"
            >PORX_MT924000NL: performer en responsibleParty moeten van dezelfde organisatie zijn</assert>
    </rule>
    
    <rule context="$element/hl7:id">
        <extends rule="II"/>
        <report role="warning" test="not(substring(@root,1,20)='2.16.528.1.1007.3.3.')"
            >PORX_MT924000NL: @root moet bij voorkeur gebaseerd zijn op de URA</report>
    </rule>
    <rule context="$element/hl7:code">
        <extends rule="CV"/>
    </rule>
    <rule context="$element/hl7:text">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@code='completed'"
            >PORX_MT924000NL: statuscode moet 'completed' zijn</assert>
    </rule>
    <rule context="$element/hl7:effectiveTime">
        <extends rule="IVL_TS"/>
        
        <assert role="error" test="@value or (hl7:low/@value and hl7:high/@value)"
            >PORX_MT924000NL: effectiveTime/low en effectiveTime/high moeten een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:quantity">
        <extends rule="PQ"/>
        <assert role="error" test="@nullFlavor='NA' or 
            hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' or @codeSystem='2.16.840.1.113883.2.4.4.12']"
            >PORX_MT924000NL: quantity moet een vertaling hebben op basis van een numerieke code uit '2.16.840.1.113883.2.4.4.1.900.2' 
            (G-Standaard basiseenheden tabel 2) of '2.16.840.1.113883.2.4.4.12' (G-Standaard deelverpakkingen tabel 4)</assert>
        <assert role="error" test="@nullFlavor='NA' or @value > 0"
            >PORX_MT924000NL: quantity moet groter zijn 0 of @nullFlavor moet "NA" zijn</assert>
        <report role="warning" test="hl7:translation and not(hl7:translation[@value=../@value])"
            >PORX_MT924000NL: quantity in translation moet gelijk zijn aan UCUM quantity</report>
        <assert role="error" test="not(hl7:translation) or hl7:translation[@code and @displayName]"
            >PORX_MT924000NL: quantity in translation moet @displayName hebben bij een code</assert>
    </rule>
<!--    <rule context="$element/hl7:expectedUseTime">
        <extends rule="IVL_TS"/>
        <report role="warning" test="not(hl7:high or ../hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:precondition)"
            >PORX_MT924000NL: expectedUseTime/high element ontbreekt en er is geen medicationAdministrationRequest/precondition</report>
    </rule>-->
    
    <!-- 
        destination
    -->
    <rule context="$element/hl7:destination">
        <assert role="error" test="not(@typeCode) or @typeCode='DST'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#DST"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'DST' zijn</assert>
    </rule>
    <rule context="$element/hl7:destination/hl7:serviceDeliveryLocation">
        <assert role="error" test="not(@classCode) or @classCode='SDLOC'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#SDLOC"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'SDLOC' zijn</assert>
    </rule>
    <rule context="$element/hl7:destination/hl7:serviceDeliveryLocation/hl7:code">
        <extends rule="CV"/>
    </rule>
    <rule context="$element/hl7:destination/hl7:serviceDeliveryLocation/hl7:addr">
        <extends rule="AD"/>
    </rule>
    
    <!-- 
        performer
    -->
    <rule context="$element/hl7:performer">
        <assert role="error" test="not(@typeCode) or @typeCode='PRF'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#PRF"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'PRF' zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ASSIGNED"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@nullFlavor='UNK' or @root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.1'"
            >PORX_MT924000NL: identificatie van de beoogde verstrekker moet UZI of AGB zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:representedOrganization">
        <assert role="error" test="not(@classCode) or @classCode='ORG'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ORG"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'ORG' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='INSTANCE'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityDeterminer.htm#INSTANCE"
            >PORX_MT924000NL: @determinerCode moet indien aanwezig 'INSTANCE' zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.3' or @root='2.16.840.1.113883.2.4.6.1'"
            >PORX_MT924000NL: identificatie van de organisatie van de beoogde voorschrijver moet URA of AGB zijn</assert>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:name">
        <extends rule="ON"/>
    </rule>
    <rule context="$element/hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:addr">
        <extends rule="AD"/>
    </rule>
    
    <!-- 
        product
    -->
    <rule context="$element/hl7:product">
        <assert role="error" test="not(@typeCode) or @typeCode='PRD'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#PRD"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'PRD' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:substitutionCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1071'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/SubstitutionCondition.htm"
            >PORX_MT924000NL: vervangingscode moet komen uit codesysteem '2.16.840.1.113883.5.1071'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication">
        <assert role="error" test="not(@classCode) or @classCode='DST'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#DST"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'DST' zijn</assert>
    </rule>
    
    <title>E_MedicationKind universal</title>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind">
        <assert role="error" test="not(@classCode) or @classCode='MMAT'"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'MMAT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >PORX_MT924000NL/COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.1' or @codeSystem='2.16.840.1.113883.2.4.4.10' or
            @codeSystem='2.16.840.1.113883.2.4.4.7' or @codeSystem='2.16.840.1.113883.2.4.4.8'"
            >PORX_MT924000NL/COCT_MT720000NL: medicatiecode moet komen uit codesysteem GPK, PRK, HPK, of ZI_Nummer</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.10' or
            hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.7' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.8'"
            >PORX_MT924000NL/COCT_MT720000NL: medicatiecode in translation moet komen uit codesysteem PRK, HPK, of ZI_Nummer</assert>
        <assert role="error" test="not(@codeSystem='2.16.840.1.113883.2.4.4.1' and 
            (hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.10' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.7' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.8'))"
            >PORX_MT924000NL/COCT_MT720000NL: medicatiecode uit GPK moet een translation hebben uit een generieker codesysteem</assert>
        <assert role="error" test="not(@codeSystem='2.16.840.1.113883.2.4.4.10' and 
            (hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.7' or hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.8'))"
            >PORX_MT924000NL/COCT_MT720000NL: medicatiecode uit PRK moet een translation hebben uit een generieker codesysteem</assert>
        <assert role="error" test="not(@codeSystem='2.16.840.1.113883.2.4.4.7' and 
            hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.8')"
            >PORX_MT924000NL/COCT_MT720000NL: medicatiecode uit HPK moet een translation hebben uit een generieker codesysteem</assert>
        <assert role="error" test="@displayName or (@nullFlavor and hl7:originalText)"
            >PORX_MT924000NL/COCT_MT720000NL: medicatiecode moet attribuut @displayName of @nullFlavor en originalText hebben</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:desc">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:formCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.11'"
            >PORX_MT924000NL/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.2.4.4.11' (G-Standaard subtabel 0006 farmaceutische vormen)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.5.85'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/OrderableDrugForm.htm"
            >PORX_MT924000NL/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.5.85'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:lotNumberText">
        <extends rule="ST"/>
    </rule>
    <!-- activeIngredient -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:activeIngredient">
        <report role="warning" test="."
            >PORX_MT924000NL/COCT_MT720000NL: activeIngredient nog niet gebruiken.</report>
        <assert role="error" test="not(@classCode) or @classCode='ACTI'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ACTI"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'ACTI' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:activeIngredient/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <!-- hl7:activeIngredient/hl7:activeIngredientMaterialKind en hl7:otherIngredient/hl7:otherIngredientMaterialKind -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']">
        <assert role="error" test="not(@classCode) or @classCode='MMAT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ACTI"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'MAT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >PORX_MT924000NL/COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']/hl7:code">
        <extends rule="CE"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:*[local-name()='activeIngredient' or local-name()='otherIngredient']/hl7:*[local-name()='activeIngredientMaterialKind' or local-name()='otherIngredientMaterialKind']/hl7:desc">
        <extends rule="ED"/>
    </rule>
    
    <!-- content -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#CONT"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#CONT"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='KIND'"
            >PORX_MT924000NL/COCT_MT720000NL: @determinerCode moet indien aanwezig 'KIND' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='1.3.160'"
            >PORX_MT924000NL/COCT_MT720000NL: verpakkingscode moet komen uit codesysteem '1.3.160' (EAN-artikelcodes)</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:formCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.12'"
            >PORX_MT924000NL/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.2.4.4.12' (G-Standaard subtabel 0004 omschrijving deelverpakkingen)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@codeSystem='2.16.840.1.113883.5.1060'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ContainerEntityType.htm"
            >PORX_MT924000NL/COCT_MT720000NL: doseervorm moet komen uit codesysteem '2.16.840.1.113883.5.1060'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:asSubContent">
        <assert role="error" test="not(@classCode) or @classCode='CONT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#CONT"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'CONT' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:content//hl7:containerKind/hl7:asSubContent/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    
    <!-- otherIngredient -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:otherIngredient">
        <assert role="error" test="not(@classCode) or @classCode='INGR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#INGR"
            >PORX_MT924000NL/COCT_MT720000NL: @classCode moet indien aanwezig 'INGR' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:MedicationKind/hl7:otherIngredient/hl7:quantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <!-- see activeIngredient for MaterialKind -->
    
    <!-- 
        directTargetOf
    -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf">
        <assert role="error" test="not(@typeCode) or @typeCode='DIR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#DIR"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'DIR' zijn. Merk op: 'DIR' is de standaardwaarde volgens het R-MIM. 'TPA' is de standaardwaarde volgens het XML Schema</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescribedMedication">
        <assert role="error" test="not(@classCode) or @classCode='THER'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#THER"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'THER' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription">
        <assert role="error" test="not(@classCode) or @classCode='SBADM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'SBADM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:text">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:statusCode">
        <extends rule="CS"/>
        <!-- Onderstaande is alleen waar bij voorschriften -->
        <!--assert test="@code='active'"
            >PORX_MT924000NL: <value-of select="local-name(..)"/>/statusCode moet 'active' zijn</assert-->
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:confidentialityCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.25'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Confidentiality.htm"
            >PORX_MT924000NL: vertrouwelijkheidscode moet komen uit codesysteem '2.16.840.1.113883.5.25'</assert>
    </rule>
    
    <!-- subject -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject">
        <assert role="error" test="not(@typeCode) or @typeCode='SBJ'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#SBJ"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'SBJ' zijn</assert>
    </rule>
    <title>COCT_MT050000NL R_PatientNL universal</title>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient" subject="COCT_MT050000NL">
        <assert role="error" test="not(@classCode) or @classCode='PAT'"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'PAT' zijn</assert>
        <assert role="error" test="hl7:id[@root='2.16.840.1.113883.2.4.6.3']"
            >PORX_MT924000NL: er moet tenminste een burgerservicenummer zijn ter identificatie</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:addr">
        <extends rule="AD"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:telecom">
        <extends rule="TEL"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@code='active'"
            >PORX_MT924000NL: <value-of select="local-name(..)"/>/statusCode moet 'active' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person">
        <assert role="error" test="hl7:name"
            >PORX_MT924000NL: patiëntnaam moet een waarde hebben</assert>
        <assert role="error" test="hl7:birthTime"
            >PORX_MT924000NL: birthTime moet een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.840.1.113883.2.4.6.3'"
            >PORX_MT924000NL: als er een persoonsnummer wordt gebruikt moet dat het burgerservicenummer zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:name">
        <extends rule="PN"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/AdministrativeGender.htm"
            >PORX_MT924000NL: geslacht moet komen uit codesysteem '2.16.840.1.113883.5.1'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:subject/hl7:Patient/hl7:Person/hl7:birthTime">
        <extends rule="TS"/>
    </rule>
    
    <!-- author -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author">
        <assert role="error" test="not(@typeCode) or @typeCode='AUT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#AUT"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'AUT' zijn</assert>
        <assert role="error" test="hl7:time[@nullFlavor='UNK' or @value]"
            >PORX_MT924000NL: moment van voorschrijven ontbreekt of nullFlavor is niet gelijk aan 'UNK'</assert>
        
        <let name="performerRoot" value="../../../../../hl7:performer/hl7:assignedPerson/hl7:id/@root"/>
        <let name="performerExt" value="../../../../../hl7:performer/hl7:assignedPerson/hl7:id/@extension"/>
        <report role="warning" test="hl7:AssignedPerson/hl7:id[@root=$performerRoot and @extension=$performerExt]"
            >PORX_MT924000NL: MedicationDispenseEvent/performer en presciption/author zijn gelijk. Alleen een apotheekhoudend huisarts mag zowel voorschrijven als afleveren.</report>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:time">
        <extends rule="TS"/>
        <let name="tsValue" value="@value"/>
        <let name="normTsValue" value="xs:integer(substring(concat(replace($tsValue,'[^\d]',''),'00000000000000'),1,14))"/>
        
        <let name="creationTime" value="ancestor::hl7:*[hl7:creationTime][1]/hl7:creationTime/@value"/>
        <let name="normCreationTime" value="xs:integer(substring(concat(replace($creationTime,'[^\d]',''),'00000000000000'),1,14))"/>
        
        <assert role="error"
            test="not(@value) or $normTsValue &lt;= $normCreationTime"
            >PORX_MT924000NL: moment van voorschrijven '<value-of select="$tsValue"/>' moet liggen vóór
            het moment van verzenden van het bericht '<value-of select="$creationTime"/>'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:modeCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1064'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationMode.htm"
            >PORX_MT924000NL: participatiewijze moet komen uit codesysteem '2.16.840.1.113883.5.1064'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:signatureCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.89'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/SignatureCode.htm"
            >PORX_MT924000NL: participatiehandtekening moet komen uit codesysteem '2.16.840.1.113883.5.89'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:signatureText">
        <extends rule="ED"/>
    </rule>
    
    <!-- assignedPerson-->
    <title>COCT_MT090102NL R_AssignedPerson identified/confirmable</title>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:AssignedPerson" subject="COCT_MT090102NL">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:AssignedPerson/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.1'"
            >PORX_MT924000NL: identificatie van de voorschrijver moet UZI of AGB zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:author/hl7:AssignedPerson/hl7:code">
        <extends rule="CE"/>
    </rule>
    
    <!-- reason -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason">
        <assert role="error" test="not(@typeCode) or @typeCode='RSON'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#RSON"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'RSON' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason/hl7:diagnosisEvent">
        <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#OBS"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'OBS' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason/hl7:diagnosisEvent/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason/hl7:diagnosisEvent/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="@code='DX' and @codeSystem='2.16.840.1.113883.5.4'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActCode.htm#DX"
            >PORX_MT924000NL: @code moet 'DX' zijn en @codeSystem '2.16.840.1.113883.5.4'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason/hl7:diagnosisEvent/hl7:text">
        <extends rule="ST"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reason/hl7:diagnosisEvent/hl7:value">
        <extends rule="CE"/>
    </rule>
    
    <!-- reference -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reference">
        <assert role="error" test="not(@typeCode) or @typeCode='REFR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#REFR"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'REFR' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reference/hl7:patientCareProvision">
        <assert role="error" test="not(@classCode) or @classCode='REFR'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#PCPR"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'PCPR' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:directTargetOf/hl7:prescription/hl7:reference/hl7:patientCareProvision/hl7:id">
        <extends rule="II"/>
    </rule>
    
    <!-- 
        therapeuticAgentOf
    -->
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf">
        <assert role="error" test="not(@typeCode) or @typeCode='TPA'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#TPA"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'TPA' zijn</assert>
        
        <let name="xsiType" value="string(hl7:effectiveTime/@xsi:type)"/>
        <assert role="error" test="not(hl7:effectiveTime) or ($xsiType='IVL_TS' or $xsiType='PIVL_TS' or $xsiType='SXPR_TS')"
            >PORX_MT924000NL: effectiveTime moet van type IVL_TS, PIVL_TS of SXPR_TS zijn</assert>
    </rule>
    
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:productOf/hl7:medicationAdministrationRequest">
        <assert role="error" test="not(@classCode) or @classCode='SBADM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'SBADM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:text">
        <extends rule="ED"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@code='active'"
            >PORX_MT924000NL: statusCode van medicationAdministrationRequest moet 'active' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='SXPR_TS']">
        <extends rule="SXPR_TS"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='PIVL_TS']">
        <extends rule="PIVL_TS"/>
        <assert role="error" test="hl7:period/@value > 0"
            >PORX_MT924000NL: als effectiveTime van het type PIVL_TS is, moet de periode groter dan 0 zijn</assert>
        <assert role="error" test="hl7:period/@value and hl7:period/@unit"
            >PORX_MT924000NL: als effectiveTime van het type PIVL_TS is, moeten @value en @unit een waarde hebben period</assert>
        <assert role="error" test="hl7:period[@unit='h' or @unit='d' or @unit='wk' or @unit='mo' or @unit='a']"
            >PORX_MT924000NL: effectiveTime is van het type PIVL_TS, maar de period unit is niet 'h', 'd', 'wk', 'mo' of 'a'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime[@xsi:type='IVL_TS']">
        <extends rule="IVL_TS"/>
        <assert role="error" test="not(hl7:high) or hl7:low"
            >PORX_MT924000NL: als effectiveTime is van het type IVL_TS en er is een high dan moet er ook een low zijn</assert>
        <assert role="error" test="not(hl7:width) or not(hl7:high)"
            >PORX_MT924000NL: als effectiveTime is van het type IVL_TS en er is een width dan mag er geen high zijn</assert>
        <assert role="error" test="not(@value or hl7:center)"
            >PORX_MT924000NL: als effectiveTime is van het type IVL_TS dan mogen @value en center niet worden gebruikt</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:priorityCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.7'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Priority.htm"
            >PORX_MT924000NL: prioriteit moet komen uit codesysteem '2.16.840.1.113883.5.7'</assert>
        <assert role="error" test="not(@code) or (@code='R' or @code='UR')" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/Priority.htm"
            >PORX_MT924000NL: prioriteit moet @code 'R' or 'UR' hebben</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:routeCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.9'"
            >PORX_MT924000NL: toedieningsweg moet komen uit codesysteem '2.16.840.1.113883.2.4.4.9' (G-standaard thesaurus subtabel 0007)</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation[@codeSystem='2.16.840.1.113883.5.112']" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RouteOfAdministration.htm"
            >PORX_MT924000NL: toedieningsweg mag een vertaling hebben en moet dan komen uit '2.16.840.1.113883.5.112'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:approachSiteCode">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1052'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActSite.htm"
            >PORX_MT924000NL: toedieningsplaats moet komen uit codesysteem '2.16.840.1.113883.5.1052'</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:doseQuantity">
        <extends rule="IVL_PQ"/>
        <assert role="error" test="not(*//hl7:translation/@codeSystem) or 
            *//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' or @codeSystem='2.16.840.1.113883.2.4.4.1.361']"
            >PORX_MT924000NL: doseerhoeveelheid mag een vertaling hebben en moet dan een numerieke code zijn uit '2.16.840.1.113883.2.4.4.1.900.2' 
            (G-Standaard basiseenheden tabel 2) of '2.16.840.1.113883.2.4.4.1.361' (NHG Tabel 25)</assert>
        <assert role="error" test="not(*//hl7:translation/@codeSystem) or *//hl7:translation/@displayName"
            >PORX_MT924000NL: in translation elementen moet @displayName een waarde hebben als er een code is</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2']) or 
            *//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' and @value=../@value]"
            >PORX_MT924000NL: translation/@value in G-Standaard basiseenheden tabel 2 moet gelijk zijn aan doseQuantity/@value</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='10' and not(@value=../@value div 15)])"
            >PORX_MT924000NL: als NHG Tabel 25 code '10' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 15</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='11' and not(@value=../@value div 8)])"
            >PORX_MT924000NL: als NHG Tabel 25 code '11' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 8</assert>
        <assert role="error" test="not(*//hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='14' and not(@value=../@value div 3)])"
            >PORX_MT924000NL: als NHG Tabel 25 code '14' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 3</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:rateQuantity">
        <extends rule="IVL_PQ"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:maxDoseQuantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:support2">
        <assert role="error" test="not(@typeCode) or @typeCode='SPRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SPRT"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'SPRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:support2/hl7:medicationAdministrationInstruction">
        <assert role="error" test="not(@classCode) or @classCode='INFRM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#INFRM"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'INFRM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:support2/hl7:medicationAdministrationInstruction/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >PORX_MT924000NL: toedieningsinstructie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:precondition">
        <assert role="error" test="not(@typeCode) or @typeCode='PRCN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#PRCN"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'PRCN' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:precondition/hl7:pauseQuantity">
        <extends rule="PQ"/>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:precondition/hl7:observationEventCriterion">
        <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#OBS"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'OBS' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN.CRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN.CRT"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'EVN.CRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:precondition/hl7:observationEventCriterion/hl7:code">
        <extends rule="CD"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >PORX_MT924000NL: preconditie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:support1">
        <assert role="error" test="not(@typeCode) or @typeCode='SPRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SPRT"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'SPRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:support1/hl7:medicationStorageInstruction">
        <assert role="error" test="not(@classCode) or @classCode='INFRM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#INFRM"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'INFRM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >PORX_MT924000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:support1/hl7:medicationStorageInstruction/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >PORX_MT924000NL: opslaginstructie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    
    <!-- 
        responsibleParty
    -->
    <rule context="$element/hl7:responsibleParty">
        <assert role="error" test="not(@typeCode) or @typeCode='RESP'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ParticipationType.htm#RESP"
            >PORX_MT924000NL: @typeCode moet indien aanwezig 'RESP' zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider">
        <assert role="error" test="not(@classCode) or @classCode='ASSIGNED'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/RoleClass.htm#ASSIGNED"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'ASSIGNED' zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.1'"
            >PORX_MT924000NL: identificatie van de verantwoordelijke zorgverlener is geen UZI of AGB</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="@nullFlavor='UNK' or (@codeSystem='2.16.840.1.113883.2.4.15.111' and (@code='01.004' or @code='17.000' or @code='17.060'))"
            >PORX_MT924000NL: rolcode van de verantwoordelijke zorgverlener moet komen uit '2.16.840.1.113883.2.4.15.111' en een van 01.004, 17.000, of 17.060 zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization">
        <assert role="error" test="not(@classCode) or @classCode='ORG'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#ORG"
            >PORX_MT924000NL: @classCode moet indien aanwezig 'ORG' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='INSTANCE'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityDeterminer.htm#INSTANCE"
            >PORX_MT924000NL: @determinerCode moet indien aanwezig 'INSTANCE' zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="@root='2.16.528.1.1007.3.3' or @root='2.16.840.1.113883.2.4.6.1'"
            >PORX_MT924000NL: identificatie van de organisatie van de verantwoordelijke zorgverlener moet URA of AGB zijn</assert>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:name">
        <extends rule="ON"/>
    </rule>
    <rule context="$element/hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:addr">
        <extends rule="AD"/>
    </rule>
    
    </pattern>
