<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van QURX_IN990103NL - Medication Combined Order Query Response</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>
    
    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>
    <include href="coreschematron/COCT_MT050000NL.sch"/>
    <include href="Mp/COCT_MT932000NL02.sch"/>
    
    <pattern is-a="transmission-wrapper" id="QURX_IN990103NL-wrapper">
        <param name="element" value="hl7:QURX_IN990103NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="QURX_IN990103NL-controlAct">
        <param name="element" value="hl7:QURX_IN990103NL/hl7:ControlActProcess"/>
    </pattern>
    
    <pattern>
        <!-- profileId -->
        <rule context="hl7:QURX_IN990103NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:QURX_IN990103NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='NE'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'NE'.</assert>
        </rule>
        <rule context="hl7:QURX_IN990103NL/hl7:attentionLine">
            <assert role="warning" test="not(.)">Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
    </pattern>
    
    <pattern is-a="COCT_MT050000NL" id="QURX_IN990103NL-COCT_MT050000NL">
        <param name="element" value="hl7:QURX_IN990103NL/hl7:ControlActProcess/hl7:subject/hl7:MedicationPrescriptionList/hl7:subject/hl7:Patient"/>
    </pattern>
    
    <pattern is-a="COCT_MT932000NL02" id="QURX_IN990103NL-COCT_MT932000NL02">
        <param name="element" value="hl7:QURX_IN990103NL/hl7:ControlActProcess/hl7:subject/hl7:MedicationPrescriptionList/hl7:component/hl7:prescription"/>
    </pattern>
    
    <pattern>
        <title>Voorschrijvend arts is niet duidelijk binnen deze interactie en wordt apart gecontroleerd</title>
        <rule context="hl7:QURX_IN990103NL/hl7:ControlActProcess/hl7:subject/hl7:MedicationPrescriptionList/hl7:component/hl7:prescription">
            <assert test="hl7:author/hl7:AssignedPerson[not(@xsi:nil='true') and not(@nullFlavor)]"
                >De voorschrijvend arts is verplicht indien deze niet duidelijk is in de context. Bij gebruik in deze interactie is de voorschrijver dus verplicht.</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>Prescription Info</title>
        <!--rule context="hl7:prescription">
            <assert role="error"
                test="(hl7:id/@root and hl7:id/@extension) or
                hl7:id/@nullFlavor='UNK'"
                >id moet @root en @extension hebben, of @nullFlavor</assert>
            <assert role="error" test="hl7:statusCode/@code='active'"
                >statusCode van de prescription moet 'active' zijn</assert>
            <assert role="error"
                test="count(hl7:subject/hl7:Patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3'
                and @extension])>0"
                >BSN ontbreekt in Patient</assert>
            <assert role="error"
                test="hl7:subject/hl7:Patient/hl7:statusCode/@code='active'"
                >statusCode van Patient moet 'active' zijn</assert>
            <assert role="error" test="hl7:subject/hl7:Patient/hl7:Person/hl7:name"
                >name van Patient is veprlicht</assert>
            <assert role="error"
                test="hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode/@code='F' or
                hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode/@code='M' or
                hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode/@code='UN'"
                >administrativeGenderCode van Patient moet 'F','M' of 'UN' zijn</assert>
            <assert role="error"
                test="hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode/@codeSystem='2.16.840.1.113883.5.1'"
                >@codeSystem voor code geslacht moet '2.16.840.1.113883.5.1' zijn</assert>
            <assert role="error"
                test="hl7:subject/hl7:Patient/hl7:Person/hl7:birthTime/@value"
                >Geboortedatum patient is verplicht</assert>
            
        </rule-->
        <!--rule context="hl7:prescription/hl7:author">
            <assert role="error"
                test="hl7:time/@value or
                hl7:time/@nullFlavor='UNK'"
                >Moment van voorschrijven is verplicht, of @nullFlavor moet 'UNK' zijn</assert>
            <assert role="error"
                test="hl7:AssignedPerson/hl7:id/@root='2.16.528.1.1007.3.1'
                or
                hl7:AssignedPerson/hl7:id/@root='2.16.840.1.113883.2.4.6.1'"
                >identificatie van een arts moet UZI of AGB zijn</assert>
        </rule-->
    </pattern>
</schema>
