<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van REPC_IN000024NL - Patient General Conditions Response</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>
    
    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>
    
    <include href="coreschematron/COCT_MT040200.sch"/>
    <include href="coreschematron/COCT_MT050000NL.sch"/>
    <include href="coreschematron/COCT_MT090100NL.sch"/>
    <include href="coreschematron/COCT_MT090102.sch"/>
    <include href="Mp/COCT_MT720000NL.sch"/>
    <include href="Mp/COCT_MT000003NL.sch"/>
    
    <pattern is-a="transmission-wrapper" id="REPC_IN000024NL-wrapper">
        <param name="element" value="hl7:REPC_IN000024NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="REPC_IN000024NL-controlAct">
        <param name="element" value="hl7:REPC_IN000024NL/hl7:ControlActProcess"/>
    </pattern>
    
    <pattern>
        <!-- profileId -->
        <rule context="hl7:REPC_IN000024NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:REPC_IN000024NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='NE'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'NE'.</assert>
        </rule>
        <rule context="hl7:REPC_IN000024NL/hl7:attentionLine">
            <assert role="warning" test="not(.)">Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
    </pattern>
    
    <!-- ControlAct Wrapper -->
    <pattern>
        <title>ControlAct Wrapper</title>
        <rule context="hl7:ControlActProcess">
            <assert role="error" test="@moodCode='EVN'">moodCode is niet gelijk aan EVN</assert>
            <assert role="error" test="hl7:authorOrPerformer/@typeCode='AUT'">typecode
                authorOrPerformer is niet gelijk aan AUT</assert>
        </rule>
    </pattern>
    
    <!-- Payload -->
    <!-- R_PatientNL universal -->
    <pattern is-a="COCT_MT050000NL" id="subject_Patient">
        <param name="element" value="hl7:subject/hl7:Patient"/>
    </pattern>
    
    <!-- administerableMedicationKind -->
    <pattern is-a="COCT_MT720000NL" id="administerableMaterial_administerableMedicationKind">
        <param name="element" value="hl7:subject/hl7:condition/hl7:causativeAgent/hl7:administerableMaterial/hl7:administerableMedicationKind"/>
    </pattern>
    <pattern>
        <title>MedicationKind: extra constraint</title>
        <rule context="hl7:subject/hl7:Condition/hl7:causativeAgent/hl7:administerableMaterial/hl7:administerableMedicationKind/hl7:code">
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.7' or @codeSystem='2.16.840.1.113883.2.4.4.10'"
                >REPC_MT000003NL: medicatie niet volgens HPK of PRK gecodeerd</assert>
            <assert role="error" test="string-length(@code)>0"
                >REPC_MT000003NL: medicatiecode moet een waarde hebben</assert>
        </rule>
    </pattern>
    
    <!-- author/assignedPerson -->
    <pattern is-a="COCT_MT090102" id="Condition_author_assignedPerson">
        <param name="element" value="hl7:subject/hl7:Condition/hl7:author/hl7:assignedPerson"/>
    </pattern>
    
    <!-- informant/assignedPerson -->
    <pattern is-a="COCT_MT090102" id="Condition_informant_assignedPerson">
        <param name="element" value="hl7:subject/hl7:Condition/hl7:informant/hl7:assignedPerson"/>
    </pattern>
    
    <!-- informant/assignedPerson -->
    <pattern is-a="COCT_MT040200" id="Condition_informant_responsibleParty">
        <param name="element" value="hl7:subject/hl7:Condition/hl7:informant/hl7:responsibleParty"/>
    </pattern>
    <!-- 
        annotation/author/assignedPerson
    -->
    <pattern is-a="COCT_MT090100NL" id="annotation_author_assignedPerson">
        <param name="element" value="hl7:subject/hl7:Condition/hl7:subjectOf2/hl7:annoation/hl7:author/hl7:assignedPerson"/>
    </pattern>
    
<!-- rest wordt afgehandeld in A_MedicalCondition (COCT_MT000003NL) -->
    
</schema>
