<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
   <title>Schematronvalidatie van REPC_IN002131NL - Resultaat gehoorscreening</title>
   <ns uri="urn:hl7-org:v3" prefix="hl7"/>
   <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
   <include href="coreschematron/xml.sch"/>
   <include href="coreschematron/attentionLine.sch"/>
   
   <include href="coreschematron/transmission-wrapper.sch"/>
   <include href="coreschematron/controlAct-wrapper.sch"/>
   
   <pattern is-a="attentionLine" id="REPC_IN002131NL-attentionLine">
      <param name="messagePatientId"
      value="hl7:ControlActProcess/hl7:subject/hl7:CareProvisionEvent/hl7:subject/hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"/>
      <param name="attentionLineOptional" value="'false'"/>
   </pattern>
   
   <pattern is-a="transmission-wrapper" id="REPC_IN002131NL-wrapper">
      <param name="element" value="hl7:REPC_IN002131NL"/>
   </pattern>
   
   <pattern is-a="controlAct-wrapper" id="REPC_IN002131NL-controlAct">
      <param name="element" value="hl7:REPC_IN002131NL/hl7:ControlActProcess"/>
   </pattern>
   
   <pattern>
      <!-- profileId -->
      <rule context="hl7:REPC_IN002131NL/hl7:profileId">
         <extends rule="II"/>
         <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
            >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
      </rule>
      <rule context="hl7:REPC_IN002131NL/hl7:acceptAckCode">
         <extends rule="CS"/>
         <assert role="error" test="@code='AL'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'AL'.</assert>
      </rule>
   </pattern>
   
   <pattern>
      <title>Codes algemeen</title>
      <rule context="hl7:code">
         <assert test="(@code and @codeSystem) or @nullFlavor or @xsi:nil='true'">Code elementen moeten een
                        code en codesystem attribuut bevatten of een nullfavor.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Bijzonderheden gezin</title>
   	<rule context="hl7:CareProvisionEvent/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:subjectOf/hl7:personalRelationshipObservation">
         <assert test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem
                        moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert test="hl7:code/@code='78' or hl7:code/@code='1322' or hl7:code/@code='1367' or hl7:code/@code='1374'">De waarde van code/@code moet 78, 1367 of 1374 zijn.</assert>
      </rule>
   </pattern>

   <pattern>
      <title>Activiteit</title>
   	<rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent">
   		<assert role="error" test="hl7:code/@code='01' or hl7:code/@code='35'">De code moet'01' of '35'  zijn.</assert>
   	</rule>
   	<rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:author/hl7:assignedEntity">
   		<assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1' or hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.1 of '2.16.528.1.1007.3.3' zijn.</assert>
   	</rule>
   	<rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:performer/hl7:assignedEntity">
   		<assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1' or hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.1 of '2.16.528.1.1007.3.3' zijn.</assert>
   	</rule>

   </pattern>
   <pattern>
      <title>Gehooronderzoek</title>
   	<rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R040']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
   		<assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code='438'])&gt;=1">Element 438, 'Gehooronderzoek uitgevoerd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='438']"
            id="BDS438">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='439']"
            id="BDS439">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='441']"
            id="BDS441">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='442']"
            id="BDS442">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='444']"
            id="BDS444">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='445']"
            id="BDS445">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='447']"
            id="BDS447">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='863']"
            id="BDS863">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionEvent/hl7:component/hl7:encounterEvent/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1413']"
            id="BDS1413">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Verantwoordelijke JGZ-organisatie</title>
   	<rule context="hl7:CareProvisionEvent/hl7:author/hl7:assignedEntity">
   		<assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1' or hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.1 of '2.16.528.1.1007.3.3' zijn.</assert>
   	</rule>
   	<rule context="hl7:CareProvisionEvent/hl7:performer/hl7:assignedEntity">
   		<assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1' or hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.1 of '2.16.528.1.1007.3.3' zijn.</assert>
   	</rule>
   </pattern>
</schema>