<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="REPC_MT000100UV01-Observation">
    <title>Metingen (Observation)</title>
    
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='OBS'"
            >@classCode moet, indien anwezig, 'OBS' bevatten</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
            >@moodCode moet, indien anwezig, 'EVN' bevatten</assert>
        
        <assert role="error" test="ancestor::hl7:encounter or hl7:effectiveTime"
            >effectiveTime is verplicht in een niet-contactgebonden meting</assert>
    </rule>
    
    <rule context="$element/hl7:id">
        <extends rule="II"/>
    </rule>
    
    <rule context="$element/hl7:code">
        <extends rule="CD"/>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.45'"
            >@codeSystem moet '2.16.840.1.113883.2.4.4.30.45' (NHG Tabel 45 Diagnostische bepalingen) bevatten</assert>
        <assert role="error" test="@codeSystemVersion"
            >@codeSystemVersion is verplicht en moet een waarde groter dan 'v10' bevatten</assert>
        <assert role="error" test="@displayName"
            >@displayName is verplicht</assert>
    </rule>
    
    <rule context="$element/hl7:text">
        <extends rule="ST"/>
    </rule>
    
    <rule context="$element/hl7:effectiveTime">
        <extends rule="IVL_TS"/>
    </rule>
    
    <rule context="$element/hl7:value[ends-with(@xsi:type,':PQ') or @xsi:type='PQ']">
        <extends rule="PQ"/>
        <assert role="error" test="not(@unit) or index-of($ucumList,@unit)"
            >@unit moet komen uit <value-of select="$ucumList"/></assert>
    </rule>
    
    <rule context="$element/hl7:value[ends-with(@xsi:type,':IVL_PQ') or @xsi:type='IVL_PQ']">
        <extends rule="IVL_PQ"/>
        <assert role="error" test="not(@unit) or index-of($ucumList,@unit)"
            >@unit moet komen uit <value-of select="$ucumList"/></assert>
        <assert role="error" test="not(hl7:low/@unit) or index-of($ucumList,hl7:low/@unit)"
            >low/@unit moet komen uit <value-of select="$ucumList"/></assert>
        <assert role="error" test="not(hl7:high/@unit) or index-of($ucumList,hl7:high/@unit)"
            >high/@unit moet komen uit <value-of select="$ucumList"/></assert>
    </rule>
    
    <rule context="$element/hl7:value[ends-with(@xsi:type,':CV') or @xsi:type='CV']">
        <extends rule="CV"/>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.1045'"
            >@codeSystem moet '2.16.840.1.113883.2.4.4.30.1045' (NHG Tabel 45 Gecodeerde uitslagen) bevatten</assert>
        <!--assert role="error" test="@codeSystemVersion"
            >@codeSystemVersion is verplicht en moet een waarde groter dan 'v14' bevatten</assert-->
        <assert role="error" test="@displayName"
            >@displayName is verplicht</assert>
    </rule>
    
    <rule context="$element/hl7:value[ends-with(@xsi:type,':ST') or @xsi:type='ST']">
        <extends rule="ST"/>
    </rule>
    
    <rule context="$element/hl7:value[ends-with(@xsi:type,':TS') or @xsi:type='TS']">
        <extends rule="TS"/>
    </rule>
    
    <rule context="$element/hl7:value[ends-with(@xsi:type,':BL') or @xsi:type='BL']">
        <extends rule="BL"/>
    </rule>
    
    <rule context="$element/hl7:value">
        <extends rule="ANY"/>
        <let name="dt" value="if (contains(@xsi:type,':')) then (substring-after(@xsi:type,':')) else (@xsi:type)"/>
        <assert role="error" test="$dt='PQ' or $dt='IVL_PQ' or $dt='CV' or $dt='ST' or $dt='TS' or $dt='BL'"
            >@xsi:type moet het datatype 'PQ', 'IVL_PQ', 'CV', 'ST', 'TS', of 'BL' bevatten</assert>
    </rule>
    
    <rule context="$element/hl7:interpretationCode">
        <extends rule="CE"/>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.5.83'"
            >@codeSystem moet '2.16.840.1.113883.5.83' (InterpretationCode) bevatten</assert>
        <assert role="error" test="@displayName"
            >@displayName is verplicht</assert>
    </rule>

    <rule context="$element/hl7:author">
        <assert role="error" test="not(@typeCode) or  @typeCode='AUT'"
            >@typeCode moet, indien anwezig, 'AUT' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >@contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>
    <rule context="$element/hl7:author/hl7:time">
        <extends rule="TS"/>
    </rule>

    <rule context="$element/hl7:performer">
        <assert role="error" test="not(@typeCode) or  @typeCode='PRF'"
            >@typeCode moet, indien anwezig, 'PRF' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >@contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>

    <rule context="$element/hl7:dataEnterer">
        <assert role="error" test="not(@typeCode) or  @typeCode='ENT'"
            >@typeCode moet, indien anwezig, 'ENT' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >@contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>
    <rule context="$element/hl7:dataEnterer/hl7:time">
        <extends rule="TS"/>
    </rule>
    
    <rule context="$element/hl7:referenceRange">
        <assert role="error" test="not(@typeCode) or  @typeCode='REFV'"
            >@typeCode moet, indien anwezig, 'REFV' bevatten</assert>
        <assert role="error" test="not(@contextControlCode) or  @contextControlCode='ON'"
            >@contextControlCode moet, indien anwezig, 'ON' bevatten</assert>
    </rule>
    
    <rule context="$element/hl7:referenceRange/hl7:observationRange">
        <assert role="error" test="not(@classCode) or  @classCode='OBS'"
            >@classCode moet, indien anwezig, 'OBS' bevatten</assert>
        <assert role="error" test="not(@moodCode) or  @moodCode='EVN.CRT'"
            >@moodCode moet, indien anwezig, 'EVN.CRT' bevatten</assert>
    </rule>
    
    <rule context="$element/hl7:referenceRange/hl7:observationRange/hl7:text">
        <extends rule="ST"/>
    </rule>
    
    <rule context="$element/hl7:referenceRange/hl7:observationRange/hl7:interpretationCode">
        <extends rule="CE"/>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.5.83'"
            >@codeSystem moet '2.16.840.1.113883.5.83' (InterpretationCode) bevatten</assert>
        <assert role="error" test="@displayName"
            >@displayName is verplicht</assert>
    </rule>
    
    <rule context="$element/hl7:referenceRange/hl7:observationRange/hl7:value[ends-with(@xsi:type,':IVL_PQ') or @xsi:type='IVL_PQ']">
        <extends rule="IVL_PQ"/>
        <assert role="error" test="hl7:low or hl7:high"
            >low/@value of high/@value of beide moeten een waarde bevatten</assert>
        <assert role="error" test="not(hl7:low/@unit) or index-of($ucumList,hl7:low/@unit)"
            >low/@unit moet komen uit <value-of select="$ucumList"/></assert>
        <assert role="error" test="not(hl7:high/@unit) or index-of($ucumList,hl7:high/@unit)"
            >high/@unit moet komen uit <value-of select="$ucumList"/></assert>
    </rule>
    
    <rule context="$element/hl7:referenceRange/hl7:observationRange/hl7:value">
        <extends rule="ANY"/>
        <let name="dtREFV" value="if (contains(@xsi:type,':')) then (substring-after(@xsi:type,':')) else (@xsi:type)"/>
        <assert role="error" test="$dtREFV='IVL_PQ'"
            >@xsi:type moet het datatype 'IVL_PQ' bevatten</assert>
    </rule>
</pattern>