<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Implementatiehandleiding HL7v3 Basiscomponenten, v2.2 - Datatype 1.0 II - Instance Identifier
    Status: in behandeling
-->
<rule abstract="true" id="II" see="http://hl7book.net/index.php?title=DatatypesR1:II" xmlns="http://purl.oclc.org/dsdl/schematron">
    <extends rule="ANY"/>
    
    <assert role="error" test="@nullFlavor or (not(@nullFlavor) and @root)">Datatype II: root is required if not null</assert>
    <assert role="error" test="not(@nullFlavor) or (@nullFlavor and not(@root))">Datatype II: no root if null</assert>
    <!-- Correction: see http://wiki.hl7.org/index.php?title=Deprecating_Lot_Number_Text for a use case for @nullFlavor + @extension -->
    <!--assert role="error" test="not(@nullFlavor) or (@nullFlavor and not(@extension))">Datatype II: no extension if null</assert-->
    <assert role="error" test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))">Datatype II: no identifierName if null</assert>
    <assert role="error" test="not(@nullFlavor) or (@nullFlavor and not(@displayable))">Datatype II: no displayable if null</assert>
    <assert role="error" test="not(@nullFlavor) or (@nullFlavor and not(@reliability))">Datatype II: no reliability if null</assert>

    <assert role="error" test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))">Datatype II: no assigningAuthorityName if null</assert>

    <!-- Dutch-specific checks -->
    <assert role="error" test="not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$')">Datatype II: UZI-nummer persoon moet 9 cijfers lang
        zijn</assert>

    <!-- Overwegen meer generieke code controles te gaan doen -->
    <let name="codeValue" value="../hl7:code[@codeSystem='2.16.840.1.113883.2.4.15.111']/@code"/>
    <assert role="error" test="string-length($codeValue)=0 or document('../vocab/2.16.840.1.113883.2.4.15.111.xml')/*/hl7:code[@code=$codeValue]">Datatype II: UZI
        rolcode attribuut code bevat geen geldige RoleCodeNL.</assert>

    <assert role="error" test="not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$')">Datatype II: UZI-nummer systeem moet 9 cijfers lang
        zijn</assert>

    <!-- 
        URA mag 1 zijn, indien het id van de entiteit waar de organisatie bij 
        hoort (bijvoorbeeld een AssignedDevice) het ZIM is.
    -->
    <assert role="error"
        test="not(@root='2.16.528.1.1007.3.3') or (../../hl7:id/@root='2.16.840.1.113883.2.4.6.6' and ../../hl7:id/@extension='1' and @extension='1') or
            matches(@extension,'^[0-9]{8}$')"
        >Datatype II: UZI-registerabonneenummer moet 8 cijfers lang zijn</assert>

    <!-- Overwegen meer generieke code controles te gaan doen -->
    <let name="codeValue" value="../hl7:code[@codeSystem='2.16.840.1.113883.2.4.15.1060']/@code"/>
    <assert role="error" test="string-length($codeValue)=0 or document('../vocab/2.16.840.1.113883.2.4.15.1060.xml')/*/hl7:code[@code=$codeValue]"
        >Datatype II: Organisatie rolcode attribuut code bevat geen geldige AssignedRoleType.</assert>

    <assert role="error" test="not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$')"
        >Datatype II: AGB-code moet 8 cijfers lang zijn</assert>

    <assert role="error" test="not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$')"
         >Datatype II: Burgerservicenummer moet 9 cijfers lang zijn</assert>
    <assert role="error"
        test="not(@root='2.16.840.1.113883.2.4.6.3') or (
            (   number(substring(@extension,1,1))*9 )+
            (   number(substring(@extension,2,1))*8 )+
            (   number(substring(@extension,3,1))*7 )+
            (   number(substring(@extension,4,1))*6 )+
            (   number(substring(@extension,5,1))*5 )+
            (   number(substring(@extension,6,1))*4 )+
            (   number(substring(@extension,7,1))*3 )+
            (   number(substring(@extension,8,1))*2 )+
            (   number(substring(@extension,9,1))*-1) ) mod 11=0"
        >Datatype II: Burgerservicenummer voldoet niet aan modulo 11 proef</assert>

    <let name="codeValue" value="@extension"/>
    <assert role="error" test="not(@root='2.16.840.1.113883.1.6') or document(concat('../vocab/',@root,'.xml'))/*/hl7:code[@code=$codeValue]"
        >Datatype II: @extension moet een geldige interactie-id bevatten</assert>
    
    <!-- 
        Issue 27375
        DICOM heeft een maximum van 64 tekens op een OID
        Canada hanteert 200 tekens op OID's
    -->
    <report role="warning" test="not(string-length(@root) &lt;= 128)">Datatype II: attribuut root is langer dan de maximale 128 tekens. Gaarne melden als 
        deze waarschuwing verschijnt, omdat huidige waarde dan blijkbaar te klein is</report>

    <report role="warning" test="not(string-length(@extension) &lt;= 64)">Datatype II: attribuut extension is langer dan de maximale 64 tekens. Gaarne melden als 
        deze waarschuwing verschijnt, omdat huidige waarde dan blijkbaar te klein is</report>
</rule>