<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="#all"
    version="2.0" xmlns:ns="http://www.w3.org/1999/xhtml" xmlns="urn:hl7-org:v3" xmlns:mif2="urn:hl7-org:v3/mif2">
    <xsl:output method="xml" encoding="UTF-8" indent="yes"/>

    <xsl:template match="/">
        <xsl:apply-templates select="//ns:table[1]"/>
    </xsl:template>

    <xsl:template match="ns:table">
        <xsl:variable name="codeSystemString"
            select="normalize-space(/ns:html/ns:body/ns:table[1]/ns:tbody[1]/ns:tr[1]/ns:td[1]//ns:strong[1]/following-sibling::text()[1])"/>
        <xsl:variable name="codeSystem" select="substring($codeSystemString,2,string-length($codeSystemString)-2)"/>
        <xsl:processing-instruction name="xml-stylesheet">type="text/xsl" href="../xsl/codeSystem2html.xsl"</xsl:processing-instruction>
        <xsl:processing-instruction name="oxygen">SCHSchema="vocab.sch"</xsl:processing-instruction>
        <codeSystem xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="urn:hl7-org:v3 vocab.xsd" xmlns="urn:hl7-org:v3"
            codeStrength="CWE">
            <xsl:element name="name">
                <xsl:value-of select="normalize-space(/ns:html/ns:body/ns:table[1]/ns:tbody[1]/ns:tr[1]/ns:td[1]//ns:strong[1])"/>
            </xsl:element>
            <xsl:element name="desc">
                <xsl:value-of select="ns:tbody[1]/ns:tr[1]/ns:td[1]/mif2:p[1]"/>
            </xsl:element>
            <xsl:for-each select="ns:tbody[1]/ns:tr">
                <xsl:apply-templates select="." mode="vocabTableRow">
                    <xsl:with-param name="codeSystem" select="$codeSystem"/>
                </xsl:apply-templates>
            </xsl:for-each>
        </codeSystem>
    </xsl:template>

    <xsl:template match="ns:tr" mode="vocabTableRow">
        <xsl:param name="codeSystem"/>
        <xsl:choose>
            <xsl:when test="ns:td[1]/ns:strong[1]='A'">
                <xsl:comment>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="concat(ns:td[1]/text(),ns:td[1]/ns:strong)"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="ns:td[2]/ns:strong[1]"/>
                    <xsl:text> (</xsl:text>
                    <xsl:value-of select="ns:td[2]//ns:a[@href][1]/text()"/>
                    <xsl:text>)</xsl:text>
                </xsl:comment>
            </xsl:when>
            <xsl:when test="ns:td[1]/ns:strong[1]='L'">
                <code>
                    <xsl:attribute name="code">
                        <xsl:value-of select="ns:td[2]/ns:strong[1]"/>
                    </xsl:attribute>
                    <xsl:attribute name="codeSystem">
                        <xsl:value-of select="$codeSystem"/>
                    </xsl:attribute>
                    <xsl:attribute name="displayName">
                        <xsl:value-of select="ns:td[3]"/>
                    </xsl:attribute>
                    <xsl:element name="originalText">
                        <xsl:value-of select="concat(normalize-space(ns:td[4]/ns:p[1]/ns:b),' ',normalize-space(ns:td[4]/*[2]))"/>
                    </xsl:element>
                </code>
            </xsl:when>
            <xsl:when test="ns:td[1]/ns:strong[1]='S'">
                <code>
                    <xsl:attribute name="code">
                        <xsl:value-of select="ns:td[2]/ns:strong[1]"/>
                    </xsl:attribute>
                    <xsl:attribute name="codeSystem">
                        <xsl:value-of select="$codeSystem"/>
                    </xsl:attribute>
                    <xsl:attribute name="displayName">
                        <xsl:value-of select="ns:td[3]"/>
                    </xsl:attribute>
                    <xsl:comment>
                        <xsl:text> </xsl:text>
                        <xsl:value-of select="ns:td[2]//ns:i/ns:a"/>
                        <xsl:text> </xsl:text>
                    </xsl:comment>
                    <xsl:element name="originalText">
                        <xsl:value-of select="concat(normalize-space(ns:td[4]/ns:p[1]/ns:b),' ',normalize-space(ns:td[4]/*[2]))"/>
                    </xsl:element>
                </code>
            </xsl:when>
        </xsl:choose>

    </xsl:template>
</xsl:stylesheet>
