<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <xsl:apply-templates select="/" mode="M5"/>
      <xsl:apply-templates select="/" mode="M6"/>
      <xsl:apply-templates select="/" mode="M7"/>
      <xsl:apply-templates select="/" mode="M8"/>
      <xsl:apply-templates select="/" mode="M53"/>
      <xsl:apply-templates select="/" mode="M54"/>
      <xsl:apply-templates select="/" mode="M55"/>
      <xsl:apply-templates select="/" mode="M56"/>
      <xsl:apply-templates select="/" mode="M57"/>
      <xsl:apply-templates select="/" mode="M58"/>
      <xsl:apply-templates select="/" mode="M59"/>
      <xsl:apply-templates select="/" mode="M60"/>
      <xsl:apply-templates select="/" mode="M61"/>
      <xsl:apply-templates select="/" mode="M62"/>
      <xsl:apply-templates select="/" mode="M63"/>
      <xsl:apply-templates select="/" mode="M64"/>
      <xsl:apply-templates select="/" mode="M65"/>
      <xsl:apply-templates select="/" mode="M66"/>
      <xsl:apply-templates select="/" mode="M67"/>
      <xsl:apply-templates select="/" mode="M68"/>
      <xsl:apply-templates select="/" mode="M69"/>
      <xsl:apply-templates select="/" mode="M70"/>
      <xsl:apply-templates select="/" mode="M71"/>
      <xsl:apply-templates select="/" mode="M72"/>
      <xsl:apply-templates select="/" mode="M73"/>
      <xsl:apply-templates select="/" mode="M74"/>
      <xsl:apply-templates select="/" mode="M75"/>
      <xsl:apply-templates select="/" mode="M76"/>
      <xsl:apply-templates select="/" mode="M77"/>
      <xsl:apply-templates select="/" mode="M78"/>
      <xsl:apply-templates select="/" mode="M79"/>
      <xsl:apply-templates select="/" mode="M80"/>
      <xsl:apply-templates select="/" mode="M81"/>
      <xsl:apply-templates select="/" mode="M82"/>
      <xsl:apply-templates select="/" mode="M83"/>
      <xsl:apply-templates select="/" mode="M84"/>
      <xsl:apply-templates select="/" mode="M85"/>
      <xsl:apply-templates select="/" mode="M86"/>
      <xsl:apply-templates select="/" mode="M87"/>
      <xsl:apply-templates select="/" mode="M88"/>
      <xsl:apply-templates select="/" mode="M89"/>
      <xsl:apply-templates select="/" mode="M90"/>
      <xsl:apply-templates select="/" mode="M91"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN xmlXML processing instruction and others Link to XML Schemas Elements Attributes-->


	<!--RULE -->
<xsl:template match="*[count(ancestor::*)=0][1]" priority="1007" mode="M5">
      <xsl:variable name="unparsed" select="unparsed-text(document-uri(/))"/>
      <xsl:variable name="declaration"
                    select="if (starts-with($unparsed, '&lt;?xml')) then concat(substring-before($unparsed, '?&gt;'), '?&gt;') else ''"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(starts-with($unparsed, '&lt;?xml')) or matches($declaration, 'version=.1\.0.')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-XML: The XML prolog declaration SHALL show version 1.0. (not(starts-with($unparsed, '&lt;?xml')) or matches($declaration, 'version=.1\.0.') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(starts-with($unparsed, '&lt;?xml')) or matches($declaration, 'encoding=.(utf-8)|(UTF-8).')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-XML: The XML prolog declaration SHALL show encoding "UTF-8" or
            SHALL be empty. (not(starts-with($unparsed, '&lt;?xml')) or matches($declaration, 'encoding=.(utf-8)|(UTF-8).') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="document(document-uri(/))/processing-instruction('nictiz') or not(starts-with($unparsed, '&lt;?xml')) or not(matches($declaration, 'standalone='))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-XML: The
            XML prolog declaration SHALL not show standalone. (document(document-uri(/))/processing-instruction('nictiz') or not(starts-with($unparsed, '&lt;?xml')) or not(matches($declaration, 'standalone=')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(document(document-uri(/))/processing-instruction()) = 0 or                 (count(document(document-uri(/))/processing-instruction()) = 1 and                  document(document-uri(/))/processing-instruction('xml')) or                 document(document-uri(/))/processing-instruction('nictiz')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-XML: The XML prolog declaration SHALL be the only processing instruction, e.g. no links to stylesheets are allowed. (count(document(document-uri(/))/processing-instruction()) = 0 or (count(document(document-uri(/))/processing-instruction()) = 1 and document(document-uri(/))/processing-instruction('xml')) or document(document-uri(/))/processing-instruction('nictiz') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="*[@xsi:schemaLocation]" priority="1005" mode="M5">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="document(document-uri(/))/processing-instruction('nictiz') or not(.)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-XML: No links to XML Schemas are allowed. Found '<xsl:text/>
               <xsl:value-of select="@xsi:schemaLocation"/>
               <xsl:text/>' (document(document-uri(/))/processing-instruction('nictiz') or not(.) / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="*[@xsi:noNamespaceSchemaLocation]" priority="1004" mode="M5">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="document(document-uri(/))/processing-instruction('nictiz') or not(.)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-XML: No links to XML Schemas are allowed. Found '<xsl:text/>
               <xsl:value-of select="@xsi:noNamespaceSchemaLocation"/>
               <xsl:text/>' (document(document-uri(/))/processing-instruction('nictiz') or not(.) / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="*[not(self::hl7:Place) and not(self::hl7:br) and not(self::hl7:p) and         not(self::hl7:patient and (../../../hl7:consentDirective or ../../../hl7:IntoleranceCondition or ../../../hl7:Condition)) and         not(*) and (not(@*) or (count(@*)=1 and @xsi:type)) and string-length(normalize-space(text()[1]))=0]"
                 priority="1002"
                 mode="M5">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-XML: Elements SHALL have at least one attribute, a child element or non-empty element content (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="*[@*[normalize-space()='']]" priority="1000" mode="M5">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-XML: Attributes SHALL have a value (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*" mode="M5"/>
   </xsl:template>

   <!--PATTERN QUPC_IN443132NL-wrapperTransmission Wrapper Algemeen Transmission Wrapper, geen batch MCCI_IN200101-->


	<!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:id" priority="1025" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root and @extension"/>
         <xsl:otherwise>
            <xsl:message>Transmission: id element mist root of extension (@root and @extension / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:creationTime" priority="1024" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="datatypeName" select="substring-after(string(@xsi:type),':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@xsi:type) or string(@xsi:type)='TS' or substring-after(string(@xsi:type),':')='TS'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: creationTime moet datatype TS hebben. Gevonden '<xsl:text/>
               <xsl:value-of select="$datatypeName"/>
               <xsl:text/>' (not(@xsi:type) or string(@xsi:type)='TS' or substring-after(string(@xsi:type),':')='TS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@value)&gt;13"/>
         <xsl:otherwise>
            <xsl:message>Transmission: creationTime moet minimaal op de seconde nauwkeurig zijn (string-length(@value)&gt;13 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:versionCode" priority="1023" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='NICTIZEd2005-Okt'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: versionCode '<xsl:text/>
               <xsl:value-of select="@code"/>
               <xsl:text/>' moet 'NICTIZEd2005-Okt' zijn (@code='NICTIZEd2005-Okt' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:interactionId" priority="1022" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="interactionId"
                    select="self::node()[@root='2.16.840.1.113883.1.6']/@extension"/>
      <xsl:variable name="interactionVocabFile" select="'../vocab/2.16.840.1.113883.1.6.xml'"/>
      <xsl:variable name="interactionName"
                    select="if (doc-available($interactionVocabFile)) then (document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/@displayName) else ()"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.1.6'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: @root moet '2.16.840.1.113883.1.6' zijn (@root='2.16.840.1.113883.1.6' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.1.6') or local-name(..)=@extension"/>
         <xsl:otherwise>
            <xsl:message>Transmission: @extension moet overeenkomen met het startelement van het bericht (not(@root='2.16.840.1.113883.1.6') or local-name(..)=@extension / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(contains(@extension,':'))"/>
         <xsl:otherwise>
            <xsl:message>Transmission: @extension mag geen namespace prefix bevatten (not(contains(@extension,':')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(doc-available($interactionVocabFile)) or              not(document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Actief']/@value='false')"/>
         <xsl:otherwise>
            <xsl:message>Transmission: interaction-id <xsl:text/>
               <xsl:value-of select="$interactionId"/>
               <xsl:text/> (<xsl:text/>
               <xsl:value-of select="$interactionName"/>
               <xsl:text/>) is niet (meer) Actief in <xsl:text/>
               <xsl:value-of select="$interactionVocabFile"/>
               <xsl:text/>
       (not(doc-available($interactionVocabFile)) or not(document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Actief']/@value='false') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:profileId" priority="1021" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.3.11.1' and (@extension='810')"/>
         <xsl:otherwise>
            <xsl:message>Transmission: profileId '<xsl:text/>
               <xsl:value-of select="@extension"/>
               <xsl:text/>' moet gelijk zijn aan 810.  (@root='2.16.840.1.113883.2.4.3.11.1' and (@extension='810') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(following-sibling::hl7:profileId)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: er mag maar één profileId worden gebruikt (not(following-sibling::hl7:profileId) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:acknowledgement" priority="1020" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="local-name(..)='MCCI_IN000002' or @typeCode='AA' or @typeCode='AE' or @typeCode='AR'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: applicatieantwoorden moeten acknowledgement/@typeCode AA, AE of AR hebben (local-name(..)='MCCI_IN000002' or @typeCode='AA' or @typeCode='AE' or @typeCode='AR' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="not(local-name(..)='MCCI_IN000002') or @typeCode='CA' or @typeCode='CE' or @typeCode='CR'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: ontvangstbevestigingen moeten acknowledgement/@typeCode CA, CE of CR hebben. In slechts sommige gevallen worden 
            toch inhoudelijke antwoorden toegestaan (@typeCode is 'AA', 'AE' or 'AR'). (not(local-name(..)='MCCI_IN000002') or @typeCode='CA' or @typeCode='CE' or @typeCode='CR' / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:targetMessage/hl7:id[@root and @extension] or hl7:targetTransmission/hl7:id[@root and @extension]"/>
         <xsl:otherwise>
            <xsl:message>Transmission: in antwoordinteracties moet de interactie waarop wordt geantwoord, worden geïdentificeerd in het element targetTransmission/id (hl7:targetMessage/hl7:id[@root and @extension] or hl7:targetTransmission/hl7:id[@root and @extension] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="@typeCode='AA' or @typeCode='CA' or hl7:acknowledgementDetail or ../hl7:ControlActProcess/hl7:reason or ../hl7:ControlActProcess/hl7:reasonOf"/>
         <xsl:otherwise>
            <xsl:message>Transmission: negatieve antwoordberichten moeten ook een reden hebben waarom (@typeCode='AA' or @typeCode='CA' or hl7:acknowledgementDetail or ../hl7:ControlActProcess/hl7:reason or ../hl7:ControlActProcess/hl7:reasonOf / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:acknowledgement/hl7:acknowledgementDetail"
                 priority="1019"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@typeCode) or @typeCode='E'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: acknowledgementDetail/@typeCode moet indien aanwezig E (Error) zijn. W (Warning) of I (Information) zijn niet toegestaan (not(@typeCode) or @typeCode='E' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:code"/>
         <xsl:otherwise>
            <xsl:message>Transmission: acknowledgementDetail/code moet een waarde hebben. (hl7:code / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:code[@code and @displayName] or hl7:text"/>
         <xsl:otherwise>
            <xsl:message>Transmission: er moet een toelichting op de fout/waarschuwing zijn in hl7:code/@displayName of text (hl7:code[@code and @displayName] or hl7:text / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:acknowledgement/hl7:acknowledgementDetail/hl7:code"
                 priority="1018"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nulFlavor)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: code moet een waarde hebben. (not(@nulFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: code mag geen translation bevatten. (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(@codeSystem='2.16.840.1.113883.5.1100' or @codeSystem='2.16.840.1.113883.2.4.6.6.1.1000' or @codeSystem='2.16.840.1.113883.5.4') and not(@displayName)">
         <xsl:message>Transmission: als de code niet uit een van de standaardcodesystemen '2.16.840.1.113883.5.1100', '2.16.840.1.113883.2.4.6.6.1.1000', of '2.16.840.1.113883.5.4' komt is het @displayName attribuut verplicht (not(@codeSystem='2.16.840.1.113883.5.1100' or @codeSystem='2.16.840.1.113883.2.4.6.6.1.1000' or @codeSystem='2.16.840.1.113883.5.4') and not(@displayName) / warning)</xsl:message>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:receiver" priority="1017" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@typeCode) or @typeCode='RCV'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: receiver/@typeCode moet 'RCV' zijn indien aanwezig (not(@typeCode) or @typeCode='RCV' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(../hl7:receiver)=1"/>
         <xsl:otherwise>
            <xsl:message>Transmission: receiver mag slechts éénmaal voorkomen (count(../hl7:receiver)=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:respondTo" priority="1016" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@typeCode) or @typeCode='RSP'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: respondTo/@typeCode moet 'RSP' zijn indien aanwezig (not(@typeCode) or @typeCode='RSP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(../hl7:respondTo)=1"/>
         <xsl:otherwise>
            <xsl:message>Transmission: respondTo mag slechts éénmaal voorkomen (count(../hl7:respondTo)=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:entityRsp)=1"/>
         <xsl:otherwise>
            <xsl:message>Transmission: respondTo/entityRsp mag slechts éénmaal voorkomen (count(hl7:entityRsp)=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="entityRspRoot" select="hl7:entityRsp/hl7:id/@root"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="not(hl7:entityRsp/hl7:id/@extension=../hl7:sender/hl7:device/hl7:id[@root=$entityRspRoot]/@extension)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: waarschuwing: het antwoord moet worden verstuurd aan dezelfde applicatie als de zendende applicatie. In dit geval is respondTo redundant. (not(hl7:entityRsp/hl7:id/@extension=../hl7:sender/hl7:device/hl7:id[@root=$entityRspRoot]/@extension) / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:sender" priority="1015" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@typeCode) or @typeCode='SND'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: sender/@typeCode moet 'SND' zijn indien aanwezig (not(@typeCode) or @typeCode='SND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:attentionLine" priority="1014" mode="M6">
      <xsl:variable name="interactionId"
                    select="../hl7:interactionId[@root='2.16.840.1.113883.1.6']/@extension"/>
      <xsl:variable name="interactionVocabFile" select="'../vocab/2.16.840.1.113883.1.6.xml'"/>
      <xsl:variable name="interactionName"
                    select="if (doc-available($interactionVocabFile)) then (document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/@displayName) else ()"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="not(doc-available($interactionVocabFile)) or              document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='AttentionLineMetBsn']/@value='true' or             ../hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'] or             ../hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.6']"/>
         <xsl:otherwise>
            <xsl:message>Transmission: interaction-id <xsl:text/>
               <xsl:value-of select="$interactionId"/>
               <xsl:text/> (<xsl:text/>
               <xsl:value-of select="$interactionName"/>
               <xsl:text/>) is niet geconfigureerd voor gebruik van het element <xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> in <xsl:text/>
               <xsl:value-of select="$interactionVocabFile"/>
               <xsl:text/> en afzender is niet GBK of GBP (not(doc-available($interactionVocabFile)) or document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='AttentionLineMetBsn']/@value='true' or ../hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'] or ../hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.6'] / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:id | hl7:respondTo/hl7:entityRsp/hl7:id"
                 priority="1013"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.6' and @extension"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(../..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/id/@root moet 2.16.840.1.113883.2.4.6.6 zijn (@root='2.16.840.1.113883.2.4.6.6' and @extension / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:desc"
                 priority="1012"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/device/descr mag niet gebruikt worden. (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:existenceTime"
                 priority="1011"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/device/existenceTime mag niet gebruikt worden. (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:manufacturerModelName"
                 priority="1010"
                 mode="M6">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/device/manufacturerModelName niet gebruiken. (not(.) / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:agencyFor"
                 priority="1009"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@classCode) or @classCode='AGNT'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(../..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/agencyFor/@classCode moet, indien aanwezig de waarde "AGNT" bevatten (not(@classCode) or @classCode='AGNT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:agencyFor/hl7:representedOrganization"
                 priority="1008"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@classCode) or @classCode='ORG'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(../../..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name(../..)"/>
               <xsl:text/>/agencyFor/representedOrganization/@classCode moet, indien aanwezig de waarde "ORG" bevatten (not(@classCode) or @classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@determinerCode) or @determinerCode='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(../../..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name(../..)"/>
               <xsl:text/>/agencyFor/representedOrganization/@determinerCode moet, indien aanwezig de waarde "INSTANCE" bevatten (not(@determinerCode) or @determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)=1"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(../../..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name(../..)"/>
               <xsl:text/>/agencyFor/representedOrganization/id mag maar één maal voorkomen (count(hl7:id)=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:agencyFor/hl7:representedOrganization/hl7:id"
                 priority="1007"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@root='2.16.528.1.1007.3.3' and @extension) or (@root='2.16.840.1.113883.2.4.3.11' and @extension='7')"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(../../../..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name(../../..)"/>
               <xsl:text/>/agencyFor/representedOrganization/id moet een UZI-registerabonneenummer zijn of het Klantenloket ((@root='2.16.528.1.1007.3.3' and @extension) or (@root='2.16.840.1.113883.2.4.3.11' and @extension='7') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:agencyFor/hl7:representedOrganization/hl7:name"
                 priority="1006"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:agencyFor/hl7:representedOrganization/hl7:telecom"
                 priority="1005"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:*[local-name()='receiver' or local-name()='sender']/hl7:device/hl7:location"
                 priority="1004"
                 mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Transmission: <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/device/location mag niet gebruikt worden. (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:processingCode" priority="1002" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="@code='P' or document(document-uri(/))/processing-instruction('nictiz')"/>
         <xsl:otherwise>
            <xsl:message>Transmission: processingCode moet in productie altijd gelijk zijn aan P (productie). D (debug) en T (training) zijn dan niet toegestaan (@code='P' or document(document-uri(/))/processing-instruction('nictiz') / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='P' or @code='T' or @code='D'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: processingCode moet de waarde P (productie). D (debug) of T (training) bevatten (@code='P' or @code='T' or @code='D' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:processingModeCode" priority="1001" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='T'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: processingModeCode moet gelijk zijn aan T (Current processing). A (Archive), I (Initial load), en R (Restore from archive) zijn niet toegestaan (@code='T' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:acceptAckCode" priority="1000" mode="M6">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='NE' or @code='AL'"/>
         <xsl:otherwise>
            <xsl:message>Transmission: acceptAckCode moet gelijk zijn aan NE (never) of AL (always) (@code='NE' or @code='AL' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*" mode="M6"/>
   </xsl:template>

   <!--PATTERN QUPC_IN443132NL-controlActControlActProcess ControlActProcess/reason en ControlActProcess/reasonOf ControlActProcess/registrationProcess ControlActProcess/registrationProcess/id ControlActProcess/registrationProcess/code ControlActProcess/registrationProcess/statusCode ControlActProcess/registrationProcess/effectiveTime ControlActProcess/queryByParameter ControlActProcess/queryAck ControlActProcess/informationRecipient ControlActProcess/dataEnterer ControlActProcess/authorOrPerformer ControlActProcess/authorOrPerformer/AssignedPerson ControlActProcess/authorOrPerformer/participant/AssignedPerson/id ControlActProcess/authorOrPerformer/AssignedDevice ControlActProcess/authorOrPerformer/participant/AssignedDevice/id ControlActProcess/overseer ControlActProcess/overseer/AssignedPerson en ControlActProcess/overseer/assignedEntity-->


	<!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess" priority="1086" mode="M7">
      <xsl:variable name="interactionId" select="local-name(..)"/>
      <xsl:variable name="interactionVocab" select="'../vocab/2.16.840.1.113883.1.6.xml'"/>
      <xsl:variable name="interactionTrustLevel"
                    select="document($interactionVocab)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Vertrouwensniveau']/@value"/>
      <xsl:variable name="interactionSendType"
                    select="document($interactionVocab)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Verzendtype']/@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:overseer or not($interactionTrustLevel) or $interactionTrustLevel='Laag'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: ControlActProcess/overseer moet de mandaterende persoon bevatten in berichten met vertrouwensniveau midden of hoog (hl7:overseer or not($interactionTrustLevel) or $interactionTrustLevel='Laag' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:queryByParameter) or @moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: ControlActProcess moodCode moet EVN zijn bij queries (not(hl7:queryByParameter) or @moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:id" priority="1085"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:code" priority="1084"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem='2.16.840.1.113883.1.18'"/>
         <xsl:otherwise>
            <xsl:message>ControlActProcess/code moet uit codeSystem '2.16.840.1.113883.1.18' komen (@codeSystem='2.16.840.1.113883.1.18' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="codeValue" select="@code"/>
      <xsl:variable name="interactionId" select="../../hl7:interactionId/@extension"/>
      <xsl:variable name="vocabFile"
                    select="concat('../vocab/',../../hl7:interactionId/@root,'.xml')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="document($vocabFile)/*/hl7:code[@code=$interactionId]/hl7:reference[@extension=$codeValue]"/>
         <xsl:otherwise>
            <xsl:message>Control Act: ControlActProcess/code (Trigger Event) moet bij deze interactie 
            '<xsl:text/>
               <xsl:value-of select="document($vocabFile)/*/hl7:code[@code=$interactionId]/hl7:reference/@extension"/>
               <xsl:text/>'
            zijn, gevonden is echter '<xsl:text/>
               <xsl:value-of select="$codeValue"/>
               <xsl:text/>' (document($vocabFile)/*/hl7:code[@code=$interactionId]/hl7:reference[@extension=$codeValue] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:text" priority="1083"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:effectiveTime"
                 priority="1082"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@xsi:type='TS' or substring-after(@xsi:type,':')='TS' or (not(@xsi:type) and @value)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: ControlActProcess/effectiveTime moet datatype TS hebben (@xsi:type='TS' or substring-after(@xsi:type,':')='TS' or (not(@xsi:type) and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:reasonCode"
                 priority="1081"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:languageCode"
                 priority="1080"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/*[self::hl7:reasonOf or self::hl7:reason]/*[self::hl7:justifiedDetectedIssue or self::hl7:justifyingDetectedIssueEvent]"
                 priority="1078"
                 mode="M7">

		<!--REPORT warning-->
<xsl:if test="not(hl7:code[@code and @displayName] or hl7:text or hl7:value)">
         <xsl:message>Control Act: Bij voorkeur moet code/@displayName, text of value een uitgebreidere toelichting op de fout/waarschuwing hebben (not(hl7:code[@code and @displayName] or hl7:text or hl7:value) / warning)</xsl:message>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/*[self::hl7:reasonOf or self::hl7:reason]/*[self::hl7:justifiedDetectedIssue or self::hl7:justifyingDetectedIssueEvent]/hl7:code[not(@xsi:type or @xsi:type='CD')]"
                 priority="1077"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>code mag geen translation bevatten (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(@codeSystem='2.16.840.1.113883.5.4') and not(@displayName) and not(following-sibling::hl7:value or following-sibling::hl7:text)">
         <xsl:message>Control Act: Als de code niet uit het standaard codesysteem '2.16.840.1.113883.5.4' komt is het @displayName attribuut verplicht, of er moet een value/text element zijn met aanvullende informatie (not(@codeSystem='2.16.840.1.113883.5.4') and not(@displayName) and not(following-sibling::hl7:value or following-sibling::hl7:text) / warning)</xsl:message>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/*[self::hl7:reasonOf or self::hl7:reason]/*[self::hl7:justifiedDetectedIssue or self::hl7:justifyingDetectedIssueEvent]/hl7:value[@xsi:type='CE']"
                 priority="1076"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/*[self::hl7:reasonOf or self::hl7:reason]/*[self::hl7:justifiedDetectedIssue or self::hl7:justifyingDetectedIssueEvent]/hl7:targetOf"
                 priority="1075"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:code[@code and @codeSystem]"/>
         <xsl:otherwise>
            <xsl:message>Control Act: Als IssueManagement aanwezig is dan is de justifiedDetectedIssue/code verplicht (../hl7:code[@code and @codeSystem] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:subject/hl7:registrationProcess"
                 priority="1073"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@classCode) or @classCode='REG'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/@classCode moet indien aanwezig 'REG' zijn (not(@classCode) or @classCode='REG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:subject/hl7:registrationProcess/hl7:id"
                 priority="1071"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="sendingApplicationIdRoot"
                    select="../../../../hl7:sender/hl7:device/hl7:id/@root"/>
      <xsl:variable name="sendingApplicationIdExt"
                    select="../../../../hl7:sender/hl7:device/hl7:id/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="($sendingApplicationIdRoot='2.16.840.1.113883.2.4.6.6' and $sendingApplicationIdExt='1') or @nullFlavor='UNK'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/id/@nullFlavor moet 'UNK' zijn als de afzender niet de ZIM is (($sendingApplicationIdRoot='2.16.840.1.113883.2.4.6.6' and $sendingApplicationIdExt='1') or @nullFlavor='UNK' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($sendingApplicationIdRoot='2.16.840.1.113883.2.4.6.6' and $sendingApplicationIdExt='1') or @root"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/id/@nullFlavor moet 'UNK' zijn als de afzender niet de ZIM is (not($sendingApplicationIdRoot='2.16.840.1.113883.2.4.6.6' and $sendingApplicationIdExt='1') or @root / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:subject/hl7:registrationProcess/hl7:code"
                 priority="1069"
                 mode="M7">
      <xsl:variable name="codeValue" select="@code"/>
      <xsl:variable name="codeSystem" select="@codeSystem"/>
      <xsl:variable name="displayName"
                    select="document(concat('../vocab/',$codeSystem,'.xml'))/*/hl7:code[@code=$codeValue]/@displayName"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$codeSystem='2.16.840.1.113883.2.4.15.4' or $codeSystem='2.16.840.1.113883.6.1'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/code moet uit ActRegistrycodeNL (2.16.840.1.113883.2.4.15.4) of LOINC (2.16.840.1.113883.6.1) komen. ($codeSystem='2.16.840.1.113883.2.4.15.4' or $codeSystem='2.16.840.1.113883.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="document(concat('../vocab/',$codeSystem,'.xml'))/*/hl7:code[@code=$codeValue]"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/code '<xsl:text/>
               <xsl:value-of select="$codeValue"/>
               <xsl:text/>' is niet geldig binnen codeSystem '<xsl:text/>
               <xsl:value-of select="$codeSystem"/>
               <xsl:text/>' (ActRegistryCodeNL of LOINC). (document(concat('../vocab/',$codeSystem,'.xml'))/*/hl7:code[@code=$codeValue] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="if ($codeValue='117117' or $codeValue='118118' or $codeValue='118400' or $codeValue='603508' or $codeValue='302850') then (                 ../hl7:subject1) else (../hl7:subject2)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/code '<xsl:text/>
               <xsl:value-of select="$codeValue"/>
               <xsl:text/>' (<xsl:text/>
               <xsl:value-of select="$displayName"/>
               <xsl:text/>) komt niet overeen met het gebruikte type register. Rollen
            horen in subject1 en Act's in subject2. (if ($codeValue='117117' or $codeValue='118118' or $codeValue='118400' or $codeValue='603508' or $codeValue='302850') then ( ../hl7:subject1) else (../hl7:subject2) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:subject/hl7:registrationProcess/hl7:statusCode"
                 priority="1067"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:subject/hl7:registrationProcess/hl7:effectiveTime"
                 priority="1065"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or @nullFlavor='UNK'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/effectiveTime/@nullFlavor moet, indien aanwezig, 'UNK' zijn. (not(@nullFlavor) or @nullFlavor='UNK' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*/@nullFlavor) or hl7:*/@nullFlavor='UNK'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/effectiveTime/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/>/@nullFlavor moet, indien aanwezig, 'UNK' zijn. (not(hl7:*/@nullFlavor) or hl7:*/@nullFlavor='UNK' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or hl7:*[local-name()='low' or local-name()='high']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: registrationProcess/effectiveTime mag alleen bestaan uit datum eerste aanmelding (effectiveTime/low) en een einde van de geldigheidsperiode (effectiveTime/high). (@nullFlavor or hl7:*[local-name()='low' or local-name()='high'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter"
                 priority="1063"
                 mode="M7">
      <xsl:variable name="interactionId" select="local-name(../..)"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="hl7:executionAndDeliveryTime or             $interactionId='PRPA_IN900111NL' or              $interactionId='PRPA_IN900112NL' or             $interactionId='QUMT_IN020010' or             $interactionId='QUMT_IN020011NL' or             $interactionId='QUMT_IN020011NL02' or             $interactionId='QUMT_IN900008NL' or             $interactionId='QUMT_IN900013NL' or             $interactionId='QUPA_IN101101' or              $interactionId='QUPA_IN101102' or             $interactionId='QUPA_IN101103' or              $interactionId='QUPA_IN101104'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: Waarschuwing: queryByParameter/executionAndDeliveryTime is verplicht vanaf AORTA 6 indien hier een waarde voor is ingesteld in het XIS. (hl7:executionAndDeliveryTime or $interactionId='PRPA_IN900111NL' or $interactionId='PRPA_IN900112NL' or $interactionId='QUMT_IN020010' or $interactionId='QUMT_IN020011NL' or $interactionId='QUMT_IN020011NL02' or $interactionId='QUMT_IN900008NL' or $interactionId='QUMT_IN900013NL' or $interactionId='QUPA_IN101101' or $interactionId='QUPA_IN101102' or $interactionId='QUPA_IN101103' or $interactionId='QUPA_IN101104' / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:responsePriorityCode or $interactionId='PRPA_IN900111NL' or $interactionId='PRPA_IN900112NL'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/responsePriorityCode is verplicht vanaf AORTA 6 (hl7:responsePriorityCode or $interactionId='PRPA_IN900111NL' or $interactionId='PRPA_IN900112NL' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:responseModalityCode or $interactionId='PRPA_IN900111NL' or $interactionId='PRPA_IN900112NL'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: responseModalityCode is verplicht vanaf AORTA 6 (hl7:responseModalityCode or $interactionId='PRPA_IN900111NL' or $interactionId='PRPA_IN900112NL' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:statusCode"
                 priority="1062"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="interactionId" select="local-name(../../..)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='executing' or @code='aborted' or @code='waitContinuedQueryResponse'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/statusCode moet 'executing', 'aborted', of 'waitContinuedQueryResponse' zijn (@code='executing' or @code='aborted' or @code='waitContinuedQueryResponse' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='executing' or             $interactionId='QUQI_IN000003' or             $interactionId='QUQI_IN000003UV'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/statusCode moet 'executing' zijn, behalve bij QUQI_IN000003(UV) (@code='executing' or $interactionId='QUQI_IN000003' or $interactionId='QUQI_IN000003UV' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='aborted' or @code='waitContinuedQueryResponse' or not(              $interactionId='QUQI_IN000003' or             $interactionId='QUQI_IN000003UV')"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/statusCode moet 'aborted' of 'waitContinuedQueryResponse' zijn bij QUQI_IN000003(UV) (@code='aborted' or @code='waitContinuedQueryResponse' or not( $interactionId='QUQI_IN000003' or $interactionId='QUQI_IN000003UV') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:modifyCode"
                 priority="1061"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='M' or @code='N'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/modifyCode moet 'M' (Modified) of 'N' (New) zijn (@code='M' or @code='N' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:responseElementGroupId"
                 priority="1060"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/responseElementGroupId mag niet gebruikt worden (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:responseModalityCode"
                 priority="1059"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='R' or @code='B'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/responseModalityCode moet 'R' (Realtime) of 'B' (Batch) zijn (@code='R' or @code='B' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="interactionId" select="local-name(../../..)"/>
      <xsl:variable name="interactionVocab" select="'../vocab/2.16.840.1.113883.1.6.xml'"/>
      <xsl:variable name="interactionSendType"
                    select="document($interactionVocab)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Verzendtype']/@value"/>
      <xsl:variable name="interactionQueryType"
                    select="document($interactionVocab)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Vraagtype']/@value"/>
      <xsl:variable name="receivingApplication"
                    select="../../../hl7:receiver/hl7:device/hl7:id[@root='2.16.840.1.113883.2.4.6.6']/@extension"/>
      <xsl:variable name="sendingApplication"
                    select="../../../hl7:sender/hl7:device/hl7:id[@root='2.16.840.1.113883.2.4.6.6']/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@code='R') or not($interactionSendType='Initiërend') or $interactionQueryType='Direct' or $sendingApplication='1'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/responseModalityCode/@code moet 'B' zijn bij indirecte vragen aan de ZIM (not(@code='R') or not($interactionSendType='Initiërend') or $interactionQueryType='Direct' or $sendingApplication='1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@code='B') or ($interactionQueryType='Indirect' and not($sendingApplication='1'))"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/responseModalityCode/@code moet 'R' zijn bij directe vragen en bij vragen verstuurd door de ZIM (in feite ook een directe vraag) (not(@code='B') or ($interactionQueryType='Indirect' and not($sendingApplication='1')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:responsePriorityCode"
                 priority="1058"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='I'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/responsePriorityCode moet 'I' (Immediate) zijn (@code='I' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:initialQuantity"
                 priority="1057"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/initialQuantity mag niet gebruikt worden (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:initialQuantityCode"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/initialQuantityCode is verplicht indien initialQuantity wordt gebruikt (../hl7:initialQuantityCode / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:initialQuantityCode"
                 priority="1056"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:initialQuantity"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/initialQuantity is verplicht indien initialQuantityCode wordt gebruikt (../hl7:initialQuantity / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:executionAndDeliveryTime"
                 priority="1055"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(../../../hl7:profileId[@root='2.16.840.1.113883.2.4.3.11.1' and (@extension='608' or @extension='705' or @extension='805')])"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/executionAndDeliveryTime is pas toegestaan vanaf profileId 810 (not(../../../hl7:profileId[@root='2.16.840.1.113883.2.4.3.11.1' and (@extension='608' or @extension='705' or @extension='805')]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/executionAndDeliveryTime/@value moet een waarde hebben (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@value,'^[0-9]{12}')"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/executionAndDeliveryTime/@value moet tenminste tot op de minuten nauwkeurig zijn (matches(@value,'^[0-9]{12}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="creationTime" select="../../../hl7:creationTime/@value"/>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@value)=string-length($creationTime))">
         <xsl:message>Control Act: queryByParameter/executionAndDeliveryTime/@value '<xsl:text/>
            <xsl:value-of select="@value"/>
            <xsl:text/>' en creationTime '<xsl:text/>
            <xsl:value-of select="$creationTime"/>
            <xsl:text/>' hebben niet dezelfde precisie. Aanbevolen is om ze dezelfde precisie te geven (not(string-length(@value)=string-length($creationTime)) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="if ((string-length(@value)=14 and string-length($creationTime)=14) or             (string-length(@value)=12 and string-length($creationTime)=12)) then (             (number(@value) - number($creationTime)) &gt;= 5) else ( 1=1 )"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/executionAndDeliveryTime/@value '<xsl:text/>
               <xsl:value-of select="@value"/>
               <xsl:text/>' ligt niet 5 seconden of meer na creationTime '<xsl:text/>
               <xsl:value-of select="$creationTime"/>
               <xsl:text/>' (if ((string-length(@value)=14 and string-length($creationTime)=14) or (string-length(@value)=12 and string-length($creationTime)=12)) then ( (number(@value) - number($creationTime)) &gt;= 5) else ( 1=1 ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter//hl7:semanticsText"
                 priority="1054"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>Control Act: het queryParameter element semanticsText bij voorkeur niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryByParameter/hl7:sortControl"
                 priority="1053"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryByParameter/sortControl mag niet gebruikt worden (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck" priority="1051"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:resultTotalQuantity"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultTotalQuantity ontbreekt (hl7:resultTotalQuantity / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:resultCurrentQuantity"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultCurrentQuantity ontbreekt (hl7:resultCurrentQuantity / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:resultRemainingQuantity"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultRemainingQuantity ontbreekt (hl7:resultRemainingQuantity / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck/hl7:id"
                 priority="1050"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root and @extension"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/queryId mist root en/of extension (@root and @extension / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck/hl7:statusCode"
                 priority="1049"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="interactionId" select="local-name(../../..)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='aborted' or @code='deliveredResponse'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/statusCode moet 'aborted', of 'deliveredResponse' zijn (@code='aborted' or @code='deliveredResponse' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck/hl7:queryResponseCode"
                 priority="1048"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code='NF' or @code='AE' or @code='QE' or @code='OK'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/queryResponsecode/code moet NF (Nothing found), AE (Application Error), QE (Query error) of OK bevatten (@code='NF' or @code='AE' or @code='QE' or @code='OK' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="acknowledgementTypeCode" select="../../../hl7:acknowledgement/@typeCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="if ($acknowledgementTypeCode='AA') then (             @code='NF' or @code='OK' ) else (             @code='AE' or @code='QE'             )"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/queryResponseCode moet bij een positief antwoord 'OK' of 'NF' zijn, anders moet deze 'AE' of 'QE' zijn (if ($acknowledgementTypeCode='AA') then ( @code='NF' or @code='OK' ) else ( @code='AE' or @code='QE' ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="resultCurrentQuantity" select="../hl7:resultCurrentQuantity/@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@code='OK') or ($acknowledgementTypeCode='AA' and $resultCurrentQuantity &gt; 0)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/queryResponseCode moet 'OK' bevatten indien er op basis van de queryParameters resultaten gevonden konden 
            worden (resultCurrentQuantity/@value='<xsl:text/>
               <xsl:value-of select="$resultCurrentQuantity"/>
               <xsl:text/>') en de query valide
            is (acknowledgement/@typeCode='<xsl:text/>
               <xsl:value-of select="$acknowledgementTypeCode"/>
               <xsl:text/>') (not(@code='OK') or ($acknowledgementTypeCode='AA' and $resultCurrentQuantity &gt; 0) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@code='NF') or ($acknowledgementTypeCode='AA' and $resultCurrentQuantity = 0)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/queryResponseCode moet 'NF' bevatten indien er op basis van de queryParameters geen resultaten gevonden konden 
            worden (resultCurrentQuantity/@value='<xsl:text/>
               <xsl:value-of select="$resultCurrentQuantity"/>
               <xsl:text/>') en de query valide
            is (acknowledgement/@typeCode='<xsl:text/>
               <xsl:value-of select="$acknowledgementTypeCode"/>
               <xsl:text/>') (not(@code='NF') or ($acknowledgementTypeCode='AA' and $resultCurrentQuantity = 0) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck/hl7:resultTotalQuantity"
                 priority="1047"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="number(@value) &gt;= 0 or @nullFlavor='NAV'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultTotalQuantity moet 0 of groter zijn, of nullFlavor moet 'NAV' zijn (number(@value) &gt;= 0 or @nullFlavor='NAV' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="resultCurrentQuantity"
                    select="number(../hl7:resultCurrentQuantity/@value)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="if (@value and $resultCurrentQuantity) then (number(@value) &gt;= $resultCurrentQuantity) else (1=1)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultTotalQuantity '<xsl:text/>
               <xsl:value-of select="@value"/>
               <xsl:text/>' moet groter zijn dan resultCurrentQuantity '<xsl:text/>
               <xsl:value-of select="$resultCurrentQuantity"/>
               <xsl:text/>' (if (@value and $resultCurrentQuantity) then (number(@value) &gt;= $resultCurrentQuantity) else (1=1) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck/hl7:resultCurrentQuantity"
                 priority="1046"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) and @value"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultCurrentQuantity moet 0 of groter zijn (not(@nullFlavor) and @value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="resultCurrentQuantity" select="count(../../hl7:subject)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=$resultCurrentQuantity"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultCurrentQuantity '<xsl:text/>
               <xsl:value-of select="@value"/>
               <xsl:text/>' moet gelijk zijn aan het aantal subject elementen ('<xsl:text/>
               <xsl:value-of select="$resultCurrentQuantity"/>
               <xsl:text/>') (@value=$resultCurrentQuantity / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:queryAck/hl7:resultRemainingQuantity"
                 priority="1045"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NAV' or @value &gt;= 0"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultRemainingQuantity moet 0 of groter zijn, of nullFlavor moet 'NAV' zijn (@nullFlavor='NAV' or @value &gt;= 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="resultTotalQuantity" select="number(../hl7:resultTotalQuantity/@value)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="if (@value and $resultTotalQuantity) then (number(@value) &lt;= $resultTotalQuantity) else (1=1)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: queryAck/resultRemainingQuantity '<xsl:text/>
               <xsl:value-of select="@value"/>
               <xsl:text/>' moet kleiner dan of gelijk aan resultTotalQuantity '<xsl:text/>
               <xsl:value-of select="$resultTotalQuantity"/>
               <xsl:text/>' zijn (if (@value and $resultTotalQuantity) then (number(@value) &lt;= $resultTotalQuantity) else (1=1) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:informationRecipient"
                 priority="1043"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: informationRecipient mag (nog) niet gebruikt worden (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:dataEnterer"
                 priority="1041"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: dataEnterer mag (nog) niet gebruikt worden (not(.) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer"
                 priority="1039"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT' or @typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/@typeCode moet AUT or PRF zijn (@typeCode='AUT' or @typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson"
                 priority="1037"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3' or @root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1'])&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/id. Tenminste één id moet als root 2.16.528.1.1007.3.1 (UZI), 2.16.840.1.113883.2.4.6.3 (BSN) of 2.16.840.1.113883.2.4.3.11.7.3 (batch inzage auteur), of 2.16.528.1.1003.1.3.5.4.1 (Nictiz-klantenloket met PKIO-pas van Getronics) hebben (count(hl7:id[@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3' or @root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1'])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:code[@codeSystem='2.16.840.1.113883.2.4.15.111']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/code ontbreekt. Dit is alleen toegestaan als de rolcode 00.000 is. (Pas voor medewerker niet op naam) (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:code[@codeSystem='2.16.840.1.113883.2.4.15.111'] / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3' and @extension]"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/Organization/id moet de zorgaanbieder van de persoon identificeren (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3' and @extension] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.840.1.113883.2.4.6.3']) or hl7:Organization/hl7:id[@nullFlavor='NA']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/Organization/id/@nullFlavor moet 'NA' bevatten (not(hl7:id[@root='2.16.840.1.113883.2.4.6.3']) or hl7:Organization/hl7:id[@nullFlavor='NA'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.840.1.113883.2.4.3.11' or @root='2.16.528.1.1003.1.3.5.4.1']) or hl7:Organization/hl7:id[@root='2.16.840.1.113883.2.4.3.11' and @extension='7']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/Organization/id moet de Nictiz-klantenloket organisatie identificeren (not(hl7:id[@root='2.16.840.1.113883.2.4.3.11' or @root='2.16.528.1.1003.1.3.5.4.1']) or hl7:Organization/hl7:id[@root='2.16.840.1.113883.2.4.3.11' and @extension='7'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:name"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/Organization/name moet de zorgaanbiedernaam bevatten (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:name / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.840.1.113883.2.4.3.11' or @root='2.16.528.1.1003.1.3.5.4.1']) or hl7:Organization/hl7:name"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/Organization/name moet de Nictiz-klantenloket organisatienaam bevatten (not(hl7:id[@root='2.16.840.1.113883.2.4.3.11' or @root='2.16.528.1.1003.1.3.5.4.1']) or hl7:Organization/hl7:name / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:id"
                 priority="1035"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.1' or @root='2.16.528.1.1007.3.2'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.UZI: UZI-nummer @root MOET 2.16.528.1.1007.3.1 (Personen) of 2.16.528.1.1007.3.2 (Systemen) zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.1' or @root='2.16.528.1.1007.3.2' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.UZI: UZI-nummer persoon MOET 9 cijfers lang zijn (not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-II.NL.UZI: UZI-nummer systeem MOET 9 cijfers lang zijn (not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3' or @root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1' or @root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/id. @root moet 2.16.528.1.1007.3.1 (UZI), 2.16.840.1.113883.2.4.6.3 (BSN) of 2.16.840.1.113883.2.4.3.11.7.3 (batch inzage auteur), 2.16.528.1.1003.1.3.5.4.1 (Nictiz-klantenloket met PKIO-pas van Getronics), of 2.16.840.1.113883.2.4.6.1 (AGB-code) zijn (@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3' or @root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1' or @root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'][@code='P']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/code/@code moet "P" (Patiënt) zijn. Wettelijke vertegenwoordigers moet dit via het Klantenloket doen en kunnen dus niet als auteur optreden (not(@root='2.16.840.1.113883.2.4.6.3') or following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'][@code='P'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or              not(../../../../*[local-name()='queryByParameter' or local-name()='subject']//hl7:*[@root='2.16.840.1.113883.2.4.6.3']) or              ../../../../../hl7:attentionLine"/>
         <xsl:otherwise>
            <xsl:message>Control Act: patiëntgebonden interacties, verzonden vanuit een patiëntenportaal (GBP), moeten een attentionLine hebben (not(@root='2.16.840.1.113883.2.4.6.3') or not(../../../../*[local-name()='queryByParameter' or local-name()='subject']//hl7:*[@root='2.16.840.1.113883.2.4.6.3']) or ../../../../../hl7:attentionLine / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1') or following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'][@code='KLANTENLOKET']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedPerson/code/@code moet "KLANTENLOKET" zijn voor klantenloketmedewerkers (not(@root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1') or following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'][@code='KLANTENLOKET'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1') or              not(../../../../*[local-name()='queryByParameter' or local-name()='subject']//hl7:*[@root='2.16.840.1.113883.2.4.6.3']) or              ../../../../../hl7:attentionLine"/>
         <xsl:otherwise>
            <xsl:message>Control Act: patiëntgebonden interacties, verzonden vanuit het klantenloket (GBK), moeten een attentionLine hebben (not(@root='2.16.840.1.113883.2.4.3.11.7.3' or @root='2.16.528.1.1003.1.3.5.4.1') or not(../../../../*[local-name()='queryByParameter' or local-name()='subject']//hl7:*[@root='2.16.840.1.113883.2.4.6.3']) or ../../../../../hl7:attentionLine / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code"
                 priority="1034"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:telecom"
                 priority="1033"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:name"
                 priority="1032"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:noteText"
                 priority="1031"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:time"
                 priority="1030"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:modeCode"
                 priority="1029"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:signatureCode"
                 priority="1028"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:signatureText"
                 priority="1027"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id"
                 priority="1026"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.URA: UZI-registerabonneenummer @root MOET 2.16.528.1.1007.3.3 zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.URA: UZI-registerabonneenummer MOET 8 cijfers lang zijn (not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:code"
                 priority="1025"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:telecom"
                 priority="1024"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:name"
                 priority="1023"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:addr"
                 priority="1022"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice"
                 priority="1020"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.2' or @root='2.16.840.1.113883.2.4.6.6' or @root='2.16.528.1.1007.4'])&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedDevice/id. Tenminste één id moet als root 2.16.528.1.1007.3.2 (UZI-systemen), 2.16.840.1.113883.2.4.6.6 (Applicatie-id) of 2.16.528.1.1007.4 (SBV-Z) hebben (count(hl7:id[@root='2.16.528.1.1007.3.2' or @root='2.16.840.1.113883.2.4.6.6' or @root='2.16.528.1.1007.4'])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3']) or hl7:id[@root='2.16.528.1.1007.3.2']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedDevice/id moet tenminste het UZI-nummer systemen bevatten voor een XIS in een GBZ (not(hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3']) or hl7:id[@root='2.16.528.1.1007.3.2'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.2']) or hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3' and @extension]"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedDevice/Organization/id moet de zorgaanbieder van het XIS identificeren (not(hl7:id[@root='2.16.528.1.1007.3.2']) or hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3' and @extension] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice/hl7:id"
                 priority="1018"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="autIdExt" select="@extension"/>
      <xsl:variable name="sendIdExt"
                    select="../../../../../hl7:sender/hl7:device/hl7:id[@root='2.16.840.1.113883.2.4.6.6']/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.2' or @root='2.16.840.1.113883.2.4.6.6' or @root='2.16.528.1.1007.4'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedDevice/id. @root 2.16.528.1.1007.3.2 (UZI-systemen), 2.16.840.1.113883.2.4.6.6 (Applicatie-id) of 2.16.528.1.1007.4 (SBV-Z) zijn (@root='2.16.528.1.1007.3.2' or @root='2.16.840.1.113883.2.4.6.6' or @root='2.16.528.1.1007.4' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$sendIdExt=$autIdExt or not(@root='2.16.840.1.113883.2.4.6.6') or empty($sendIdExt) or $sendIdExt='1'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedDevice/id. Applicatie-id <xsl:text/>
               <xsl:value-of select="$autIdExt"/>
               <xsl:text/> komt niet overeen met Transmission-wrapper sender <xsl:text/>
               <xsl:value-of select="$sendIdExt"/>
               <xsl:text/>. ($sendIdExt=$autIdExt or not(@root='2.16.840.1.113883.2.4.6.6') or empty($sendIdExt) or $sendIdExt='1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.6' and @extension='1' and following-sibling::hl7:Organization)"/>
         <xsl:otherwise>
            <xsl:message>Control Act: authorOrPerformer/*/AssignedDevice/id. De verantwoordelijke organisatie voor de ZIM moet niet worden meegegeven (not(@root='2.16.840.1.113883.2.4.6.6' and @extension='1' and following-sibling::hl7:Organization) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer" priority="1016"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RESP'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/@typeCode moet RESP zijn (@typeCode='RESP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer/hl7:noteText"
                 priority="1015"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer/hl7:time"
                 priority="1014"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer/hl7:modeCode"
                 priority="1013"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer/hl7:signatureCode"
                 priority="1012"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer/hl7:signatureText"
                 priority="1011"
                 mode="M7">

		<!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="false()"/>
         <xsl:otherwise>
            <xsl:message>
               <xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/<xsl:text/>
               <xsl:value-of select="local-name()"/>
               <xsl:text/> niet gebruiken (false() / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']"
                 priority="1009"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:id[@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/id. Tenminste één id moet als root 2.16.528.1.1007.3.1 (UZI), 2.16.840.1.113883.2.4.6.3 (BSN) hebben (hl7:id[@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:code"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/code is verplicht (hl7:code / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:assignedPrincipalChoiceList/hl7:assignedPerson/hl7:name"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/name is verplicht (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:assignedPrincipalChoiceList/hl7:assignedPerson/hl7:name / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3' and @extension]"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/Organization/id moet de zorgaanbieder van de persoon identificeren (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:id[@root='2.16.528.1.1007.3.3' and @extension] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.840.1.113883.2.4.6.3']) or hl7:Organization/hl7:id[@nullFlavor='NA']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/Organization/id/@nullFlavor moet 'NA' bevatten (not(hl7:id[@root='2.16.840.1.113883.2.4.6.3']) or hl7:Organization/hl7:id[@nullFlavor='NA'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:name"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/Organization/name moet de zorgaanbiedernaam bevatten (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:name / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:addr/hl7:city"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer/*/<xsl:text/>
               <xsl:value-of select="local-name(.)"/>
               <xsl:text/>/Organization/addr moet tennminste de vestigingsplaats bevatten (not(hl7:id[@root='2.16.528.1.1007.3.1']) or hl7:Organization/hl7:addr/hl7:city / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:id"
                 priority="1008"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.1' or @root='2.16.528.1.1007.3.2'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.UZI: UZI-nummer @root MOET 2.16.528.1.1007.3.1 (Personen) of 2.16.528.1.1007.3.2 (Systemen) zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.1' or @root='2.16.528.1.1007.3.2' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.UZI: UZI-nummer persoon MOET 9 cijfers lang zijn (not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-II.NL.UZI: UZI-nummer systeem MOET 9 cijfers lang zijn (not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3' or @root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer//<xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/id. @root moet 2.16.528.1.1007.3.1 (UZI), 2.16.840.1.113883.2.4.6.3 (BSN), of  or 2.16.840.1.113883.2.4.6.1 (AGB) zijn (@root='2.16.528.1.1007.3.1' or @root='2.16.840.1.113883.2.4.6.3' or @root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or              following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'][@code='P'] or             following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.6']"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer//<xsl:text/>
               <xsl:value-of select="local-name(..)"/>
               <xsl:text/>/code/@code moet "P" (Patiënt) zijn of een geldige waarde uit RoleCodeWettelijkeVertegenwoordigerNL (not(@root='2.16.840.1.113883.2.4.6.3') or following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.8'][@code='P'] or following-sibling::hl7:code[@codeSystem='2.16.840.1.113883.2.4.3.11.6'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:code"
                 priority="1007"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:telecom"
                 priority="1006"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:assignedPrincipalChoiceList/hl7:assignedPerson/hl7:name"
                 priority="1005"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:Organization/hl7:id"
                 priority="1004"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.URA: UZI-registerabonneenummer @root MOET 2.16.528.1.1007.3.3 zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.URA: UZI-registerabonneenummer MOET 8 cijfers lang zijn (not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="overseerRoot" select="@root"/>
      <xsl:variable name="overseerExt" select="@extension"/>
      <xsl:variable name="authorExt"
                    select="ancestor::hl7:*[hl7:authorOrPerformer]/hl7:authorOrPerformer//hl7:Organization/hl7:id[@root=$overseerRoot]/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or $authorExt=$overseerExt or ancestor::hl7:*[hl7:authorOrPerformer]/hl7:authorOrPerformer//hl7:AssignedDevice"/>
         <xsl:otherwise>
            <xsl:message>Control Act: overseer//<xsl:text/>
               <xsl:value-of select="local-name(../..)"/>
               <xsl:text/>/Organization/id. Organisatie van de overseer (<xsl:text/>
               <xsl:value-of select="$overseerRoot"/>
               <xsl:text/>#<xsl:text/>
               <xsl:value-of select="$overseerExt"/>
               <xsl:text/>) moet gelijk zijn aan die van de authorOrPerformer (<xsl:text/>
               <xsl:value-of select="$authorExt"/>
               <xsl:text/>) (@nullFlavor or $authorExt=$overseerExt or ancestor::hl7:*[hl7:authorOrPerformer]/hl7:authorOrPerformer//hl7:AssignedDevice / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:Organization/hl7:code"
                 priority="1003"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:Organization/hl7:telecom"
                 priority="1002"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:Organization/hl7:name"
                 priority="1001"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:ControlActProcess/hl7:overseer//hl7:*[local-name()='AssignedPerson' or local-name()='assignedEntity']/hl7:Organization/hl7:addr"
                 priority="1000"
                 mode="M7">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*" mode="M7"/>
   </xsl:template>

   <!--PATTERN -->


	<!--RULE -->
<xsl:template match="hl7:QUPC_IN443132NL/hl7:profileId" priority="1000" mode="M8">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"/>
         <xsl:otherwise>
            <xsl:message>In de transmission wrapper moet het element profileId worden gevuld met de
                                        waarde '810' (@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*" mode="M8"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.9003-->


	<!--RULE tmp-45925ae0-1476-477c-9ab4-3f14e65fbb1f-->
<xsl:template match="hl7:queryByParameter" priority="1003" mode="M53">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:parameterList)&gt;=1 and not(hl7:parameterList/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): element hl7:parameterList is mandatory [min 1x]. (count(hl7:parameterList)&gt;=1 and not(hl7:parameterList/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M53"/>
   </xsl:template>

	  <!--RULE tmp-7dac7088-6138-47b3-924d-bb137468bfd9-->
<xsl:template match="hl7:queryByParameter/hl7:parameterList" priority="1002" mode="M53">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientId)&gt;=1 and not(hl7:patientId/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): element hl7:patientId is mandatory [min 1x]. (count(hl7:patientId)&gt;=1 and not(hl7:patientId/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientId)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): element hl7:patientId komt te vaak voor [max 1x]. (count(hl7:patientId)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M53"/>
   </xsl:template>

	  <!--RULE tmp-94c51007-e49b-4fd3-8d3a-c17258c96f81-->
<xsl:template match="hl7:queryByParameter/hl7:parameterList/hl7:patientId" priority="1001"
                 mode="M53">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 and not(hl7:value[@root='2.16.840.1.113883.2.4.6.3']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): element hl7:value[@root='2.16.840.1.113883.2.4.6.3'] is mandatory [min 1x]. (count(hl7:value[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 and not(hl7:value[@root='2.16.840.1.113883.2.4.6.3']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): element hl7:value[@root='2.16.840.1.113883.2.4.6.3'] komt te vaak voor [max 1x]. (count(hl7:value[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M53"/>
   </xsl:template>

	  <!--RULE tmp-f03e9fba-6035-4b74-8f9e-a8b091cff99a-->
<xsl:template match="hl7:queryByParameter/hl7:parameterList/hl7:patientId/hl7:value[@root='2.16.840.1.113883.2.4.6.3']"
                 priority="1000"
                 mode="M53">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (@root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PrimaryCareRecordProfileQuerySEH-PS): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M53"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M53"/>
   <xsl:template match="@*|node()" priority="-2" mode="M53">
      <xsl:apply-templates select="*" mode="M53"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.10Correspondentie Verkort-->


	<!--RULE tmp-b9e44282-91ee-448d-ad1d-c26c339c00c9-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act"
                 priority="1009"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DOCCLIN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): De waarde van @classCode MOET 'DOCCLIN' zijn. (@classCode='DOCCLIN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:author is mandatory [min 1x]. (count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-4ffa0721-c5a1-4620-aef5-bf35800769cd-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.10']"
                 priority="1008"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.10'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.10' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.10' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-7880d6c3-d650-4fb6-852a-387a41763933-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:id"
                 priority="1007"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-76ad1bb3-780f-436c-bf9e-e9dea7340b67-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:code"
                 priority="1006"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-4574d723-3a11-4185-b7da-df781ffa52e2-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:author"
                 priority="1005"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&gt;=1 and not(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] is mandatory [min 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&gt;=1 and not(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-261f413d-7964-4033-ad70-619805f639ad-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:author/hl7:time"
                 priority="1004"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-c48d2795-ffd7-4101-aa9f-fbee3e9a604f-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1003"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-eedf4afd-c14e-475c-9edd-c839c184eaf7-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:code"
                 priority="1002"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.30.12')"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): De waarde van @codeSystem MOET '2.16.840.1.113883.2.4.4.30.12' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.30.12') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

	  <!--RULE tmp-b388c5df-da57-4c1f-89ff-e9a179bd7317-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.10']]/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M54">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP CorrespondentieVerkort): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M54"/>
   <xsl:template match="@*|node()" priority="-2" mode="M54">
      <xsl:apply-templates select="*" mode="M54"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.100Assessment-->


	<!--RULE tmp-4d8bf387-e557-4655-90f2-ab60a0fd354e-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.100']]/hl7:observation"
                 priority="1003"
                 mode="M55">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M55"/>
   </xsl:template>

	  <!--RULE tmp-b2f4f702-3cc0-4b83-80c0-9bd82cc394c1-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.100']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.100']"
                 priority="1002"
                 mode="M55">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.100'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.100' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.100' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M55"/>
   </xsl:template>

	  <!--RULE tmp-7c5894f5-2964-4dd4-b178-6ec8c42a59b4-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.100']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M55">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11283-9' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Acuity assessment')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): De waarde van @code/@codeSystem MOET '11283-9' codeSystem '2.16.840.1.113883.6.1' displayName='Acuity assessment' zijn. (@nullFlavor or (@code='11283-9' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Acuity assessment') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M55"/>
   </xsl:template>

	  <!--RULE tmp-55b3c2b5-6660-445f-94fd-891afddbf349-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.100']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M55">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Assessment): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M55"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M55"/>
   <xsl:template match="@*|node()" priority="-2" mode="M55">
      <xsl:apply-templates select="*" mode="M55"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.101Assessment and Plan-->


	<!--RULE tmp-a364f442-2c7b-4daf-b55d-16144d55f04c-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.101']]/hl7:act"
                 priority="1003"
                 mode="M56">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): De waarde van @classCode MOET 'ACT' zijn. (@classCode='ACT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): element hl7:text is mandatory [min 1x]. (count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M56"/>
   </xsl:template>

	  <!--RULE tmp-f47cbf54-4f0d-413c-8a28-98ed8a060218-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.101']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.101']"
                 priority="1002"
                 mode="M56">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.101'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.101' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.101' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M56"/>
   </xsl:template>

	  <!--RULE tmp-a6bab059-b93f-4018-beee-5ef36a8b5e7a-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.101']]/hl7:act/hl7:code"
                 priority="1001"
                 mode="M56">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='51847-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Assessment and plan')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): De waarde van @code/@codeSystem MOET '51847-2' codeSystem '2.16.840.1.113883.6.1' displayName='Assessment and plan' zijn. (@nullFlavor or (@code='51847-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Assessment and plan') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M56"/>
   </xsl:template>

	  <!--RULE tmp-a71d1311-89ed-4df8-b5ee-f4cc283ddf5e-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.101']]/hl7:act/hl7:text"
                 priority="1000"
                 mode="M56">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssessmentPlan): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M56"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M56"/>
   <xsl:template match="@*|node()" priority="-2" mode="M56">
      <xsl:apply-templates select="*" mode="M56"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.103-->


	<!--RULE tmp-b976fef0-14dd-4824-af63-71d926ddb849-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern"
                 priority="1011"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='CONC'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @classCode MOET 'CONC' zijn. (@classCode='CONC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject2)&gt;=1 and not(hl7:subject2/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:subject2 is mandatory [min 1x]. (count(hl7:subject2)&gt;=1 and not(hl7:subject2/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-b7def624-4cbd-44d1-b89a-abd7224da764-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.103']"
                 priority="1010"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.103'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.103' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.103' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-211b4a0d-5c3c-4a47-8a7b-b463e5b049ca-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:id"
                 priority="1009"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-cdbb26bd-aeac-4e62-b7eb-b6ef79504a67-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2"
                 priority="1008"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @contextConductionInd MOET 'true' zijn. (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SUBJ'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @typeCode MOET 'SUBJ' zijn. (@typeCode='SUBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-f8d3a768-d8e9-47b5-9a32-b712fedf5ea9-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation"
                 priority="1007"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-be616ded-0244-4490-b60c-3df6e1056317-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105']"
                 priority="1006"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.105'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.105' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.105' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-14200a9a-20b4-4700-8ca2-6e15054f2b60-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:code"
                 priority="1005"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ADMDX' and @codeSystem='2.16.840.1.113883.5.4' and @displayName='Admitting diagnosis')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @code/@codeSystem MOET 'ADMDX' codeSystem '2.16.840.1.113883.5.4' displayName='Admitting diagnosis' zijn. (@nullFlavor or (@code='ADMDX' and @codeSystem='2.16.840.1.113883.5.4' and @displayName='Admitting diagnosis') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-414b477b-e572-41e9-b536-9b65aec931f0-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:value"
                 priority="1004"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CV' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CV" bevatten (@nullFlavor or @xsi:type='CV' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CV: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.42.4.3.32.50')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @codeSystem MOET '2.16.840.1.113883.5.42.4.3.32.50' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.5.42.4.3.32.50') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-2027996a-85de-45db-b756-a0db173a690e-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:author"
                 priority="1003"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-e7be454d-5826-40a7-aa23-759f4dbe7972-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:author/hl7:assignedEntity"
                 priority="1002"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-02bed06b-d705-4b9e-b9a5-d3302725a44e-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:author/hl7:assignedEntity/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']"
                 priority="1001"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.104'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.104' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.104' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

	  <!--RULE tmp-1b426ac6-b540-4446-a39f-84da1251873a-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.103']]/hl7:concern/hl7:subject2/hl7:observation/hl7:author/hl7:assignedEntity/hl7:code"
                 priority="1000"
                 mode="M57">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='001' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='002' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='003' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='004' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='005' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='007' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='009' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@codeSystem='2.16.840.1.113883.2.4.3.32.51')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgvraag): De waarde van @code MOET één van de volgende codes bevatten: '001' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 002' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 003' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 004' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 005' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 007' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 009' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 2.16.840.1.113883.2.4.3.32.51'. (@nullFlavor or (@code='001' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='002' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='003' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='004' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='005' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='007' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='009' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@codeSystem='2.16.840.1.113883.2.4.3.32.51') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M57"/>
   <xsl:template match="@*|node()" priority="-2" mode="M57">
      <xsl:apply-templates select="*" mode="M57"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.104-->


	<!--RULE tmp-8a12e6ce-685c-43bb-acdd-bb7ab9f26d23-->
<xsl:template match="*[hl7:assignedEntity[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.104']]/hl7:assignedEntity"
                 priority="1002"
                 mode="M58">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M58"/>
   </xsl:template>

	  <!--RULE tmp-93d2a2da-80c4-4e39-8780-58e179712e0e-->
<xsl:template match="*[hl7:assignedEntity[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.104']]/hl7:assignedEntity/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']"
                 priority="1001"
                 mode="M58">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.104'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.104' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.104' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M58"/>
   </xsl:template>

	  <!--RULE tmp-37f6a0a2-ff3a-4e81-83d8-8a6a61404479-->
<xsl:template match="*[hl7:assignedEntity[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.104']]/hl7:assignedEntity/hl7:code"
                 priority="1000"
                 mode="M58">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='001' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='002' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='003' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='004' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='005' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='007' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='009' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@codeSystem='2.16.840.1.113883.2.4.3.32.51')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Zorgaanvrager): De waarde van @code MOET één van de volgende codes bevatten: '001' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 002' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 003' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 004' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 005' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 007' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 009' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 2.16.840.1.113883.2.4.3.32.51'. (@nullFlavor or (@code='001' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='002' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='003' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='004' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='005' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='007' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='009' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@codeSystem='2.16.840.1.113883.2.4.3.32.51') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M58"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M58"/>
   <xsl:template match="@*|node()" priority="-2" mode="M58">
      <xsl:apply-templates select="*" mode="M58"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.105-->


	<!--RULE tmp-4779cc7d-2703-4b47-b126-491d99d2a9d8-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation"
                 priority="1007"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-ef94b216-f2cf-467c-a803-611b8c45dfb9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.105']"
                 priority="1006"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.105'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.105' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.105' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-7fe2c34b-2dbf-4fe7-ac1e-197adc227c77-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:code"
                 priority="1005"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ADMDX' and @codeSystem='2.16.840.1.113883.5.4' and @displayName='Admitting diagnosis')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @code/@codeSystem MOET 'ADMDX' codeSystem '2.16.840.1.113883.5.4' displayName='Admitting diagnosis' zijn. (@nullFlavor or (@code='ADMDX' and @codeSystem='2.16.840.1.113883.5.4' and @displayName='Admitting diagnosis') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-3792ad80-5266-43ae-966f-7a6dc6c0282d-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:value"
                 priority="1004"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CV' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CV" bevatten (@nullFlavor or @xsi:type='CV' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CV: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.42.4.3.32.50')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @codeSystem MOET '2.16.840.1.113883.5.42.4.3.32.50' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.5.42.4.3.32.50') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-26cba29d-ca72-4583-b037-c6d7fa5b38d8-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:author"
                 priority="1003"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-2ab375b0-f1f8-4b99-a6df-10a7f2c5d621-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:author/hl7:assignedEntity"
                 priority="1002"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-040c1605-684a-4066-b9dd-b3f0fdb8010a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:author/hl7:assignedEntity/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.104']"
                 priority="1001"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.104'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.104' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.104' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

	  <!--RULE tmp-783302eb-d266-4a27-9c9e-93b5cafa5344-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.105']]/hl7:observation/hl7:author/hl7:assignedEntity/hl7:code"
                 priority="1000"
                 mode="M59">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='001' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='002' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='003' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='004' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='005' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='007' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='009' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@codeSystem='2.16.840.1.113883.2.4.3.32.51')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Vraagstelling): De waarde van @code MOET één van de volgende codes bevatten: '001' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 002' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 003' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 004' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 005' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 007' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 009' codeSystem '2.16.840.1.113883.2.4.3.32.3 of 2.16.840.1.113883.2.4.3.32.51'. (@nullFlavor or (@code='001' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='002' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='003' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='004' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='005' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='007' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@code='009' and @codeSystem='2.16.840.1.113883.2.4.3.32.3') or (@codeSystem='2.16.840.1.113883.2.4.3.32.51') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M59"/>
   <xsl:template match="@*|node()" priority="-2" mode="M59">
      <xsl:apply-templates select="*" mode="M59"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.107Conclusie-->


	<!--RULE tmp-49389738-e489-4bb2-a12f-38d627cda66a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.107']]/hl7:observation"
                 priority="1003"
                 mode="M60">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M60"/>
   </xsl:template>

	  <!--RULE tmp-19121e87-4863-4cfc-b578-74351b8124f0-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.107']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.107']"
                 priority="1002"
                 mode="M60">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.107'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.107' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.107' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M60"/>
   </xsl:template>

	  <!--RULE tmp-4bb79795-4f93-4888-847e-a11980ce01ba-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.107']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M60">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='DISDX' and @codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): De waarde van @code/@codeSystem MOET 'DISDX' codeSystem '2.16.840.1.113883.5.4' zijn. (@nullFlavor or (@code='DISDX' and @codeSystem='2.16.840.1.113883.5.4') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M60"/>
   </xsl:template>

	  <!--RULE tmp-ad00f694-a667-4bfb-bc83-5c23be820113-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.107']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M60">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Conclusie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M60"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M60"/>
   <xsl:template match="@*|node()" priority="-2" mode="M60">
      <xsl:apply-templates select="*" mode="M60"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.108Aanbevelingen huisarts-->


	<!--RULE tmp-8e56ed7a-6e6c-49ab-86c8-e06ab085fd5d-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.108']]/hl7:observation"
                 priority="1003"
                 mode="M61">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M61"/>
   </xsl:template>

	  <!--RULE tmp-eede6bc8-a075-4bb9-86ee-addfddf11bf5-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.108']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.108']"
                 priority="1002"
                 mode="M61">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.108'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.108' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.108' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M61"/>
   </xsl:template>

	  <!--RULE tmp-4a42ef0b-08ec-48de-bc01-797866cf5d88-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.108']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M61">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='18776-5' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Plan of treatment')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): De waarde van @code/@codeSystem MOET '18776-5' codeSystem '2.16.840.1.113883.6.1' displayName='Plan of treatment' zijn. (@nullFlavor or (@code='18776-5' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Plan of treatment') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M61"/>
   </xsl:template>

	  <!--RULE tmp-5f3c5a99-aa18-4435-86c3-9a1e63553575-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.108']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M61">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AanbevelingenHuisarts): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M61"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M61"/>
   <xsl:template match="@*|node()" priority="-2" mode="M61">
      <xsl:apply-templates select="*" mode="M61"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.109Anamnese-->


	<!--RULE tmp-e4ced08a-2bd0-4f66-96bb-470a962220d6-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.109']]/hl7:observation"
                 priority="1003"
                 mode="M62">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M62"/>
   </xsl:template>

	  <!--RULE tmp-93cd3f07-fe5e-481b-94f3-0205371b473d-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.109']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.109']"
                 priority="1002"
                 mode="M62">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.109'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.109' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.109' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M62"/>
   </xsl:template>

	  <!--RULE tmp-73a43c85-ace8-431b-80d5-78586313ccc2-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.109']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M62">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='10154-3' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Chief Complaint')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): De waarde van @code/@codeSystem MOET '10154-3' codeSystem '2.16.840.1.113883.6.1' displayName='Chief Complaint' zijn. (@nullFlavor or (@code='10154-3' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Chief Complaint') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M62"/>
   </xsl:template>

	  <!--RULE tmp-c6e3eba4-abee-489c-a6fd-37c1f4934160-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.109']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M62">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Anamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M62"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M62"/>
   <xsl:template match="@*|node()" priority="-2" mode="M62">
      <xsl:apply-templates select="*" mode="M62"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.110Familie anamnese-->


	<!--RULE tmp-a50d5710-b583-4a13-8f4b-737d948453aa-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation"
                 priority="1006"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element hl7:subject is required [min 1x]. (count(hl7:subject)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

	  <!--RULE tmp-f46ddce7-3acc-44ac-af37-b1e4200b20c7-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.110']"
                 priority="1005"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.110'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.110' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.110' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

	  <!--RULE tmp-6ccb30de-9047-4963-9aff-b866f3f302f9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation/hl7:code"
                 priority="1004"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='10157-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='History of family member diseases')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @code/@codeSystem MOET '10157-6' codeSystem '2.16.840.1.113883.6.1' displayName='History of family member diseases' zijn. (@nullFlavor or (@code='10157-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='History of family member diseases') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

	  <!--RULE tmp-ab4bfed6-9810-4d36-9629-d2e17db22aa4-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation/hl7:value"
                 priority="1003"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

	  <!--RULE tmp-da81d511-8615-44bc-b9f4-0163e6cf209b-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation/hl7:author"
                 priority="1002"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]|hl7:patient[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): keuze (hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] of hl7:patient[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']]) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

	  <!--RULE tmp-6fba8404-bb53-4137-9a8f-fc790dc0334f-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation/hl7:author/hl7:assignedEntity"
                 priority="1001"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

	  <!--RULE tmp-0019958c-3e4e-4eea-873f-4e1c962d4b22-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.110']]/hl7:observation/hl7:subject"
                 priority="1000"
                 mode="M63">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&gt;=1 and not(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'] is mandatory [min 1x]. (count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&gt;=1 and not(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieAnamnese): element *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'] komt te vaak voor [max 1x]. (count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M63"/>
   <xsl:template match="@*|node()" priority="-2" mode="M63">
      <xsl:apply-templates select="*" mode="M63"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.111Psychosociale anamnese-->


	<!--RULE tmp-053171b3-050d-42f4-900c-2e6b09183722-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.111']]/hl7:observation"
                 priority="1003"
                 mode="M64">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M64"/>
   </xsl:template>

	  <!--RULE tmp-1b5d8197-93e9-48c4-b231-3dd8a33226fd-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.111']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.111']"
                 priority="1002"
                 mode="M64">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.111'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.111' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.111' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M64"/>
   </xsl:template>

	  <!--RULE tmp-5cd260e3-0574-4851-a216-b03462ba1a68-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.111']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M64">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='46002-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Psychosocial well-being section')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): De waarde van @code/@codeSystem MOET '46002-2' codeSystem '2.16.840.1.113883.6.1' displayName='Psychosocial well-being section' zijn. (@nullFlavor or (@code='46002-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Psychosocial well-being section') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M64"/>
   </xsl:template>

	  <!--RULE tmp-dc77b536-be51-406d-956a-0db6bb5e75c8-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.111']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M64">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PsychosocialeAnamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M64"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M64"/>
   <xsl:template match="@*|node()" priority="-2" mode="M64">
      <xsl:apply-templates select="*" mode="M64"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.112Lichamelijk onderzoek-->


	<!--RULE tmp-56943c25-e103-45df-b5f8-a86fe9c30136-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation"
                 priority="1007"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

	  <!--RULE tmp-32f443bf-6d96-4241-91ff-b883388a8455-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.112']"
                 priority="1006"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.112'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.112' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.112' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

	  <!--RULE tmp-0226852b-32e6-4fab-b9b7-71fd1e6a2267-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation/hl7:code"
                 priority="1005"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='29545-1' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Physical Examination')"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): De waarde van @code/@codeSystem MOET '29545-1' codeSystem '2.16.840.1.113883.6.1' displayName='Physical Examination' zijn. (@nullFlavor or (@code='29545-1' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Physical Examination') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

	  <!--RULE tmp-aa0c7dec-94da-4e27-b66f-f60281c4568d-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation/hl7:value"
                 priority="1004"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

	  <!--RULE tmp-479c52e8-0a5e-4180-bb60-7ed3095bf1bf-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation/hl7:performer"
                 priority="1003"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

	  <!--RULE tmp-bc547e34-50ad-450f-ba9a-62f70e7bd7a8-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

	  <!--RULE tmp-69e5075f-aa07-470d-a1d3-63872ee804e4-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.112']]/hl7:observation/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M65">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP LichamelijkOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M65"/>
   <xsl:template match="@*|node()" priority="-2" mode="M65">
      <xsl:apply-templates select="*" mode="M65"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.113Laboratorium onderzoek-->


	<!--RULE tmp-b24bddc7-7073-4672-8a66-9ae0c382d695-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act"
                 priority="1007"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): De waarde van @classCode MOET 'ACT' zijn. (@classCode='ACT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:text is mandatory [min 1x]. (count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

	  <!--RULE tmp-bc0a9c57-09a4-4f6b-89f9-60cef19c22ce-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.113']"
                 priority="1006"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.113'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.113' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.113' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

	  <!--RULE tmp-db1c88a6-ac4c-4d16-b3b2-bcdb57a43b8a-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act/hl7:code"
                 priority="1005"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='56850-1' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Interpretation and review of laboratory results')"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): De waarde van @code/@codeSystem MOET '56850-1' codeSystem '2.16.840.1.113883.6.1' displayName='Interpretation and review of laboratory results' zijn. (@nullFlavor or (@code='56850-1' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Interpretation and review of laboratory results') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

	  <!--RULE tmp-92ab11bc-d3b9-41fa-b215-eb80aad9b65d-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act/hl7:text"
                 priority="1004"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

	  <!--RULE tmp-dd2dac05-c9b9-4f6f-9f72-395f8dfc6be9-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act/hl7:performer"
                 priority="1003"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

	  <!--RULE tmp-72651009-e3d0-4b84-9cbe-d339c4d4f404-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

	  <!--RULE tmp-da639d00-7752-4586-9f42-97513c20e872-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.113']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M66">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP LaboratoriumOderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M66"/>
   <xsl:template match="@*|node()" priority="-2" mode="M66">
      <xsl:apply-templates select="*" mode="M66"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.114Beeldvormend onderzoek-->


	<!--RULE tmp-fa02fb10-8d17-4a04-8ad5-d6f398ff94a7-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act"
                 priority="1007"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): De waarde van @classCode MOET 'ACT' zijn. (@classCode='ACT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:text is mandatory [min 1x]. (count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

	  <!--RULE tmp-acdb2ebe-378c-4172-8bd2-da32d551a7ba-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.114']"
                 priority="1006"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.114'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.114' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.114' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

	  <!--RULE tmp-663e6791-9f18-4421-8dfb-bf08e0bd3f24-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act/hl7:code"
                 priority="1005"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='30954-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Studies summary')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): De waarde van @code/@codeSystem MOET '30954-2' codeSystem '2.16.840.1.113883.6.1' displayName='Studies summary' zijn. (@nullFlavor or (@code='30954-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Studies summary') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

	  <!--RULE tmp-e3e27c5f-4c01-4dda-98ab-590f37251bf2-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act/hl7:text"
                 priority="1004"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

	  <!--RULE tmp-ca9a4d8b-18f9-45f7-832a-9ba75243fd85-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act/hl7:performer"
                 priority="1003"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

	  <!--RULE tmp-adc54fe1-e16b-4e80-893b-4d14e4a8227f-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

	  <!--RULE tmp-a5c5c9ba-064a-45cd-a942-27f69a30ea56-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.114']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M67">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BeeldvormendOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M67"/>
   <xsl:template match="@*|node()" priority="-2" mode="M67">
      <xsl:apply-templates select="*" mode="M67"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.115Functioneel onderzoek-->


	<!--RULE tmp-3ddd36b4-86ba-4b54-a34b-3e93e38c02b8-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act"
                 priority="1007"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): De waarde van @classCode MOET 'ACT' zijn. (@classCode='ACT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:text is mandatory [min 1x]. (count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

	  <!--RULE tmp-03a45724-39c3-49e7-bc89-198b14b6b2b5-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.115']"
                 priority="1006"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.115'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.115' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.115' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

	  <!--RULE tmp-380a1d7b-f299-4c39-be27-5df532efb09c-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act/hl7:code"
                 priority="1005"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='42345-9' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Discharge functional status')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): De waarde van @code/@codeSystem MOET '42345-9' codeSystem '2.16.840.1.113883.6.1' displayName='Discharge functional status' zijn. (@nullFlavor or (@code='42345-9' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Discharge functional status') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

	  <!--RULE tmp-d1125e88-a31a-463e-a693-6757e298aca5-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act/hl7:text"
                 priority="1004"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

	  <!--RULE tmp-504ef379-c5a1-4a0c-8cd1-fd32b068ec8e-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act/hl7:performer"
                 priority="1003"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

	  <!--RULE tmp-24f48f00-228c-4e2a-858c-dc0587f94903-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

	  <!--RULE tmp-9b0ad4c7-14d2-4d6a-bfd8-a77a4cae4122-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.115']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M68">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FunctioneelOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M68"/>
   <xsl:template match="@*|node()" priority="-2" mode="M68">
      <xsl:apply-templates select="*" mode="M68"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.116Overig onderzoek-->


	<!--RULE tmp-610411b2-9c47-4227-8353-cf9d89a52cc3-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act"
                 priority="1007"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): De waarde van @classCode MOET 'ACT' zijn. (@classCode='ACT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:text is mandatory [min 1x]. (count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

	  <!--RULE tmp-a0a5515f-c198-43cd-9405-489c69d49878-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.116']"
                 priority="1006"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.116'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.116' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.116' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

	  <!--RULE tmp-75109563-f636-46bb-9c24-7f518de23fed-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act/hl7:code"
                 priority="1005"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='26436-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Laboratory Studies')"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): De waarde van @code/@codeSystem MOET '26436-6' codeSystem '2.16.840.1.113883.6.1' displayName='Laboratory Studies' zijn. (@nullFlavor or (@code='26436-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Laboratory Studies') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

	  <!--RULE tmp-33fc74a5-5431-4dc1-a51b-b05fd80dd3f0-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act/hl7:text"
                 priority="1004"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

	  <!--RULE tmp-08f9060b-bb2f-4715-9fc5-3332b5782848-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act/hl7:performer"
                 priority="1003"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

	  <!--RULE tmp-b6856054-afda-4896-bc60-5822c925d45b-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

	  <!--RULE tmp-b0901af9-646b-43eb-81a4-3d7d006f4112-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.116']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M69">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP OverigOnderzoek): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M69"/>
   <xsl:template match="@*|node()" priority="-2" mode="M69">
      <xsl:apply-templates select="*" mode="M69"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.117Intercollegiaal consult-->


	<!--RULE tmp-ccc23d73-e2b3-4f11-9af8-e2f8e0be2459-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.117']]/hl7:observation"
                 priority="1003"
                 mode="M70">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M70"/>
   </xsl:template>

	  <!--RULE tmp-851b05eb-ba67-4ce9-9b6d-07a151c10a3c-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.117']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.117']"
                 priority="1002"
                 mode="M70">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.117'"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.117' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.117' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M70"/>
   </xsl:template>

	  <!--RULE tmp-dc65dda3-4c62-4f45-b9f7-c5a052981c78-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.117']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M70">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='47042-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Counseling note')"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): De waarde van @code/@codeSystem MOET '47042-7' codeSystem '2.16.840.1.113883.6.1' displayName='Counseling note' zijn. (@nullFlavor or (@code='47042-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Counseling note') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M70"/>
   </xsl:template>

	  <!--RULE tmp-12f1f279-baec-4cf7-9c30-e127622cffb6-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.117']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M70">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP IntercollegiaalConsult): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M70"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M70"/>
   <xsl:template match="@*|node()" priority="-2" mode="M70">
      <xsl:apply-templates select="*" mode="M70"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.118Risicovol leefgedrag-->


	<!--RULE tmp-6c174bd8-3543-4b00-8873-be6ce8cd78bc-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.118']]/hl7:observation"
                 priority="1003"
                 mode="M71">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M71"/>
   </xsl:template>

	  <!--RULE tmp-16f5a0ce-7e91-4a7a-8245-e60eb74c71a1-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.118']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.118']"
                 priority="1002"
                 mode="M71">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.118'"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.118' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.118' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M71"/>
   </xsl:template>

	  <!--RULE tmp-7dcc4bf9-74a1-442e-9105-7fa8b757eaa6-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.118']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M71">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='57207-3' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Risk factors present or past affecting health status')"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): De waarde van @code MOET één van de volgende codes bevatten: '57207-3' codeSystem '2.16.840.1.113883.6.1' displayName='Risk factors present or past affecting health status'. (@nullFlavor or (@code='57207-3' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Risk factors present or past affecting health status') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M71"/>
   </xsl:template>

	  <!--RULE tmp-3292ed96-f20f-4721-8d4f-3c322fa9d19d-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.118']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M71">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP RisicovolLeefgedrag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M71"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M71"/>
   <xsl:template match="@*|node()" priority="-2" mode="M71">
      <xsl:apply-templates select="*" mode="M71"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.119Reanimatiebeleid-->


	<!--RULE tmp-a785b55c-08b5-4791-a91d-7a1b01eb89ba-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.119']]/hl7:observation"
                 priority="1003"
                 mode="M72">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M72"/>
   </xsl:template>

	  <!--RULE tmp-0c3ff438-665a-430d-813b-4af8c000ee06-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.119']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.119']"
                 priority="1002"
                 mode="M72">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.119'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.119' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.119' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M72"/>
   </xsl:template>

	  <!--RULE tmp-cefdf325-9c7f-4bc9-ba0c-de0a94c528f4-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.119']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M72">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='REP' and @codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): De waarde van @code/@codeSystem MOET 'REP' codeSystem '2.16.840.1.113883.5.4' zijn. (@nullFlavor or (@code='REP' and @codeSystem='2.16.840.1.113883.5.4') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M72"/>
   </xsl:template>

	  <!--RULE tmp-2aa560d7-b8d3-431f-8fb2-97f85464f625-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.119']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M72">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Reanimatiebeleid): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M72"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M72"/>
   <xsl:template match="@*|node()" priority="-2" mode="M72">
      <xsl:apply-templates select="*" mode="M72"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.120Patient Advies-->


	<!--RULE tmp-1e16b009-6d67-47ea-960c-541275faa038-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.120']]/hl7:observation"
                 priority="1003"
                 mode="M73">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE tmp-2dec4a83-5163-488e-9941-a87cb127e721-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.120']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.120']"
                 priority="1002"
                 mode="M73">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.120'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.120' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.120' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE tmp-b5f19309-5211-4bc6-853a-8a83f1b11c63-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.120']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M73">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='28574-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Discharge Note')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): De waarde van @code/@codeSystem MOET '28574-2' codeSystem '2.16.840.1.113883.6.1' displayName='Discharge Note' zijn. (@nullFlavor or (@code='28574-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Discharge Note') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

	  <!--RULE tmp-324cd827-a368-4ea9-ad9c-db37059a1e9d-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.120']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M73">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientAdvies): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M73"/>
   <xsl:template match="@*|node()" priority="-2" mode="M73">
      <xsl:apply-templates select="*" mode="M73"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.40.17Belaste Familieanamnese-->


	<!--RULE tmp-bff26706-37f9-4e45-95cf-87c7928ce113-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation"
                 priority="1013"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 and not(hl7:subject/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:subject is mandatory [min 1x]. (count(hl7:subject)&gt;=1 and not(hl7:subject/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-a804639e-a3b9-4dc3-b847-27ac3d793c4c-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.40.17']"
                 priority="1012"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.40.17'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.40.17' hebben. (@root='2.16.840.1.113883.2.4.6.10.40.17' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-6dfaa92e-e5ae-470e-a6b7-c7be5bad77b9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:id"
                 priority="1011"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-447b69e6-5c07-4d8f-b9bd-d7a6d277843b-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:code"
                 priority="1010"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='10157-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='History of family member diseases')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @code/@codeSystem MOET '10157-6' codeSystem '2.16.840.1.113883.6.1' displayName='History of family member diseases' zijn. (@nullFlavor or (@code='10157-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='History of family member diseases') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-057f84a4-f650-46f8-9646-45758cce3157-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:text"
                 priority="1009"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-5e07cb87-bfb9-4816-914c-c6c037f60f8b-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:statusCode"
                 priority="1008"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active') or (@code='completed')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @code MOET één van de volgende codes bevatten: 'active of completed'. (@nullFlavor or (@code='active') or (@code='completed') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-c4f841a5-7e81-4462-9cf6-510656110867-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:effectiveTime"
                 priority="1007"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_TS" bevatten (@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:low is required [min 1x]. (count(hl7:low)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:width)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:width MAY NOT be present  (count(hl7:width)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:center)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:center MAY NOT be present  (count(hl7:center)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-2e30aeeb-8d54-48ab-a2aa-72913df51bba-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:effectiveTime/hl7:low"
                 priority="1006"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-8ae1b295-a44d-4e07-bf75-cd7c61edd16b-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:effectiveTime/hl7:high"
                 priority="1005"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-7a80d193-5e19-4ba8-95bf-d29ad72be2fd-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:value"
                 priority="1004"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.31.1')"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @codeSystem MOET '2.16.840.1.113883.2.4.4.31.1' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.31.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-ccd73910-2dbd-4c46-bc6a-3d4c3245ec80-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:author"
                 priority="1003"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]|hl7:patient[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): keuze (hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] of hl7:patient[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']]) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-26035598-1a4e-4418-8bda-019618085df4-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:author/hl7:time"
                 priority="1002"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-6c2ac4b9-e6e8-4786-978b-be2ee4208227-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:author/hl7:assignedEntity"
                 priority="1001"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

	  <!--RULE tmp-e8ca84e8-88eb-444c-baec-f3a4f17002b5-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.40.17']]/hl7:observation/hl7:subject"
                 priority="1000"
                 mode="M74">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&gt;=1 and not(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'] is mandatory [min 1x]. (count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&gt;=1 and not(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP BelasteFamilieanamnese): element *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'] komt te vaak voor [max 1x]. (count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M74"/>
   <xsl:template match="@*|node()" priority="-2" mode="M74">
      <xsl:apply-templates select="*" mode="M74"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.1-->


	<!--RULE tmp-07e3d158-5330-4334-a3b7-4b0b6db31dfd-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation"
                 priority="1010"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-b11f7b7d-9080-45fa-baa6-ac8fbc21300f-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.1']"
                 priority="1009"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.1'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.1' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-a57a1871-fdb2-43a9-b3f3-885de00bed67-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:code"
                 priority="1008"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-NoteCategory-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-NoteCategory-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De waarde van @code MOET worden gekozen uit Value Set NoteCategory Note Category DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set NoteCategory Note Category DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-3e1fb116-677d-4217-8c4e-fc0181894269-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:value"
                 priority="1007"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-57d77098-5d30-4fce-bcbc-8d93ed114130-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:effectiveTime"
                 priority="1006"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_TS" bevatten (@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:low is required [min 1x]. (count(hl7:low)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:center)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:center MAY NOT be present  (count(hl7:center)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:width)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:width MAY NOT be present  (count(hl7:width)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-537c4b3f-9cba-4723-982e-2383f568bee0-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:effectiveTime/hl7:low"
                 priority="1005"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-d8376ae5-45bd-44ab-8d9f-e798c2d6fe3a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:effectiveTime/hl7:high"
                 priority="1004"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-e77e5544-106a-49bd-9abc-e74080d0f5e7-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:author"
                 priority="1003"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-cfd5874a-9fac-4805-a549-30ee8bf7a58a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

	  <!--RULE tmp-9a67fba6-0a50-4a03-b434-e945e049676a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.1']]/hl7:observation/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M75">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Overdrachtgegevens): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M75"/>
   <xsl:template match="@*|node()" priority="-2" mode="M75">
      <xsl:apply-templates select="*" mode="M75"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.15-->


	<!--RULE tmp-44d03645-3026-4bd9-88f4-21d2faffa564-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern"
                 priority="1009"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='CONC'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @classCode MOET 'CONC' zijn. (@classCode='CONC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:statusCode is mandatory [min 1x]. (count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject2)&gt;=1 and not(hl7:subject2/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:subject2 is mandatory [min 1x]. (count(hl7:subject2)&gt;=1 and not(hl7:subject2/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-906a5ef0-7769-4fc2-a92b-9d988d0c467f-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.15']"
                 priority="1008"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.15'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.15' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.15' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-e26b7ae5-944f-4e01-87d4-1165ed7614d4-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:id"
                 priority="1007"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-c1cc849b-dfd6-4213-a487-262b34fe1f47-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:statusCode"
                 priority="1006"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active') or (@code='completed')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @code MOET één van de volgende codes bevatten: 'active of completed'. (@nullFlavor or (@code='active') or (@code='completed') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-84f3d0ac-bf46-4130-8518-e67158f3959c-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:effectiveTime"
                 priority="1005"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_TS" bevatten (@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:low is mandatory [min 1x]. (count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:width)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:width MAY NOT be present  (count(hl7:width)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:center)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element hl7:center MAY NOT be present  (count(hl7:center)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-8de10776-6f6a-4bdc-958d-046e70e37e48-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:effectiveTime/hl7:low"
                 priority="1004"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-8bcd844c-10ce-4b55-8418-fc5c1dc4d015-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:component"
                 priority="1003"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @contextConductionInd MOET 'true' zijn. (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-94d98b30-5790-4c1e-ae81-09bfae50cea2-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:reference"
                 priority="1002"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='false'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @contextConductionInd MOET 'false' zijn. (@contextConductionInd='false' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='REFR'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @typeCode MOET 'REFR' zijn. (@typeCode='REFR' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.2']|*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.16'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): keuze (*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.2'] of *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.16']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-e28c95ee-cb69-4ac2-8fd0-7e4c6baff10a-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:subject2"
                 priority="1001"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @contextConductionInd MOET 'true' zijn. (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SUBJ'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @typeCode MOET 'SUBJ' zijn. (@typeCode='SUBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']|*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.25'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): keuze (*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5'] of *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.25']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

	  <!--RULE tmp-b5f1a93d-28f6-4a17-98d1-26f69cb7a8c9-->
<xsl:template match="*[hl7:concern[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.15']]/hl7:concern/hl7:author"
                 priority="1000"
                 mode="M76">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Episode): element *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M76"/>
   <xsl:template match="@*|node()" priority="-2" mode="M76">
      <xsl:apply-templates select="*" mode="M76"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.16-->


	<!--RULE tmp-e9970cec-7962-4636-a511-3a1f692bdc3c-->
<xsl:template match="*[hl7:actReference[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.16']]/hl7:actReference"
                 priority="1002"
                 mode="M77">
      <xsl:variable name="theClass" select="@classCode"/>
      <xsl:variable name="theMood" select="@moodCode"/>
      <xsl:variable name="theRoot" select="hl7:id/@root"/>
      <xsl:variable name="theExtension" select="hl7:id/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="ancestor::hl7:CareProvisionEvent//hl7:*[@classCode=$theClass and @moodCode=$theMood]/hl7:id[not(parent::hl7:actReference) and @root=$theRoot and (not(@extension) or @extension=$theExtension)]"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): (TMP ActReferentie): actReference MOET verwijzen naar een element met dezelfde @classCode en @moodCode en hetzelfde id binnen dezelfde CareProvisionEvent (ancestor::hl7:CareProvisionEvent//hl7:*[@classCode=$theClass and @moodCode=$theMood]/hl7:id[not(parent::hl7:actReference) and @root=$theRoot and (not(@extension) or @extension=$theExtension)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE tmp-541369f2-4a2f-41ab-b280-4c48bd5f1516-->
<xsl:template match="*[hl7:actReference[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.16']]/hl7:actReference/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.16']"
                 priority="1001"
                 mode="M77">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.16'"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.16' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.16' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

	  <!--RULE tmp-16bab4b5-9a9f-484b-b5bd-d60bd425b572-->
<xsl:template match="*[hl7:actReference[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.16']]/hl7:actReference/hl7:id"
                 priority="1000"
                 mode="M77">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP ActReferentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M77"/>
   <xsl:template match="@*|node()" priority="-2" mode="M77">
      <xsl:apply-templates select="*" mode="M77"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.18-->


	<!--RULE tmp-d6f2247d-b343-40c1-be63-8975d40f6bb6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']"
                 priority="1010"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PAT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): De waarde van @classCode MOET 'PAT' zijn. (@classCode='PAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']] is required [min 1x]. (count(hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']] komt te vaak voor [max 1x]. (count(hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-2a61fd30-bc3d-4357-af6b-c3a5b75034c4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.18']"
                 priority="1009"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.18'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.18' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.18' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-0d54506b-1375-48b2-b267-a88c08e46e6e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:id"
                 priority="1008"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-8c2e8b13-6587-4e0c-9bfe-8e9032b876cb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:addr"
                 priority="1007"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-2e4d599e-beb5-46c7-ad01-caec4cae469f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:telecom"
                 priority="1006"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TEL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TEL" bevatten (@nullFlavor or @xsi:type='TEL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-1a1b923d-d15d-4155-85de-4634a9fbd405-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:statusCode"
                 priority="1005"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-03886cde-d346-4882-9540-e73915401b33-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']]"
                 priority="1004"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): De waarde van @determinerCode MOET 'INSTANCE' zijn. (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:administrativeGenderCode komt te vaak voor [max 1x]. (count(hl7:administrativeGenderCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthPlace)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): element hl7:birthPlace komt te vaak voor [max 1x]. (count(hl7:birthPlace)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-f33e30f4-e100-418a-b2bb-bf7d8d46981c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']"
                 priority="1003"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.19'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.19' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.19' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-12acba4e-d484-46d2-b771-9b732d6d0f4d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']]/hl7:name"
                 priority="1002"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-8ef31484-4b2b-4b6b-affe-700f37e0a32f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']]/hl7:administrativeGenderCode"
                 priority="1001"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): De waarde van @code MOET worden gekozen uit Value Set AdministrativeGender Administratieve geslachten DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set AdministrativeGender Administratieve geslachten DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

	  <!--RULE tmp-882d7e1e-a9db-4763-b93a-74ad04181769-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.18']/hl7:patientPerson[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']]/hl7:birthTime"
                 priority="1000"
                 mode="M78">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M78"/>
   <xsl:template match="@*|node()" priority="-2" mode="M78">
      <xsl:apply-templates select="*" mode="M78"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.19-->


	<!--RULE tmp-299fe48a-5ed1-46d0-b131-305cf921e6db-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.19']"
                 priority="1004"
                 mode="M79">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): De waarde van @determinerCode MOET 'INSTANCE' zijn. (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): element hl7:administrativeGenderCode komt te vaak voor [max 1x]. (count(hl7:administrativeGenderCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthPlace)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): element hl7:birthPlace komt te vaak voor [max 1x]. (count(hl7:birthPlace)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE tmp-7fd4bf7a-7881-47aa-8fbf-621428b7a0df-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.19']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.19']"
                 priority="1003"
                 mode="M79">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.19'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.19' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.19' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE tmp-1ae57df2-71df-4de9-8632-99e8b4599cd4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.19']/hl7:name"
                 priority="1002"
                 mode="M79">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE tmp-319c0d64-805d-48b3-b0ec-62871870a365-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.19']/hl7:administrativeGenderCode"
                 priority="1001"
                 mode="M79">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): De waarde van @code MOET worden gekozen uit Value Set AdministrativeGender Administratieve geslachten DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set AdministrativeGender Administratieve geslachten DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

	  <!--RULE tmp-3ec28603-6898-45d7-a670-7ed97cf32c2c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.19']/hl7:birthTime"
                 priority="1000"
                 mode="M79">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PersonNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M79"/>
   <xsl:template match="@*|node()" priority="-2" mode="M79">
      <xsl:apply-templates select="*" mode="M79"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.2-->


	<!--RULE tmp-b9587066-9d04-4f85-aa32-e8859203b3ad-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.2']]/hl7:observation"
                 priority="1003"
                 mode="M80">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE tmp-b47fe4df-a3b4-4c33-ac19-cfe56c77e57c-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.2']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.2']"
                 priority="1002"
                 mode="M80">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.2'"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.2' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.2' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE tmp-3829e791-9f00-424a-9f26-922e0954e533-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.2']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M80">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='21975-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Date last contact')"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): De waarde van @code/@codeSystem MOET '21975-8' codeSystem '2.16.840.1.113883.6.1' displayName='Date last contact' zijn. (@nullFlavor or (@code='21975-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Date last contact') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

	  <!--RULE tmp-1c37ec53-1050-4a37-ab40-595383b40e67-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.2']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M80">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP DatumLaatsteContact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.FULL: null or date precision of time stamp shall be YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M80"/>
   <xsl:template match="@*|node()" priority="-2" mode="M80">
      <xsl:apply-templates select="*" mode="M80"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.20-->


	<!--RULE tmp-c2b4eb3e-46a8-4fc4-aa42-c9cb4733abec-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']"
                 priority="1013"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount" select="count(hl7:assignedPerson|hl7:assignedOrganization)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): keuze (hl7:assignedPerson of hl7:assignedOrganization) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): keuze (hl7:assignedPerson of hl7:assignedOrganization) bevat te veel elementen [max 1x] ($elmcount&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element representedOrganization komt te vaak voor [max 1x]. (count(representedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-01a563e0-03b5-4452-976a-3d3ccf50aa4b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20']"
                 priority="1012"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.20'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.20' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.20' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-efdf3c14-6ee1-48b1-bec2-5ac9cb3c21f3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:id"
                 priority="1011"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-005b8e40-381f-4fa9-9cd3-c00281cbe21e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:code"
                 priority="1010"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-b02cec0b-283a-45f0-a1e0-44fcb2e882c3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:addr"
                 priority="1009"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-7c380c06-0937-4a2d-ab6c-2aff1c2f91ce-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:assignedPerson"
                 priority="1008"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): De waarde van @determinerCode MOET 'INSTANCE' zijn. (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-5d35116d-e1d8-4807-a0c1-21a8875392f7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:assignedPerson/hl7:name"
                 priority="1007"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-eeb18d43-b914-499b-81ce-28d9d0db77cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:assignedOrganization"
                 priority="1006"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): De waarde van @determinerCode MOET 'INSTANCE' zijn. (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-4dc450d6-7f3c-4bd0-9413-63a2b212d884-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/hl7:assignedOrganization/hl7:name"
                 priority="1005"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='EN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "EN" bevatten (@nullFlavor or @xsi:type='EN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-ffb6612b-227b-46e0-a306-3c85f1eef1ec-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/representedOrganization"
                 priority="1004"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-8b3137d4-a89b-4fae-8750-c38fa9679ff9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/representedOrganization/hl7:id"
                 priority="1003"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-d9ce3784-b0cc-44d3-be32-91fafd325935-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/representedOrganization/hl7:code"
                 priority="1002"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-d9976ef9-e14a-4731-90f3-2072e9472db1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/representedOrganization/hl7:name"
                 priority="1001"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

	  <!--RULE tmp-43123193-d7ed-4ee2-805a-9b75a6c6d5c0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.20']/representedOrganization/hl7:addr"
                 priority="1000"
                 mode="M81">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPartyNL): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M81"/>
   <xsl:template match="@*|node()" priority="-2" mode="M81">
      <xsl:apply-templates select="*" mode="M81"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.21-->


	<!--RULE tmp-55376479-badd-4c32-90ec-51b1aafd9250-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1001"
                 mode="M82">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonNL): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonNL): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

	  <!--RULE tmp-16567fa2-fb5c-45ac-9ed9-135777611cff-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.21']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M82">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonNL): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonNL): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M82"/>
   <xsl:template match="@*|node()" priority="-2" mode="M82">
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.22-->


	<!--RULE tmp-2e16eccb-3a0b-4b23-b90f-c6d73502cb58-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.22']"
                 priority="1001"
                 mode="M83">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonIdentified): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonIdentified): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

	  <!--RULE tmp-4ade0d40-8a42-4586-b5d5-595159194ba4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.22']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.22']"
                 priority="1000"
                 mode="M83">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.22'"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonIdentified): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.22' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.22' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP AssignedPersonIdentified): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M83"/>
   <xsl:template match="@*|node()" priority="-2" mode="M83">
      <xsl:apply-templates select="*" mode="M83"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.23-->


	<!--RULE tmp-d9d1bfea-7b97-4c21-87b3-df306b1b500c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.23']"
                 priority="1001"
                 mode="M84">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNLIdentified): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNLIdentified): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE tmp-d66cba61-b065-4104-92e9-1efc108fcad3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.23']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']"
                 priority="1000"
                 mode="M84">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.23'"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNLIdentified): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.23' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.23' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP PatientNLIdentified): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M84"/>
   <xsl:template match="@*|node()" priority="-2" mode="M84">
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.24-->


	<!--RULE tmp-5dbaf4de-49d8-48d8-a53d-bce6343202d7-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship"
                 priority="1006"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PRS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): De waarde van @classCode MOET 'PRS' zijn. (@classCode='PRS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE tmp-cf139b25-97a9-4831-b7d4-6fbaaa6c9224-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.24']"
                 priority="1005"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.24'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.24' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.24' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE tmp-c825677f-1561-4ae9-bb91-12c0715c3c3d-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship/hl7:code"
                 priority="1004"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): De waarde van @codeSystem MOET '2.16.840.1.113883.5.111' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE tmp-5d1c0d72-093d-47af-a132-01ab40178ad0-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1003"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): De waarde van @determinerCode MOET 'INSTANCE' zijn. (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:administrativeGenderCode komt te vaak voor [max 1x]. (count(hl7:administrativeGenderCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): element hl7:deceasedTime komt te vaak voor [max 1x]. (count(hl7:deceasedTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE tmp-a6278365-ff72-476f-8d08-cdb635557ff8-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship/hl7:relationshipHolder/hl7:administrativeGenderCode"
                 priority="1002"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): De waarde van @code MOET worden gekozen uit Value Set AdministrativeGender Administratieve geslachten DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set AdministrativeGender Administratieve geslachten DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE tmp-3aa78cbc-3998-4bbb-8bb2-0c708459cf8a-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship/hl7:relationshipHolder/hl7:birthTime"
                 priority="1001"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE tmp-51982b05-8c10-4fa0-9cd2-a1551f05271f-->
<xsl:template match="*[hl7:personalRelationship[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.24']]/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedTime"
                 priority="1000"
                 mode="M85">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP FamilieRelatie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M85"/>
   <xsl:template match="@*|node()" priority="-2" mode="M85">
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.25-->


	<!--RULE tmp-104e043a-984c-4110-b69f-730985ab52ab-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.25']]/hl7:observation"
                 priority="1003"
                 mode="M86">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE tmp-7cee62b5-dd8a-4eb7-b91f-774661139264-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.25']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.25']"
                 priority="1002"
                 mode="M86">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.25'"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.25' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.25' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE tmp-47cdac46-b691-4e9a-b597-b839af30e75c-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.25']]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M86">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='DX' and @codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): De waarde van @code/@codeSystem MOET 'DX' codeSystem '2.16.840.1.113883.5.4' zijn. (@nullFlavor or (@code='DX' and @codeSystem='2.16.840.1.113883.5.4') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE tmp-bfbb732e-2e27-4923-aa81-2d09768bf6c1-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.25']]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M86">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP EpisodeNaam): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M86"/>
   <xsl:template match="@*|node()" priority="-2" mode="M86">
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.3-->


	<!--RULE tmp-fecabbe5-abea-4c0d-8026-fec3f43e1359-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter"
                 priority="1017"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ENC'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @classCode MOET 'ENC' zijn. (@classCode='ENC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-31a5d294-ee10-4985-8541-78a4fd25c233-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.3']"
                 priority="1016"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.3' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-cddcc7e1-944e-4d90-989b-e67bc0269925-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:id"
                 priority="1015"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-eb541d15-f839-4a1b-852c-774cb968b292-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:code"
                 priority="1014"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Contactwijze-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Contactwijze-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @code MOET worden gekozen uit Value Set Contactwijze NHG HIS tabel 14 Contactwijze versie 7 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set Contactwijze NHG HIS tabel 14 Contactwijze versie 7 DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:translation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:translation komt te vaak voor [max 1x]. (count(hl7:translation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-ae259d40-86d8-4000-9efe-1a296970da94-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:code/hl7:translation"
                 priority="1013"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Verrichtingen-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Verrichtingen-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @code MOET worden gekozen uit Value Set Verrichtingen WCIAv3 Tabel 15 Verrichtingen DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set Verrichtingen WCIAv3 Tabel 15 Verrichtingen DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-1350bd27-6d45-4335-998d-5a53b560e7b5-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:effectiveTime"
                 priority="1012"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_TS" bevatten (@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:low is mandatory [min 1x]. (count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:center)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:center MAY NOT be present  (count(hl7:center)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:width)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:width MAY NOT be present  (count(hl7:width)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-1c7cba1d-b707-4bf8-b5bf-b913daa6c0b0-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:effectiveTime/hl7:low"
                 priority="1011"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-cbb53e5a-abec-47e0-b27c-2159f7ca271b-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:effectiveTime/hl7:high"
                 priority="1010"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-381beb9a-9413-4fbb-8f22-3eca86b5b9c0-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:author"
                 priority="1009"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-cafda331-1294-4fcd-b87e-bddd6d60b44a-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1008"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-cfa57240-d7c3-40d4-9620-31ebd044fa1f-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1006"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-8bbbb0ca-0ff1-47fe-9374-77d196539a41-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:performer"
                 priority="1005"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-3ec6cce5-005b-4db5-adb8-b2900adf120d-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1004"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-a170e9fb-1a81-4473-9ddc-b259e6cd6302-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1002"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-d6f305ee-717d-4901-8fb1-861879fcfb4d-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:outboundRelationship"
                 priority="1001"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): De waarde van @contextConductionInd MOET 'true' zijn. (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:sequenceNumber)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): element hl7:sequenceNumber komt te vaak voor [max 1x]. (count(hl7:sequenceNumber)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']|*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']|*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']|*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): keuze (*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4'] of *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5'] of *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6'] of *[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE tmp-19f7852e-73ac-4da2-b006-d7463580228c-->
<xsl:template match="*[hl7:encounter[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.3']]/hl7:encounter/hl7:outboundRelationship/hl7:sequenceNumber"
                 priority="1000"
                 mode="M87">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt; 0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT.POS: null or value &gt; 0 (@nullFlavor or @value &gt; 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>(TMP Contact): @value is geen geldig INT getal <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M87"/>
   <xsl:template match="@*|node()" priority="-2" mode="M87">
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.4-->


	<!--RULE tmp-b7d86f1d-138a-4064-b552-6e69ce831753-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation"
                 priority="1013"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-d5858093-fba8-4c9d-894f-aef767785417-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.4']"
                 priority="1012"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.4'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.4' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.4' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-6fa80b99-ea3c-4c3d-9f13-94da039e0ad3-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:id"
                 priority="1011"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-dbe888f7-6e5f-49fc-bc1d-8740906c826c-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:code"
                 priority="1010"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Journaalregeltypen-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Journaalregeltypen-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @code MOET worden gekozen uit Value Set Journaalregeltypen DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set Journaalregeltypen DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-dcbf8263-1498-4f93-87b1-3071c02c4277-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:effectiveTime"
                 priority="1009"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-18c6789d-0ac5-4103-8d1d-c04821ef01b7-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:value"
                 priority="1008"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-ed145be9-4450-4a9a-87cb-7bfec9e7c267-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:author"
                 priority="1007"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-bf7f62d2-7bf4-4802-9dbc-8b13db9ae0db-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1006"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-5f2c446d-278a-4835-870d-4fca3ed27244-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1004"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-43a876cd-9ede-43f5-89d6-84b11b2a9286-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:performer"
                 priority="1003"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-7d8ab4b6-7a97-4ac0-b56a-adb12150255e-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE tmp-d4303a93-7107-45bb-8e9e-f150c0c5a8ce-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.4']]/hl7:observation/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M88">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Journaalregel): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M88"/>
   <xsl:template match="@*|node()" priority="-2" mode="M88">
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.5-->


	<!--RULE tmp-6f5dbfea-aa1a-4e34-b177-a974fc87d138-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation"
                 priority="1014"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-588e575e-7462-4008-8354-798f048e9b6a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.5']"
                 priority="1013"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.5'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.5' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.5' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-8963ab58-9156-4760-a873-d3deb66cb798-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:id"
                 priority="1012"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-5a487f94-4d42-4c82-aa0f-a7bf29769f05-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:code"
                 priority="1011"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='DISDX' and @codeSystem='2.16.840.1.113883.5.4') or (@code='ADMDX' and @codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @code MOET één van de volgende codes bevatten: 'DISDX' codeSystem '2.16.840.1.113883.5.4 of ADMDX' codeSystem '2.16.840.1.113883.5.4'. (@nullFlavor or (@code='DISDX' and @codeSystem='2.16.840.1.113883.5.4') or (@code='ADMDX' and @codeSystem='2.16.840.1.113883.5.4') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-311e7a7f-3b0b-45ea-9564-c0e8779653fe-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:text"
                 priority="1010"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-7e57c906-2e3d-4ad9-bdf4-07da6c34d24f-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:effectiveTime"
                 priority="1009"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_TS" bevatten (@nullFlavor or @xsi:type='IVL_TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_TS: low/@value must have the same precision as
        high/@value (not(hl7:low/@value and hl7:high/@value) or string-length(hl7:low/@value) = string-length(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_TS: low/@value must be before high/@value (not(hl7:low/@value and hl7:high/@value) or number(substring(concat(hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_TS: for width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:low is mandatory [min 1x]. (count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:center)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:center MAY NOT be present  (count(hl7:center)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:width)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:width MAY NOT be present  (count(hl7:width)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-092edac8-f4e1-4321-baa8-5af7c8bc94e5-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:effectiveTime/hl7:low"
                 priority="1008"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-bdce0316-5ef0-44e5-a319-8448ae4292ab-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:effectiveTime/hl7:high"
                 priority="1007"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-6bb8b1c3-58dd-4769-aac7-e31ad90ad9e2-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:uncertaintyCode"
                 priority="1006"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-UncertaintyCodeUncertainty-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-UncertaintyCodeUncertainty-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @code MOET worden gekozen uit Value Set UncertaintyCodeUncertainty Uncertainty Code (uncertainty only) DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set UncertaintyCodeUncertainty Uncertainty Code (uncertainty only) DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-109376e1-c9a4-494a-afa3-2fb5026d4a21-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:value"
                 priority="1005"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.31.1')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @codeSystem MOET '2.16.840.1.113883.2.4.4.31.1' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.31.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-1dadbc5c-b1e5-4249-9776-79341fe284dd-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:author"
                 priority="1004"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]|hl7:patient[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): keuze (hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] of hl7:patient[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']]) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-8f0b3be8-cb31-4ece-a03b-e97331fc358f-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:author/hl7:time"
                 priority="1003"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-9a232831-359e-422a-9d90-db7f78388fdd-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:author/hl7:assignedEntity"
                 priority="1002"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-3e1525f7-0767-4cb3-8ba0-0e769b2564a0-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:performer"
                 priority="1001"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20']]|hl7:patient1[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): keuze (hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.20']] of hl7:patient1[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.23']]) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE tmp-91de89de-b2b2-4b37-a85c-2f0cf8ede647-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.5']]/hl7:observation/hl7:performer/hl7:assignedEntity"
                 priority="1000"
                 mode="M89">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Diagnose): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M89"/>
   <xsl:template match="@*|node()" priority="-2" mode="M89">
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.6-->


	<!--RULE tmp-1ac22d95-ae98-4206-8ffa-0c024fb79b26-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation"
                 priority="1025"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:value[@xsi:type='PQ']|hl7:value[@xsi:type='IVL_PQ']|hl7:value[@xsi:type='CV']|hl7:value[@xsi:type='ST']|hl7:value[@xsi:type='TS']|hl7:value[@xsi:type='BL'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): keuze (hl7:value[@xsi:type='PQ'] of hl7:value[@xsi:type='IVL_PQ'] of hl7:value[@xsi:type='CV'] of hl7:value[@xsi:type='ST'] of hl7:value[@xsi:type='TS'] of hl7:value[@xsi:type='BL']) bevat te veel elementen [max 1x] ($elmcount&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-fe57da4f-3fbd-4ba5-ba29-214b0cdd9ab9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.6']"
                 priority="1024"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.6'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.6' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.6' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-e4901c1c-9c02-44a6-9871-9f9cc6d75fd4-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:id"
                 priority="1023"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-13506a14-1b20-485e-b809-17a7a63aa4fb-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:code"
                 priority="1022"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-DiagnostischeBepalingen-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-DiagnostischeBepalingen-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @code MOET worden gekozen uit Value Set DiagnostischeBepalingen NHG HIS tabel 45 Diagnostische bepalingen versie 14 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set DiagnostischeBepalingen NHG HIS tabel 45 Diagnostische bepalingen versie 14 DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-c6358a95-3a99-4480-9d41-ed955207caec-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:text"
                 priority="1021"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-ea93516a-e3d4-48e5-b9c1-474b558530c1-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:effectiveTime"
                 priority="1020"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-73895e60-0eeb-4fb1-a03c-aa84de5e6fc9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:value[@xsi:type='PQ']"
                 priority="1019"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @value is geen geldig PQ getal <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): value/@unit (PQ) MOET een geldige UCUM-eenheid zijn (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-c2534cb2-ab7a-4afd-aac1-6a06439e9fdc-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:value[@xsi:type='IVL_PQ']"
                 priority="1018"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_PQ" bevatten (@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@unit and hl7:high/@unit) or         hl7:low/@unit = hl7:high/@unit"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_PQ: units in low and high must be equal (not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         not(hl7:low/@unit = hl7:high/@unit) or         number(hl7:low/@value) &lt; number(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_PQ:
        low/@value must be lower than high/@value (not(hl7:low/@value and hl7:high/@value) or not(hl7:low/@unit = hl7:high/@unit) or number(hl7:low/@value) &lt; number(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center) or (hl7:center and not(hl7:low or hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_PQ: center may not be used together with low or high (not(hl7:center) or (hl7:center and not(hl7:low or hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): value/low @value is not a valid PQ number<xsl:text/>
               <xsl:value-of select="hl7:low/@value"/>
               <xsl:text/>
       (not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): value/high @value is not a valid PQ number<xsl:text/>
               <xsl:value-of select="hl7:high/@value"/>
               <xsl:text/>
       (not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): value/center @value is not a valid PQ number<xsl:text/>
               <xsl:value-of select="hl7:center/@value"/>
               <xsl:text/>
       (not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-2d243188-3677-4308-a8f4-2a3a53d368a3-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:value[@xsi:type='CV']"
                 priority="1017"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CV' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CV" bevatten (@nullFlavor or @xsi:type='CV' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CV: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.30.1045')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @codeSystem MOET '2.16.840.1.113883.2.4.4.30.1045' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.30.1045') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-68fc47ae-9167-41da-afc5-e3b27d677a80-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:value[@xsi:type='ST']"
                 priority="1016"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-ae968023-91d9-4622-9baa-65a08a6f23c0-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:value[@xsi:type='TS']"
                 priority="1015"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-5924401c-2154-4090-b7cb-d41866289d73-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:value[@xsi:type='BL']"
                 priority="1014"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-526cadcf-07a7-4903-a0c3-feded760c9e9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:interpretationCode"
                 priority="1013"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ObservationInterpretation-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ObservationInterpretation-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @code MOET worden gekozen uit Value Set ObservationInterpretation Observation Interpretation DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set ObservationInterpretation Observation Interpretation DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-2e05e0ae-2b9c-4c26-a08a-69584ea39656-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:author"
                 priority="1012"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-56848835-5688-4293-a189-a6cf64296d13-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1011"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-a3a598fd-3846-48cb-bf03-d4367ea8804e-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1009"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-c6797d89-7a9e-47ae-a275-3bea70ee4028-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:performer"
                 priority="1008"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-c64c5785-3592-4f73-a620-ea98f205c253-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1007"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-dfd57413-731d-4871-b307-00469b641c05-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1005"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-7b06a488-cdc9-44c0-a072-b1ced704fcbf-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:referenceRange"
                 priority="1004"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='REFV'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @typeCode MOET 'REFV' zijn. (@typeCode='REFV' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='false'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @contextConductionInd MOET 'false' zijn. (@contextConductionInd='false' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-d0170872-31fd-419b-8665-c8c1ff60674f-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:referenceRange/hl7:observationRange"
                 priority="1003"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN.CRT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @moodCode MOET 'EVN.CRT' zijn. (@moodCode='EVN.CRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:interpretationCode)&gt;=1 and not(hl7:interpretationCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:interpretationCode is mandatory [min 1x]. (count(hl7:interpretationCode)&gt;=1 and not(hl7:interpretationCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:interpretationCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:interpretationCode komt te vaak voor [max 1x]. (count(hl7:interpretationCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-2ea6041b-8282-41a2-b146-a14b9b768bd9-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:referenceRange/hl7:observationRange/hl7:text"
                 priority="1002"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-776d703f-3c45-459e-9424-6a892d6a2940-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:referenceRange/hl7:observationRange/hl7:interpretationCode"
                 priority="1001"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ObservationInterpretation-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ObservationInterpretation-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De waarde van @code MOET worden gekozen uit Value Set ObservationInterpretation Observation Interpretation DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Uitslag): De nul waarde voor @code MOET worden gekozen uit de set geldige null flavors gedefinieerd voor dit attribuut of degene geassocieerd met Value Set ObservationInterpretation Observation Interpretation DYNAMIC. (not(@nullFlavor) or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE tmp-7353c18f-da84-46aa-a6ba-ef793651690a-->
<xsl:template match="*[hl7:observation[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.6']]/hl7:observation/hl7:referenceRange/hl7:observationRange/hl7:value"
                 priority="1000"
                 mode="M90">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_PQ" bevatten (@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@unit and hl7:high/@unit) or         hl7:low/@unit = hl7:high/@unit"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_PQ: units in low and high must be equal (not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         not(hl7:low/@unit = hl7:high/@unit) or         number(hl7:low/@value) &lt; number(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_PQ:
        low/@value must be lower than high/@value (not(hl7:low/@value and hl7:high/@value) or not(hl7:low/@unit = hl7:high/@unit) or number(hl7:low/@value) &lt; number(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center) or (hl7:center and not(hl7:low or hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_PQ: center may not be used together with low or high (not(hl7:center) or (hl7:center and not(hl7:low or hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: value/low @value is not a valid PQ number<xsl:text/>
               <xsl:value-of select="hl7:low/@value"/>
               <xsl:text/>
       (not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: value/high @value is not a valid PQ number<xsl:text/>
               <xsl:value-of select="hl7:high/@value"/>
               <xsl:text/>
       (not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: value/center @value is not a valid PQ number<xsl:text/>
               <xsl:value-of select="hl7:center/@value"/>
               <xsl:text/>
       (not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:low or hl7:high"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: hl7:low or hl7:high elements (or both) mandatory (hl7:low or hl7:high / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:center)=0"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: element hl7:center MAY NOT be present  (count(hl7:center)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:width)=0"/>
         <xsl:otherwise>
            <xsl:message>observationRange/value: element hl7:width MAY NOT be present  (count(hl7:width)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M90"/>
   <xsl:template match="@*|node()" priority="-2" mode="M90">
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.6.10.70.9-->


	<!--RULE tmp-52928190-8ef0-42db-b60f-0b0b0a4b4c03-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act"
                 priority="1028"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DOCCLIN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @classCode MOET 'DOCCLIN' zijn. (@classCode='DOCCLIN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:effectiveTime MAY NOT be present  (count(hl7:effectiveTime)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:author is mandatory [min 1x]. (count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-ff8d6e7d-0f19-44fa-b6e9-a508d52c22f4-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.9']"
                 priority="1027"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.9'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.9' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.9' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-464e990d-1793-454a-8909-7c87a7006beb-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:id"
                 priority="1026"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-117b0d08-4b4c-4f88-8895-9fd92d29f5c2-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:code"
                 priority="1025"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-1fc74852-0829-4111-b085-13c44dc21f8a-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:text"
                 priority="1024"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-17ce1aa8-b1f4-4610-aaab-b5fd9f2b1ed4-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:author"
                 priority="1023"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&gt;=1 and not(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] is mandatory [min 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&gt;=1 and not(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-714feee3-072b-46aa-8e14-f6b6b21b7892-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:author/hl7:time"
                 priority="1022"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-bed058a7-a9d5-4231-bd1a-64c588ff3f31-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1021"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-61a7deee-7af4-4562-a955-db874c48eb3a-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:code"
                 priority="1020"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.30.12')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @codeSystem MOET '2.16.840.1.113883.2.4.4.30.12' zijn. (@nullFlavor or (@codeSystem='2.16.840.1.113883.2.4.4.30.12') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-eec903e5-d74d-4b11-9dec-ff710d05b5cc-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1018"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-f458d1bd-18a1-4a1f-92f7-99081c3ca43e-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:performer"
                 priority="1017"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-6e59067b-a427-471f-af6a-05744df576e5-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1016"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-ef63735f-5ad1-4120-801f-42cdf977da48-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1014"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-fd6c3b8b-9379-4b6b-b068-ccd00cf2f673-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship"
                 priority="1013"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SUMM'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @typeCode MOET 'SUMM' zijn. (@typeCode='SUMM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @contextConductionInd MOET 'true' zijn. (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&gt;=1 and not(hl7:act/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:act is mandatory [min 1x]. (count(hl7:act)&gt;=1 and not(hl7:act/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-42c06cb8-ac32-4a05-af0d-121e928a10d3-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act"
                 priority="1012"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DOCCLIN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @classCode MOET 'DOCCLIN' zijn. (@classCode='DOCCLIN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:text is mandatory [min 1x]. (count(hl7:text)&gt;=1 and not(hl7:text/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:author is mandatory [min 1x]. (count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-58aef08a-5c6f-40ac-81b4-6ad952cb6a8f-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:id"
                 priority="1011"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-e4f1d855-73fa-4873-ae14-699c4fbe8fbd-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:code"
                 priority="1010"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-7978776c-3835-43c9-a39d-c6a06741bbc2-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:text"
                 priority="1009"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ED' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ED" bevatten (@nullFlavor or @xsi:type='ED' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="text()"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-5fa97353-8562-4eba-825a-61def696cc24-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:author"
                 priority="1008"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='ON'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @contextControlCode MOET 'ON' zijn. (@contextControlCode='ON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-46e7a4c0-a999-451a-bb95-b1759a00cb41-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:author/hl7:time"
                 priority="1007"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-5bb3f461-c048-48fa-9041-ca6176a56be4-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1006"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-15eea5ab-90b5-4f22-b542-051badcf0faf-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:author/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1004"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-a9d1d183-6a38-4d96-bd6c-47e04704e81c-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:performer"
                 priority="1003"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']] komt te vaak voor [max 1x]. (count(hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-30540088-25fa-402c-806c-859abb7c27eb-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]"
                 priority="1002"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE tmp-75db4b3a-5202-486c-abad-f5ab5fee8934-->
<xsl:template match="*[hl7:act[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.70.9']]/hl7:act/hl7:outboundRelationship/hl7:act/hl7:performer/hl7:assignedEntity[hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']]/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.70.21']"
                 priority="1000"
                 mode="M91">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.70.21'"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.70.21' hebben. (@root='2.16.840.1.113883.2.4.6.10.70.21' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP Correspondentie): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M91"/>
   <xsl:template match="@*|node()" priority="-2" mode="M91">
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>
</xsl:stylesheet>