<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:peri="urn:nictiz-nl:v3/perinatologie"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <xsl:apply-templates select="/" mode="M43"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN template-2.16.840.1.113883.2.4.6.10.90.60Overdracht Acute Fase bericht (antepartum)-->


	<!--RULE tmp-77acf5dc-4411-473d-a96d-3e7874ca9c70-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']"
                 priority="1249"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:subject is required [min 1x]. (count(hl7:subject)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:subject komt te vaak voor [max 1x]. (count(hl7:subject)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:author is required [min 1x]. (count(hl7:author)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]] is mandatory [min 1x]. (count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-edf4242a-24d4-4c16-8746-a64e36bd30f2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.60']"
                 priority="1248"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.90.60'"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root MOET de waarde '2.16.840.1.113883.2.4.6.10.90.60' hebben. (@root='2.16.840.1.113883.2.4.6.10.90.60' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9fa4939a-d2d9-4267-a32d-de2a7a0362d3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:id"
                 priority="1247"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-30ade174-7846-46c4-a608-1f5314e4a8dd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:statusCode"
                 priority="1246"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b8beec2a-23bc-41aa-849f-028fbc063670-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject"
                 priority="1245"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:patient is mandatory [min 1x]. (count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:patient komt te vaak voor [max 1x]. (count(hl7:patient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9408129f-128c-4345-99e4-68e6d14416ea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient"
                 priority="1244"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PAT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'PAT' zijn. (@classCode='PAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: identification mother requires either a BSN or a local id or both (count(hl7:id)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] is required [min 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:statusCode is mandatory [min 1x]. (count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson)&gt;=1 and not(hl7:patientPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:patientPerson is mandatory [min 1x]. (count(hl7:patientPerson)&gt;=1 and not(hl7:patientPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:patientPerson komt te vaak voor [max 1x]. (count(hl7:patientPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7259facc-6568-4092-a3bd-507bcaa59a8e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3'][@root='2.16.840.1.113883.2.4.6.3']"
                 priority="1243"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.BSN: Burgerservicenummer @root MOET 2.16.840.1.113883.2.4.6.3 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.BSN: Burgerservicenummer MOET 9 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or (         (   number(substring(@extension,1,1))*9 )+         (   number(substring(@extension,2,1))*8 )+         (   number(substring(@extension,3,1))*7 )+         (   number(substring(@extension,4,1))*6 )+         (   number(substring(@extension,5,1))*5 )+         (   number(substring(@extension,6,1))*4 )+         (   number(substring(@extension,7,1))*3 )+         (   number(substring(@extension,8,1))*2 )+         (   number(substring(@extension,9,1))*-1) ) mod 11=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-II.NL.BSN: Burgerservicenummer voldoet niet aan modulo 11 proef (not(@root='2.16.840.1.113883.2.4.6.3') or ( ( number(substring(@extension,1,1))*9 )+ ( number(substring(@extension,2,1))*8 )+ ( number(substring(@extension,3,1))*7 )+ ( number(substring(@extension,4,1))*6 )+ ( number(substring(@extension,5,1))*5 )+ ( number(substring(@extension,6,1))*4 )+ ( number(substring(@extension,7,1))*3 )+ ( number(substring(@extension,8,1))*2 )+ ( number(substring(@extension,9,1))*-1) ) mod 11=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (@root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: attribute @extension MOET aanwezig zijn. (string-length(@extension)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4023b07a-9192-47f0-831b-113251294b70-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:id"
                 priority="1242"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@root)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: attribute @root MOET aanwezig zijn. (string-length(@root)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: attribute @extension MOET aanwezig zijn. (string-length(@extension)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c9375329-3802-4514-8b8a-841104dc0b6a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:addr"
                 priority="1241"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @use='HP' or @use='PHYS' or @use='TMP' or @use='HP PHYS' or @use='TMP PHYS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @use MOET één van de volgende codes bevatten: 'HP', 'PHYS', 'TMP', 'HP PHYS', 'TMP PHYS'. (@nullFlavor or @use='HP' or @use='PHYS' or @use='TMP' or @use='HP PHYS' or @use='TMP PHYS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:postalCode is mandatory [min 1x]. (count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:postalCode komt te vaak voor [max 1x]. (count(hl7:postalCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3fa3c3dc-59c0-44bc-b86d-6ca18f0b67bf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:statusCode"
                 priority="1240"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b43626b8-9eac-4103-9982-2ce83a663478-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson"
                 priority="1239"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:deceasedInd/@value='false' or hl7:deceasedTime"/>
         <xsl:otherwise>
            <xsl:message>acufap: Datum maternale sterfte: if deceasedInd=true an element deceasedTime shall be present (hl7:deceasedInd/@value='false' or hl7:deceasedTime / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name komt te vaak voor [max 2x]. (count(hl7:name)&lt;=2 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:languageCommunication komt te vaak voor [max 1x]. (count(hl7:languageCommunication)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&gt;=1 and not(hl7:deceasedInd/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:deceasedInd is mandatory [min 1x]. (count(hl7:deceasedInd)&gt;=1 and not(hl7:deceasedInd/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:deceasedInd komt te vaak voor [max 1x]. (count(hl7:deceasedInd)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:deceasedTime komt te vaak voor [max 1x]. (count(hl7:deceasedTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:ethnicGroupCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:ethnicGroupCode is required [min 1x]. (count(hl7:ethnicGroupCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:ethnicGroupCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:ethnicGroupCode komt te vaak voor [max 1x]. (count(hl7:ethnicGroupCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8e01550c-5b30-4f75-973e-3f1e762d7783-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name"
                 priority="1238"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @use='OR' or @use='L' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @use MOET één van de volgende codes bevatten: 'OR', 'L'. (@nullFlavor or @use='OR' or @use='L' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-64b26648-26af-4e9a-bc71-236f3b7db051-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:birthTime"
                 priority="1237"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-29cbfd10-3628-4bf5-bdad-fea7a2c0538a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication"
                 priority="1236"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&gt;=1 and not(hl7:languageCommunication/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:languageCommunication is mandatory [min 1x]. (count(hl7:languageCommunication)&gt;=1 and not(hl7:languageCommunication/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:languageCommunication komt te vaak voor [max 1x]. (count(hl7:languageCommunication)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:proficiencyLevelCode)&gt;=1 and not(hl7:proficiencyLevelCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:proficiencyLevelCode is mandatory [min 1x]. (count(hl7:proficiencyLevelCode)&gt;=1 and not(hl7:proficiencyLevelCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:proficiencyLevelCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:proficiencyLevelCode komt te vaak voor [max 1x]. (count(hl7:proficiencyLevelCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5f1dc4fc-d294-48f0-822d-2c986ca749b3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication/hl7:languageCommunication"
                 priority="1235"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'nl-NL' codeSystem '2.16.840.1.113883.6.121' zijn. (@nullFlavor or (@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5ad35f71-5f56-43ef-ac08-4ea03b0b72d2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication/hl7:proficiencyLevelCode"
                 priority="1234"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-LanguageAbilityProficiency-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-LanguageAbilityProficiency-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set LanguageAbilityProficiency Language Ability Proficiency DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b6e636db-e8be-40f7-9b92-456755cef75e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:deceasedInd"
                 priority="1233"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0fc108b6-51c9-4698-b497-91bf4a4b621e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:deceasedTime"
                 priority="1232"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2644f23b-f71e-4772-80ae-e1dbd9fa0ac7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:ethnicGroupCode"
                 priority="1231"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EthnicGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EthnicGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set EthnicGroup DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1b0be110-6436-44f2-8bff-14cd4c6d6eba-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:performer"
                 priority="1230"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:responsibleParty is mandatory [min 1x]. (count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f157c12e-26c6-4c93-a7aa-2d4eab1e45d2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:performer/hl7:responsibleParty"
                 priority="1229"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:agentPerson is mandatory [min 1x]. (count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bca68b1c-90d1-43a6-8e72-abbab2e1039d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:performer/hl7:responsibleParty/hl7:code"
                 priority="1228"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.37')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '2' codeSystem '2.16.840.1.113883.2.4.4.13.37' zijn. (@nullFlavor or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.37') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7f1510b0-423c-479c-b89d-86cecff98957-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:performer/hl7:responsibleParty/hl7:agentPerson"
                 priority="1227"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e088843a-5a3e-4e1d-8b1d-75e60a25d302-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:performer/hl7:responsibleParty/hl7:agentPerson/hl7:name"
                 priority="1226"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e183c733-8d56-43b7-b861-99795111cf7f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author"
                 priority="1225"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:modeCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:modeCode is required [min 1x]. (count(hl7:modeCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:modeCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:modeCode komt te vaak voor [max 1x]. (count(hl7:modeCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:signatureCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:signatureCode is required [min 1x]. (count(hl7:signatureCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:signatureCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:signatureCode komt te vaak voor [max 1x]. (count(hl7:signatureCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:responsibleParty is mandatory [min 1x]. (count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1291b7a7-d8c6-4946-8c20-a0552e7bee27-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:time"
                 priority="1224"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fa69722f-3eb8-484a-85cd-6dd121208aae-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:modeCode"
                 priority="1223"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@nullFlavor)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: attribute @nullFlavor MOET aanwezig zijn. (string-length(@nullFlavor)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@code='NA')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van nullFlavor MOET 'NA' zijn. ((@code='NA') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-68fc9c8d-43bf-48e9-b333-cf6f06a545e7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:signatureCode"
                 priority="1222"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@nullFlavor)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: attribute @nullFlavor MOET aanwezig zijn. (string-length(@nullFlavor)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@code='NA')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van nullFlavor MOET 'NA' zijn. ((@code='NA') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-93a0c734-1de4-479c-a7f9-77292cc39f32-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty"
                 priority="1221"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:telecom)&gt;=1 and not(hl7:telecom/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:telecom is mandatory [min 1x]. (count(hl7:telecom)&gt;=1 and not(hl7:telecom/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:telecom)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:telecom komt te vaak voor [max 1x]. (count(hl7:telecom)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:agentPerson is mandatory [min 1x]. (count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&gt;=1 and not(hl7:representedOrganization/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:representedOrganization is mandatory [min 1x]. (count(hl7:representedOrganization)&gt;=1 and not(hl7:representedOrganization/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:representedOrganization komt te vaak voor [max 1x]. (count(hl7:representedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d02e6859-4455-4421-bf15-265e7ca9e357-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:id"
                 priority="1220"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e1c8f018-b0a5-45ad-9caf-e3d566bc55d8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:code"
                 priority="1219"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-59d1152a-5251-4420-af73-f1ac736dd483-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:telecom"
                 priority="1218"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TEL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TEL" bevatten (@nullFlavor or @xsi:type='TEL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-744f59eb-fe50-4a25-a135-88296e5221e2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:agentPerson"
                 priority="1217"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-83eecbdc-d527-4ead-88f0-2cc20b5dd16b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name"
                 priority="1216"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-34ab82ad-18d8-4d37-b546-6a92ed6ce2e5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization"
                 priority="1215"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:id[@root='2.16.840.1.113883.2.4.6.1']|hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']|hl7:id[@root='2.16.528.1.1007.3.3'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: keuze (hl7:id[@root='2.16.840.1.113883.2.4.6.1'] of hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'] of hl7:id[@root='2.16.528.1.1007.3.3']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-18ef8169-e33f-4b0b-a752-85fde04c34c6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id"
                 priority="1214"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-46830466-85a1-42f5-bc82-0a1bd6ec0d14-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1213"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.AGB: AGB-code @root MOET 2.16.840.1.113883.2.4.6.1 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.AGB: AGB-code moet 8 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (@root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1276ea79-69e3-46c9-b4c3-9f8022debabe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']"
                 priority="1212"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.3.22.98.1'"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root MOET de waarde '2.16.840.1.113883.2.4.3.22.98.1' hebben. (@root='2.16.840.1.113883.2.4.3.22.98.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-264cd562-602f-4f4f-b1ee-4466a4f63bf9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1211"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.URA: UZI-registerabonneenummer @root MOET 2.16.528.1.1007.3.3 zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.URA: UZI-registerabonneenummer MOET 8 cijfers lang zijn (not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (@root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufap: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-40614d71-5b9e-4987-8d47-f3efac85b0e1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:code"
                 priority="1210"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set ZorgaanbiederType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-576887b1-3be4-49cd-93f5-c04d54bd1a8e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:name"
                 priority="1209"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0293c989-de10-436a-b453-604723fec218-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:addr"
                 priority="1208"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ef6e86c9-7048-41a6-81bd-5f26d1977350-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1207"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f845fc9a-3fa2-4bdf-83d4-a66c94ef02cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1206"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1b5b54ae-75bd-436e-a4a9-5450966e28fe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent"
                 priority="1205"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='COND' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'COND' zijn. (@classCode='COND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9706f7b5-3c23-4b7d-b655-ae41b88b913f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent/hl7:id"
                 priority="1204"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-08f1f54b-5546-412a-bd95-e41925c6f719-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent/hl7:code"
                 priority="1203"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RedenOverdrachtCategorie-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RedenOverdrachtCategorie-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set RedenOverdrachtCategorie Categorie Reden overdracht DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-455ba81c-9b3d-4a98-861b-7d11d552127b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent/hl7:text"
                 priority="1202"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c6b6f604-63b3-4f23-a3be-6faba45beb6e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1201"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-22e17091-46ee-4801-a03a-5e59a2541914-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1200"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8906568a-d68f-405d-9310-ff766f9f9969-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1198"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship is mandatory [min 1x]. (count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7fd636a3-86bb-47a0-9d00-bffb1aae7be3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1197"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0bb3cb9e-7557-41c4-9212-2674beedd5d7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship"
                 priority="1196"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bbc1841b-055b-4ec6-83c3-2cd775d14d0f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation"
                 priority="1195"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-75baa577-ea79-4048-b22a-907e3adaba16-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1194"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c5941661-6213-491c-b86b-a29633ebb3ba-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1193"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship
                                component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ff6b19e3-d224-445f-aa8e-4d45f016157f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship"
                 priority="1192"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bb2de369-e31d-408c-b203-809f2da8dbfe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation"
                 priority="1191"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8edbe288-257e-4a69-b78a-814544fb2ada-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1190"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-38cb903c-cdd6-4b8a-8743-275cf96f8442-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1189"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set VILLijst10002000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a0516e7d-0d83-437f-96da-b845370c4205-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1188"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eba058d4-5837-4f20-a6d6-48a9beafcb57-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1187"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b4f12ca2-eefc-47a5-8fc6-46de2b4ddd51-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1185"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship is mandatory [min 1x]. (count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4798da5f-b912-4ca4-8439-1d2235d8afe5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1184"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-30de0e6b-a12f-4187-aaa3-99fe78642a69-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship"
                 priority="1183"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-377ddd5d-2f10-4f75-9ab1-22c9e3209895-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation"
                 priority="1182"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5178eaae-c99b-4bf3-88f1-c7fc75a0f3bb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1181"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0b1a1ecc-8e58-401b-9d34-4851078e3191-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1180"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship
                                component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-83a6f100-a8cb-4949-b236-f4cfa0414642-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship"
                 priority="1179"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-98620317-b81d-44d1-ab0f-6e022d2b9b9a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation"
                 priority="1178"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cda25f1a-5d14-4759-b881-824fcb98cc58-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1177"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-86c752f9-6160-4111-861f-5854f9ca9fbf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1176"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst3000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst3000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set VILLijst3000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-600070c8-343b-48a6-b860-eb70db4886eb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1175"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ee4a7519-3644-4677-94ba-819dee81f7ea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1174"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-46e0540f-5cb2-4c3b-9bb0-58f7864d9052-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1173"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='276986009')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET '276986009' zijn. (@nullFlavor or (@code='276986009') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-94b57c0f-bbe4-4c3f-80d4-e899fa1b3fcd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1172"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9fe8f343-f8b4-4a22-b3b5-a4f9cf5dd171-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1171"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e4ef1a13-8d63-4ab6-806d-bf7b0d0daa22-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1170"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-PerinatalperiodADP-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-PerinatalperiodADP-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set PerinatalperiodADP DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='276986009')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET '276986009' zijn. (@nullFlavor or (@code='276986009') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e25df8fc-63a2-43a3-8a5d-690b465311fe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1167"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='373663005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '373663005' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='373663005' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b10b070c-8bd1-4815-95bf-720b0e659987-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1165"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8cd3901f-8f50-4fef-88a7-3b357c179f52-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1164"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-04a25f64-b3b1-4284-a01b-e1859bd7bee0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1163"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-94474196-98fa-4788-aec1-b50b9893aec7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1162"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '106190000' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='106190000' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c1493538-5431-4c8d-88dd-cdadc43c4e90-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1161"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Allergies-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Allergies-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set Allergies DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8cff2efc-1c4e-40ad-ae26-593b91e6e041-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1160"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-83bc93eb-17ec-4138-9fcb-e2d4fd358af2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1159"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7b8b94ae-5248-4102-aa30-9b5312818dbc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1158"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7d82f7a1-bcdc-4009-b15c-1e1e5cdc3e1d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1157"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '129019007' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='129019007' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9305a05d-5067-4643-9497-0da1a90ac795-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1156"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5f050554-2c23-4425-a386-b659e8fce566-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship"
                 priority="1155"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-74ba153d-e9c1-42d5-8914-7fd292c49a85-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship"
                 priority="1154"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1db8eea8-513b-4709-b73e-13955fe182b3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration"
                 priority="1153"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='SBADM' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'SBADM' zijn. (@classCode='SBADM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:consumable is mandatory [min 1x]. (count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:consumable komt te vaak voor [max 1x]. (count(hl7:consumable)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-15e66dec-ae3f-456c-8d47-49b8e3aae46e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable"
                 priority="1152"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='CSM' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'CSM' zijn. (@typeCode='CSM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:manufacturedProduct is required [min 1x]. (count(hl7:manufacturedProduct)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:manufacturedProduct komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b84b2d13-69b0-4ea3-8851-cbe2802c4bb4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct"
                 priority="1151"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='MANU' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'MANU' zijn. (@classCode='MANU' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:manufacturedProduct is required [min 1x]. (count(hl7:manufacturedProduct)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:manufacturedProduct komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0b877a78-6c96-4027-b76f-43b32cb6fde7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct/hl7:manufacturedProduct"
                 priority="1150"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='MMAT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'MMAT' zijn. (@classCode='MMAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='KIND' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @determinerCode SHALL have value 'KIND' STATIC  (@determinerCode='KIND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7d6905a8-c954-4948-a4d3-8106f6695382-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct/hl7:manufacturedProduct/hl7:name"
                 priority="1149"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3cfee65a-b662-4b67-a84f-761060e9f29f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]"
                 priority="1148"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4ffa0b02-6642-40a0-9c4a-627aa4a502f0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]"
                 priority="1147"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c216a8ac-58a2-4546-b161-9b5ec09cd676-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]/hl7:observation"
                 priority="1146"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2b288062-5c5b-42fe-a650-346ed1334619-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]/hl7:observation/hl7:code"
                 priority="1145"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'NEGSE' codeSystem '2.16.840.1.113883.3.799.5.1' zijn. (@nullFlavor or (@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-07e70d2a-c815-4787-8955-d822e6823612-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]/hl7:observation/hl7:value"
                 priority="1144"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bfb2d85a-4ff0-40d0-b8e7-c225141817da-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1143"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-da56b170-ce44-49a5-bcac-b1ef7563fa42-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1142"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-841e6932-5b19-4ff4-b395-ed06d5387728-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1141"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a8103836-31f0-4b16-8432-946a45c3cecd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1140"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '266096002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='266096002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ce5e3e5e-f4f0-42b9-9739-87ba678ce20c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1139"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9175983f-0f5b-47d9-997c-1dbcfa343dc5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1138"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-12391aa5-86b7-4208-9c59-42b8c41ddac2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1137"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dcc1d4c3-a629-4b37-83a2-1b4e13713a54-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1136"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7914d31d-ee87-4f47-bb3c-821ac0718180-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1135"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '161664006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='161664006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-045d8978-b3fd-4e86-8a25-b5ea699a3a1d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1134"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8150591e-4b15-4e0f-9dd9-ed4e6304146f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1133"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2448c42a-b5f7-44c3-849f-0e9a63048b66-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1132"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5a64d539-a462-4a6a-92c4-e963ecb432d4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1131"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-33385fa9-5d87-42f6-8abd-c7f692b18988-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1130"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '39156-5' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4d33ecf2-50e2-4c53-8f0a-609ea6629c7b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1129"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='kg/m2' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufap: value MOET eenheid 'kg/m2' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='kg/m2' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c33719b8-85dc-4a78-8b07-dda9a12cb020-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1128"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-717a9a33-3526-4f95-bca8-727e7910c0a7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1127"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35426117-6760-4148-b806-47dadeab6cb8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer"
                 priority="1126"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='CONTAINER' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'CONTAINER' zijn. (@classCode='CONTAINER' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7d80d39b-5170-48b9-949d-89ca0bf8ab13-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:code"
                 priority="1125"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '75367002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='75367002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d8668cad-f49d-4b53-8c7c-e35906a64c6f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1124"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-836b269e-bb12-479a-af21-1ade2b4a2672-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1123"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5071976-05cf-4d2b-8ed0-2eb3cfaa8c27-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1122"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cd0ffab2-9455-401a-87bf-dc059567a3af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1121"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '271649006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='271649006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a9673789-8ff9-4eab-8883-0bdfd664f1fa-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1120"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufap: value MOET eenheid 'mm[Hg]' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-31896e4e-854c-4cd2-b89f-50590c418cf1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1119"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4d1e2538-2e61-4114-bcfc-4a5c1ea563cc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1118"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-aeada5c0-ae90-4296-9f86-a2b4ac3a5fab-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1117"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fc00a534-2a76-4154-9ec2-79b93266352b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1116"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '271650006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='271650006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-860272ae-ac10-4b84-981c-a2c3466744f6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1115"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufap: value MOET eenheid 'mm[Hg]' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1499efa9-8d9b-4e18-bb8b-8b8ff6d4d8e1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1114"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-447f1e88-4d3b-4b50-bcad-d153c3b264c4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1113"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bd4a55c5-750f-4674-9413-d0438bd69344-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1112"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fa779f07-5db1-4b6d-9557-b487395f3878-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1111"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '883-9' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='883-9' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5433fae9-52af-44bc-87ab-05522add08ea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1110"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AB0BloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AB0BloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set AB0BloodGroup AB0 blood group DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-44e1eb37-cb68-4e82-8ff5-f45c55160667-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1109"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-020d1b97-96f1-489f-a235-b04a8c0cab80-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1108"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c8ac6491-150b-47bc-86a8-6c9114510d1a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1107"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-98172816-3d2a-497b-94a9-0cc683767fe2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1106"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '115758001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-962c9697-d10f-4660-b9cd-0e64a36acbb1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1105"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RhesusDBloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RhesusDBloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set RhesusDBloodGroup Rhesus D Blood Group DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f01cfa7d-713c-4a66-aee7-e3e3ce82b71d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1104"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e281de21-2d8c-4e17-96f8-18b61fc91af3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1103"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-20c1f669-f919-43ab-a633-a2b5f7ae86cc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1102"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@negationInd)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: attribute @negationInd MOET aanwezig zijn. (string-length(@negationInd)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@negationInd='true' or hl7:value"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er irregulaire antistoffen aanwezig zijn moet value een waarde bevatten of moet @nullFlavor="NA" bevatten (@negationInd='true' or hl7:value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-59d4fbf3-c698-4b86-bd92-343b3f7e5777-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1101"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '312457003' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='312457003' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5ec4edf1-7d59-4d25-abc6-49f3a32c75fc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1100"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-BloodGroupAntibodies-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-BloodGroupAntibodies-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set BloodGroupAntibodies Blood Group Antibodies DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8904f8d9-e657-4ef4-b041-9c5bd4f7e496-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1099"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bf5574f8-903f-4764-b7e7-bccdf552e97e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1098"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-720db2cd-b718-4d2f-ac57-3724072d1472-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1097"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47799352-8c8e-4372-8a0c-47a37eba7140-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1096"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '59260-0' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0d7e9e61-4ad6-492e-8e83-e9e059c8a7be-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1095"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-286e96f9-03ab-44ab-a6c8-e74e33c87f96-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1094"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mmol/L' and (matches($theValue, '^[-+]?[0-9]*\.[0-9]{1,1}$'))))"/>
         <xsl:otherwise>
            <xsl:message>acufap: value MOET eenheid 'mmol/L' gebruiken en exact op 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mmol/L' and (matches($theValue, '^[-+]?[0-9]*\.[0-9]{1,1}$')))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7d81791d-49c6-4540-9b3b-c6463b76493e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1093"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f834ff47-ad6e-40e9-b7f0-7796cd89ed0a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1092"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-620ce965-0b6c-4f73-b79c-02f91d19d917-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1091"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b285b0b4-e6d0-441b-a543-c23848f1b32c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1090"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '115758001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ac9cac92-18aa-4613-83cf-46dde2594cc0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:effectiveTime"
                 priority="1089"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9c5097fa-685b-46f7-84f8-a0b42c17f679-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1088"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RhesusCFactor-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RhesusCFactor-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set RhesusCFactor Rhesus C Factor DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1b248bed-cb23-41a5-994d-e164ca9a4d34-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1087"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c1ae3124-a772-4478-8444-f7da56cb0229-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1086"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-008a2587-a65f-4ce6-b164-975e804ea3b8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1085"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9675cbcf-8bf3-4557-90ff-8ef78cfa7bf0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1084"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '165806002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='165806002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a4db2a4a-3d08-4f2b-b9a8-23831233e6f2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1083"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c7d4bd13-5acf-4320-8042-16cb74a37405-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1082"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-de37a884-4835-4609-bfc0-8f01349500e5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1081"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-107d591c-6b06-44bc-b738-343c3f06e265-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer"
                 priority="1080"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='CONTAINER' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'CONTAINER' zijn. (@classCode='CONTAINER' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9bec5766-4a07-4172-bc06-f29568b6b040-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:code"
                 priority="1079"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '248983002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='248983002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d4d58a66-5bde-422c-b4e4-8eed230517b4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1078"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a960e6f-8c38-45af-98a7-fb0dc4fa5938-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1077"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-36f35ad6-fb11-433e-816e-5dc11e963f10-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1076"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fe190137-3446-459f-ad9d-2638108c4098-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1075"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'X_PREGNBR' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-27f6e250-f217-4005-bc48-5e46249d9125-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1074"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2e0831f3-4d91-439a-9e83-6a5c8fbe31da-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1073"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2918797a-08c5-4a07-b388-f40451b852e4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1072"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1c73be62-d797-4fb8-9835-0eac1722e803-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1070"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship is mandatory [min 1x]. (count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fe3ee55a-ea52-4231-b45c-6396a3dae655-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1069"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b318c1f0-2d84-4dc7-94a4-7cabcf9f447f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship"
                 priority="1068"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a02250e3-0f12-452d-b599-f109bcf6a04b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation"
                 priority="1067"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-77370ab9-1c6e-43bc-8d8e-b369a82f44cc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1066"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a0b71616-a6cf-4276-a40b-b4dfa46b48f4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1065"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship
                                component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-570ee1a0-6d6f-4675-8e0c-00e3886ee862-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship"
                 priority="1064"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5f98ad65-116c-465a-9d6d-fd961aad7618-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation"
                 priority="1063"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bebe8701-bb1b-4869-91e8-336e9ab1d992-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1062"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2e5a1610-5978-411d-8a44-bf543ccd952f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1061"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set VILLijst10002000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-001298fd-ace6-4e1b-8d3c-e91cfce0935d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1060"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ad521889-5e60-4674-8f8c-80c35ceac473-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1059"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1d94ed07-77ac-42e1-b2d5-516ffebb76c3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1058"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ecebd2d4-472b-4945-9eef-230df1c6c0b7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1057"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'TypeDeliv' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4df806ea-4ffe-4764-a542-a2c55dafc9d1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1056"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-030adddc-5e04-41ee-ac9f-5bcb6b6252bf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1055"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set TypeBevalling DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2b0e21e0-0d0d-40a5-90e5-878de1a157af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1054"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8faa6119-c488-4037-8c1a-c07bc5788b68-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1053"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3516f7b6-5656-4a4a-88d9-e3e5c115b4d6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1052"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0262392b-febb-45b1-8970-7ba793ee3663-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1051"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='366323009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '366323009' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='366323009' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-38e702a8-b509-4c8e-a034-1dbfb2f91cb8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1050"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufap: value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufap: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b40f14ec-59f4-489a-8882-82f1a63a6a86-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1049"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-48afbeae-fc3f-4d6e-bf2b-c2a49e3846cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1048"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-71b692d7-f720-4e3f-bce6-0c247cf8f948-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1047"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b7786a97-87e5-4507-9473-bfccb3c2df32-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1046"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'PRN520301' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b4f6f817-c87f-4317-998b-a99dc78ef045-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1045"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e8b54bcf-a301-4bee-8dae-8cfb22318632-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1044"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6d73112a-89a1-42b4-9204-8dd08488e068-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1043"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d10dca2a-844d-497d-b194-9efa75022378-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1042"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4d44791f-3445-4acd-a6fd-c4056a8e1d3e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1041"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'PRN530401' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5077c8e7-ba6f-4d99-a3bc-c49a57127961-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1040"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-48e55b37-7397-465d-92a4-028f4de9f6f4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]"
                 priority="1039"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0f6efb7c-4cdd-46f3-bd80-a715f13e0ed4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure"
                 priority="1038"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-71ad72c3-1215-4219-9d7b-3ad69e15df8e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:id"
                 priority="1037"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NI'"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @nullFlavor MOET 'NI' zijn. (@nullFlavor='NI' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-074a8854-dce2-40d6-a613-bf8df01d2fa1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:code"
                 priority="1036"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'Baring' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ac6e41e2-fd15-4dc2-b747-b3174877018c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject"
                 priority="1035"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:personalRelationship is mandatory [min 1x]. (count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:personalRelationship komt te vaak voor [max 1x]. (count(hl7:personalRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-69a0b3da-2ba0-4216-837a-9c3169e4beea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship"
                 priority="1034"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PRS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'PRS' zijn. (@classCode='PRS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fc016f23-b0ba-4da0-a9d1-d9b5edd0d42f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:code"
                 priority="1033"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'CHILD' codeSystem '2.16.840.1.113883.5.111' zijn. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d466ba98-4c3f-4bbc-acd3-cdf5dc090dfe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1032"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ba5168fb-d672-43ba-b922-70b2068ddf37-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd"
                 priority="1031"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-400910ac-141d-4ff9-96e0-72f29d38f8d2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1030"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d57cba4a-1cd3-40df-ad43-caa73f6c4506-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1029"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3dfcf5b8-68f2-4c5d-adbb-d3aed769b5da-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1028"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a9f0bf5a-66f1-41a8-a2bb-d86bca2ca7d3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1027"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'Gravidity' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-79aab2c1-f8a2-40dc-a0d5-a3b6f1126f8c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1026"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75))"/>
         <xsl:otherwise>
            <xsl:message>acufap: value MOET in bereik [0..75] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e96588e5-6f7d-4726-ab07-26215d31fb6a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1025"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c63ea4e6-1448-4f98-bfad-8ed299bb0468-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1024"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f7be3037-5fae-4e66-9611-f9a1ccb2c5b7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1023"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-974cdf4d-d58b-48e9-a8a5-768521e09da6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1022"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'EDD' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fbe21b35-bf63-4cda-9a8b-2ad44520e0e6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1021"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9593e988-20db-475e-b8c9-656884c4d330-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1020"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1686b089-1c6f-4066-a56b-d66f03601ebd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1019"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-38c6f077-4edf-4e6a-a18a-51ce96d554b7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1018"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-30068776-574e-4b4c-8d43-6813203eca2b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1017"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6e36acd2-a32d-4fc3-9003-55607af48e6e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1016"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'EDDBasedOn' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-239342b8-a2bc-454f-9116-e3c54fd303dd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1015"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EDDBasis-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EDDBasis-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code MOET worden gekozen uit Value Set EDDBasis DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f75c69ce-a680-4ca4-9c03-56596c692642-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1014"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2ef4e664-1f30-4226-ab95-e0a119152079-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1013"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c398e394-27f3-456d-bd8d-53520c950af4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1012"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e4434bed-3320-4415-967c-7eb864e53a6d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1011"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET 'ActualEDD' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8483a6a4-f9f6-4899-ab2d-322bde0a1468-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1010"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-365085f2-0de9-4d6c-b20a-a04ce5f51d20-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1009"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5ef124c-5646-4e67-b062-f8fad380f1d7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1008"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-be186e56-487c-4021-8354-e3d6a16f753d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1007"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2c6ca052-4e5e-42fb-8c3a-f579f9416f65-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1006"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @code/@codeSystem MOET 'Parturit' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1ef902f0-24e2-4ee6-b73b-2cb5f9110980-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1005"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=30))"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: value MOET in bereik [1..30] liggen   ((@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=30)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d2637b00-5adf-4de3-8228-f6f1128583cd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1004"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b15dead2-1633-4f7c-8adc-226479ee4592-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1003"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufap: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47a4b10f-0a5e-4a6a-a588-255b5104c28f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1002"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufap: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0f079187-7b26-4611-aa57-5eaa1493a6a1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='224118004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufap: De waarde van @code/@codeSystem MOET '224118004' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='224118004' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f1f536ee-b91d-4948-8b20-ca6e5752884f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.60']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufap: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt;= 0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT.NONNEG: null or value &gt;= 0 (@nullFlavor or @value &gt;= 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufap: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>
</xsl:stylesheet>