<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:peri="urn:nictiz-nl:v3/perinatologie"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <xsl:apply-templates select="/" mode="M43"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN template-2.16.840.1.113883.2.4.6.10.90.61Overdracht Acute Fase bericht (durante partu)-->


	<!--RULE tmp-e3c817fd-962e-4505-883f-74a7665ae697-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']"
                 priority="1351"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:subject is required [min 1x]. (count(hl7:subject)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:subject komt te vaak voor [max 1x]. (count(hl7:subject)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:author is required [min 1x]. (count(hl7:author)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]] is mandatory [min 1x]. (count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&gt;=1 and not(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]] komt te vaak voor [max 1x]. (count(hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=9"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] komt te vaak voor [max 9x]. (count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=9 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5c0d1875-7fe2-42e5-948e-1f9cf6e2206a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.61']"
                 priority="1350"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.90.61'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root MOET de waarde '2.16.840.1.113883.2.4.6.10.90.61' hebben. (@root='2.16.840.1.113883.2.4.6.10.90.61' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-099f33c5-2da1-402f-b3a8-ddc3e183e454-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:id"
                 priority="1349"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a9319e4d-e86d-4ec3-a477-ba745825b545-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:statusCode"
                 priority="1348"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-280994bf-0f25-4fe5-8426-57aee1b22465-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject"
                 priority="1347"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:patient is mandatory [min 1x]. (count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:patient komt te vaak voor [max 1x]. (count(hl7:patient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4b84e482-d476-45b2-845b-9221d9be8ab2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient"
                 priority="1346"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PAT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PAT' zijn. (@classCode='PAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: identification mother requires either a BSN or a local id or both (count(hl7:id)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] is required [min 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:statusCode is mandatory [min 1x]. (count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson)&gt;=1 and not(hl7:patientPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:patientPerson is mandatory [min 1x]. (count(hl7:patientPerson)&gt;=1 and not(hl7:patientPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:patientPerson komt te vaak voor [max 1x]. (count(hl7:patientPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5bf3a691-8112-4f2d-b081-2c73b406ac26-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3'][@root='2.16.840.1.113883.2.4.6.3']"
                 priority="1345"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.BSN: Burgerservicenummer @root MOET 2.16.840.1.113883.2.4.6.3 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.BSN: Burgerservicenummer MOET 9 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or (         (   number(substring(@extension,1,1))*9 )+         (   number(substring(@extension,2,1))*8 )+         (   number(substring(@extension,3,1))*7 )+         (   number(substring(@extension,4,1))*6 )+         (   number(substring(@extension,5,1))*5 )+         (   number(substring(@extension,6,1))*4 )+         (   number(substring(@extension,7,1))*3 )+         (   number(substring(@extension,8,1))*2 )+         (   number(substring(@extension,9,1))*-1) ) mod 11=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-II.NL.BSN: Burgerservicenummer voldoet niet aan modulo 11 proef (not(@root='2.16.840.1.113883.2.4.6.3') or ( ( number(substring(@extension,1,1))*9 )+ ( number(substring(@extension,2,1))*8 )+ ( number(substring(@extension,3,1))*7 )+ ( number(substring(@extension,4,1))*6 )+ ( number(substring(@extension,5,1))*5 )+ ( number(substring(@extension,6,1))*4 )+ ( number(substring(@extension,7,1))*3 )+ ( number(substring(@extension,8,1))*2 )+ ( number(substring(@extension,9,1))*-1) ) mod 11=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (@root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: attribute @extension MOET aanwezig zijn. (string-length(@extension)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47312cc9-0878-4e55-b611-d4c894f5734e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:id"
                 priority="1344"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@root)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: attribute @root MOET aanwezig zijn. (string-length(@root)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: attribute @extension MOET aanwezig zijn. (string-length(@extension)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-65d650af-ea56-4bf3-a643-5b75f795f580-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:addr"
                 priority="1343"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @use='HP' or @use='PHYS' or @use='TMP' or @use='HP PHYS' or @use='TMP PHYS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @use MOET één van de volgende codes bevatten: 'HP', 'PHYS', 'TMP', 'HP PHYS', 'TMP PHYS'. (@nullFlavor or @use='HP' or @use='PHYS' or @use='TMP' or @use='HP PHYS' or @use='TMP PHYS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:postalCode is mandatory [min 1x]. (count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:postalCode komt te vaak voor [max 1x]. (count(hl7:postalCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c36eab85-0d8b-438c-96e5-cbfd4618f628-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:statusCode"
                 priority="1342"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-51f02f2a-675c-4d01-8b16-ddada44670ad-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson"
                 priority="1341"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:deceasedInd/@value='false' or hl7:deceasedTime"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Datum maternale sterfte: if deceasedInd=true an element deceasedTime shall be present (hl7:deceasedInd/@value='false' or hl7:deceasedTime / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name komt te vaak voor [max 2x]. (count(hl7:name)&lt;=2 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:languageCommunication komt te vaak voor [max 1x]. (count(hl7:languageCommunication)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&gt;=1 and not(hl7:deceasedInd/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:deceasedInd is mandatory [min 1x]. (count(hl7:deceasedInd)&gt;=1 and not(hl7:deceasedInd/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:deceasedInd komt te vaak voor [max 1x]. (count(hl7:deceasedInd)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:deceasedTime komt te vaak voor [max 1x]. (count(hl7:deceasedTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:ethnicGroupCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:ethnicGroupCode is required [min 1x]. (count(hl7:ethnicGroupCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:ethnicGroupCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:ethnicGroupCode komt te vaak voor [max 1x]. (count(hl7:ethnicGroupCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47823016-a4a0-4a02-ad8c-391d30c7126c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:name"
                 priority="1340"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @use='OR' or @use='L' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @use MOET één van de volgende codes bevatten: 'OR', 'L'. (@nullFlavor or @use='OR' or @use='L' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9b1d9d2f-d8b6-485e-9367-04e391ae7149-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:birthTime"
                 priority="1339"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-48123621-6fbf-4b1f-81cb-efb3e7df3423-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication"
                 priority="1338"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&gt;=1 and not(hl7:languageCommunication/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:languageCommunication is mandatory [min 1x]. (count(hl7:languageCommunication)&gt;=1 and not(hl7:languageCommunication/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCommunication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:languageCommunication komt te vaak voor [max 1x]. (count(hl7:languageCommunication)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:proficiencyLevelCode)&gt;=1 and not(hl7:proficiencyLevelCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:proficiencyLevelCode is mandatory [min 1x]. (count(hl7:proficiencyLevelCode)&gt;=1 and not(hl7:proficiencyLevelCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:proficiencyLevelCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:proficiencyLevelCode komt te vaak voor [max 1x]. (count(hl7:proficiencyLevelCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bbc470f3-6ab7-44d2-ae0a-c58bdb9c5142-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication/hl7:languageCommunication"
                 priority="1337"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'nl-NL' codeSystem '2.16.840.1.113883.6.121' zijn. (@nullFlavor or (@code='nl-NL' and @codeSystem='2.16.840.1.113883.6.121') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ea27a957-f0ea-4f76-b47a-b1396b66540b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:languageCommunication/hl7:proficiencyLevelCode"
                 priority="1336"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-LanguageAbilityProficiency-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-LanguageAbilityProficiency-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set LanguageAbilityProficiency Language Ability Proficiency DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c2d1d124-defc-4e39-8aeb-6c527113c293-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:deceasedInd"
                 priority="1335"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a662ff81-26d1-45b7-9e8e-53f4979408fc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:deceasedTime"
                 priority="1334"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d121615d-6170-467b-aa1c-523c4209ddd4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:subject/hl7:patient/hl7:patientPerson/hl7:ethnicGroupCode"
                 priority="1333"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EthnicGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EthnicGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set EthnicGroup DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1bc79a60-a137-4ef8-85ac-654a74a0a76f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:performer"
                 priority="1332"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:responsibleParty is mandatory [min 1x]. (count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c6eae62d-07b7-4dfe-a382-9bc8a63dede1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:performer/hl7:responsibleParty"
                 priority="1331"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:agentPerson is mandatory [min 1x]. (count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-af94e991-5d74-4c3c-9c7a-ce3cece7ca43-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:performer/hl7:responsibleParty/hl7:code"
                 priority="1330"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.37')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '2' codeSystem '2.16.840.1.113883.2.4.4.13.37' zijn. (@nullFlavor or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.4.13.37') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-747a532b-3ca3-40cd-a685-45921c0c2012-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:performer/hl7:responsibleParty/hl7:agentPerson"
                 priority="1329"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c1d1475f-ce7c-4cde-97b2-67aae13046d8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:performer/hl7:responsibleParty/hl7:agentPerson/hl7:name"
                 priority="1328"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3be26010-043f-44a6-be02-4514550490f3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author"
                 priority="1327"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:modeCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:modeCode is required [min 1x]. (count(hl7:modeCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:modeCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:modeCode komt te vaak voor [max 1x]. (count(hl7:modeCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:signatureCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:signatureCode is required [min 1x]. (count(hl7:signatureCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:signatureCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:signatureCode komt te vaak voor [max 1x]. (count(hl7:signatureCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:responsibleParty is mandatory [min 1x]. (count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-af527f26-a13e-4d7a-a4e1-0aa66887b7fc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:time"
                 priority="1326"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d9b55f36-77d2-4972-9d70-26ad1e940b09-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:modeCode"
                 priority="1325"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@nullFlavor)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: attribute @nullFlavor MOET aanwezig zijn. (string-length(@nullFlavor)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@code='NA')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van nullFlavor MOET 'NA' zijn. ((@code='NA') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ff533316-d671-431a-aab1-b6662fad0f84-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:signatureCode"
                 priority="1324"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@nullFlavor)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: attribute @nullFlavor MOET aanwezig zijn. (string-length(@nullFlavor)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@code='NA')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van nullFlavor MOET 'NA' zijn. ((@code='NA') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f4e68b4b-179c-4eb7-97ea-4d7b839114a8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty"
                 priority="1323"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:telecom)&gt;=1 and not(hl7:telecom/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:telecom is mandatory [min 1x]. (count(hl7:telecom)&gt;=1 and not(hl7:telecom/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:telecom)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:telecom komt te vaak voor [max 1x]. (count(hl7:telecom)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:agentPerson is mandatory [min 1x]. (count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&gt;=1 and not(hl7:representedOrganization/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:representedOrganization is mandatory [min 1x]. (count(hl7:representedOrganization)&gt;=1 and not(hl7:representedOrganization/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:representedOrganization komt te vaak voor [max 1x]. (count(hl7:representedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3183625f-3e94-4db0-bbe2-a489de845615-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:id"
                 priority="1322"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-67691d29-eb1c-4f67-b72d-d1c141554e81-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:code"
                 priority="1321"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-78b1a3d1-b9c9-4a93-8b12-b009055e4806-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:telecom"
                 priority="1320"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TEL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TEL" bevatten (@nullFlavor or @xsi:type='TEL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6b911da1-4897-4bd5-8879-b8f12d7ea59e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:agentPerson"
                 priority="1319"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35e44b1a-a8d2-4365-8ed4-cbffadf7fc87-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:agentPerson/hl7:name"
                 priority="1318"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6af5cc03-3c94-4147-9b97-e772797ebb89-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization"
                 priority="1317"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:id[@root='2.16.840.1.113883.2.4.6.1']|hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']|hl7:id[@root='2.16.528.1.1007.3.3'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: keuze (hl7:id[@root='2.16.840.1.113883.2.4.6.1'] of hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'] of hl7:id[@root='2.16.528.1.1007.3.3']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6e753ea3-53e5-447e-875f-8182dd03b680-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id"
                 priority="1316"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f3d0ff2e-db09-4c58-bd57-e63f7425b05f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1315"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.AGB: AGB-code @root MOET 2.16.840.1.113883.2.4.6.1 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.AGB: AGB-code moet 8 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (@root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0ccc52f7-302d-4d40-bc6d-66a428046325-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']"
                 priority="1314"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.3.22.98.1'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root MOET de waarde '2.16.840.1.113883.2.4.3.22.98.1' hebben. (@root='2.16.840.1.113883.2.4.3.22.98.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b5f9c8e7-b9ad-499d-b9b8-b4ff8580a7b9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1313"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.URA: UZI-registerabonneenummer @root MOET 2.16.528.1.1007.3.3 zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.URA: UZI-registerabonneenummer MOET 8 cijfers lang zijn (not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (@root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-46379211-e57a-412f-b66f-b8db44a2ca69-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:code"
                 priority="1312"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set ZorgaanbiederType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-934a9ed3-22f6-4444-beff-e7d85c329c0d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:name"
                 priority="1311"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6669ee28-3812-4379-8bd1-96a6f4cd7063-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:author/hl7:responsibleParty/hl7:representedOrganization/hl7:addr"
                 priority="1310"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1e388e06-370f-4be4-986f-bdcd7a575ed9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1309"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-af228aa0-3860-457a-be06-73b55244a7fe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]"
                 priority="1308"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-98492e1b-9ed1-4d7b-b43a-7ecfa50c423a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent"
                 priority="1307"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='COND' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'COND' zijn. (@classCode='COND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6426dd9e-7309-4a1f-9f4b-2c6748ff5706-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent/hl7:id"
                 priority="1306"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3e630fc0-ccc0-4ab6-a706-3fb6c07f3435-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent/hl7:code"
                 priority="1305"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RedenOverdrachtCategorie-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RedenOverdrachtCategorie-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set RedenOverdrachtCategorie Categorie Reden overdracht DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-795f0ff9-7304-453c-a404-88a5990b371a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:reason[hl7:conditionEvent[hl7:code[(@code='38341003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='45757002' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='44247006' and @codeSystem='2.16.840.1.113883.6.96') or (@code='21522001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='???' and @codeSystem='2.16.840.1.113883.6.96') or (@code='288250001' and @codeSystem='2.16.840.1.113883.6.96') or (@code='106004004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='289261003' and @codeSystem='2.16.840.1.113883.6.96') or (@code='276601004' and @codeSystem='2.16.840.1.113883.6.96') or (@code='49333008' and @codeSystem='2.16.840.1.113883.6.96') or (@code='309737007' and @codeSystem='2.16.840.1.113883.6.96') or (@code='87383005' and @codeSystem='2.16.840.1.113883.6.96') or (@code='183695003' and @codeSystem='2.16.840.1.113883.6.96')]]]/hl7:conditionEvent/hl7:text"
                 priority="1304"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-95468a78-9b62-4e11-91b9-8471165af7af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1303"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9646a411-4bdf-4a36-88d3-105c2270cc41-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1302"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35fbbf2e-5b93-4ead-afb3-e214986984d7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1300"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship is mandatory [min 1x]. (count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-82924755-92d2-490e-9a0d-1e95775afc13-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1299"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-54b53940-4b67-4053-894c-670c966de23e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship"
                 priority="1298"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-66ee46e9-c652-460b-b6ea-1195a7b5668b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation"
                 priority="1297"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7d4a1e7f-a453-4eae-80d0-6afd489f08f6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1296"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c39c4398-30c8-4f5a-b61f-128fb60965c9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1295"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship
                                component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d66bcc59-46f3-472a-abda-265d86b76fd4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship"
                 priority="1294"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a1dcdd8d-8d86-4ed6-a3b4-803d4045d69d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation"
                 priority="1293"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4bf27d4d-7bdb-4321-b4f6-ab1ecb8cf8b9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1292"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d47d041c-8e92-4c40-81c7-41f9acd27076-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1291"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set VILLijst10002000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c36ca084-5e09-451f-a87c-b716c2d5a9b7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1290"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-32bed619-ad59-4578-80fa-88a38704efd5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1289"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a3f3edb2-4130-4f7b-a579-838ae0ea5634-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1287"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship is mandatory [min 1x]. (count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9a4bf251-a44b-4048-9c46-fd7d9cf6bb68-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1286"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4e5c4a31-2046-40eb-ab42-a69edeb6c93f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship"
                 priority="1285"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1edebeda-a187-499a-bae3-e41f5c1cb7f7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation"
                 priority="1284"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3a4db2f5-24f8-437f-a357-f850b0a8fdc3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1283"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0ad39651-9166-4c28-956a-4096afc5bf6b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1282"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship
                                component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d287c75e-c5dc-46ab-8977-d0a0284af1ed-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship"
                 priority="1281"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9f00b8ab-4057-4bcf-8389-958a827c3c37-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation"
                 priority="1280"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2a8625e6-748d-42dd-bace-9f030a3b314b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1279"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7248bc2c-b799-43c7-899d-cf5cf926640e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation2[hl7:act[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1278"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst3000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst3000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set VILLijst3000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bb533b16-2663-4aac-a13f-2fcfd41be9e7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1277"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7c42ff48-1749-4aa2-b3a4-6d58ed1de374-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1276"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-29608539-856f-4a07-a31d-01ddfa5b5a77-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1275"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='276987000')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET '276987000' zijn. (@nullFlavor or (@code='276987000') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bc487308-f040-41b9-b7ce-8a1f6a2aeadc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1274"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-66e9a0a6-3759-40d1-9a75-3ecb898fe3b1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1273"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-730c6817-5942-4fbc-9d9b-601f0629731f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1272"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-PerinatalperiodADP-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-PerinatalperiodADP-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set PerinatalperiodADP DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='276987000')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET '276987000' zijn. (@nullFlavor or (@code='276987000') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9bc84801-8a87-4ac9-bd72-956ba194b501-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='373663005' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1269"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='373663005' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '373663005' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='373663005' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-344ab53f-5911-41bc-b824-24afda9a8e50-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1267"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0610c491-32c5-4947-80dc-266c9595aa05-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1266"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8a9bbb38-f9f4-42c0-b0a7-e86c944748cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1265"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-debd6414-9c74-4ecc-a8da-60cd8ea7619c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1264"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='106190000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '106190000' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='106190000' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8d2867cc-10c2-4dc4-a56b-0c5375a5d5cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='106190000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1263"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Allergies-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Allergies-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set Allergies DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8853b0c0-b4c4-4e81-9d6c-6d1c8c75daf2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1262"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-877fb033-a9e7-4a59-b5e5-d7eb6a68980e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1261"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1be9725f-b125-4a2c-9968-e79b6d543a23-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1260"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0c762c11-4aa1-4aae-a693-cf8b8011f458-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1259"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='129019007' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '129019007' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='129019007' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-61e25b2d-2dc4-447d-99d0-2b389d16232f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1258"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f58000e7-8a8b-4e6a-a721-12d0385eb4fd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship"
                 priority="1257"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1192665f-20a0-4ad2-8a60-a67f7b396746-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship"
                 priority="1256"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-138b2022-3d92-4e82-9e24-48fc3e500c9b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration"
                 priority="1255"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='SBADM' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'SBADM' zijn. (@classCode='SBADM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:consumable is mandatory [min 1x]. (count(hl7:consumable)&gt;=1 and not(hl7:consumable/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:consumable komt te vaak voor [max 1x]. (count(hl7:consumable)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9ee5fd8e-9027-4197-9474-399da6ce58e2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable"
                 priority="1254"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='CSM' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'CSM' zijn. (@typeCode='CSM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:manufacturedProduct is required [min 1x]. (count(hl7:manufacturedProduct)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:manufacturedProduct komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-03606438-7f0c-49f2-baf5-eca3acdcd34d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct"
                 priority="1253"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='MANU' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'MANU' zijn. (@classCode='MANU' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:manufacturedProduct is required [min 1x]. (count(hl7:manufacturedProduct)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:manufacturedProduct)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:manufacturedProduct komt te vaak voor [max 1x]. (count(hl7:manufacturedProduct)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ac45041f-f008-407b-b166-907b51fb6575-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct/hl7:manufacturedProduct"
                 priority="1252"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='MMAT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'MMAT' zijn. (@classCode='MMAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='KIND' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @determinerCode SHALL have value 'KIND' STATIC  (@determinerCode='KIND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6def3af5-f8d6-4d8f-a3b5-4ee267003f11-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='129019007' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:inboundRelationship/hl7:substanceAdministration/hl7:consumable/hl7:manufacturedProduct/hl7:manufacturedProduct/hl7:name"
                 priority="1251"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-721366cc-268d-4971-857a-86bd1ce8e537-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]"
                 priority="1250"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-82c9ae34-81d3-439d-ac4a-9ade0be704f2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]"
                 priority="1249"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2915d8fa-f54d-47b9-a876-c3864acb13bc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]/hl7:observation"
                 priority="1248"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6db0413e-2a4f-4d2a-83d8-cc9a4c87ed9b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]/hl7:observation/hl7:code"
                 priority="1247"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'NEGSE' codeSystem '2.16.840.1.113883.3.799.5.1' zijn. (@nullFlavor or (@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-75cb16a3-cb5d-426f-be74-c25b5a300cb1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NEGSE' and @codeSystem='2.16.840.1.113883.3.799.5.1']]]/hl7:observation/hl7:value"
                 priority="1246"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d30e44b1-6380-404d-9774-3276fa5236a8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1245"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7e3de8ae-a2c1-4eae-bfb5-3ced0b3468b5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1244"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b71e8855-0bdc-4a06-bd5c-315cf0388e8b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1243"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d302746d-7b20-4cec-9618-d30cae478406-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1242"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='266096002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '266096002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='266096002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ad13505c-04c1-45d8-a09d-ccbc2b93901c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='266096002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1241"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f96717ef-d712-46b2-9d38-248ed93ac761-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1240"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dc2a9700-9582-4ce2-8dc3-5efd273f075c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1239"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8c0280df-0cc2-4834-8d0d-940d5a9adfc6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1238"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-390b9277-06d0-4f47-ad41-217df87aeabf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1237"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='161664006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '161664006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='161664006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-69157dff-2fe5-4d63-affb-4f00c8ab47a6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='161664006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1236"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-34f76fa8-28fd-478f-8e55-ed664a16e205-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1235"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4b553fc0-a26e-44aa-8ed2-ecdad2a31cdd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1234"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e2cb13d1-96a9-4675-87db-d1a1c719b0e0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1233"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7812d4a5-e78e-4ea7-b9ec-4d39cb4fe66d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1232"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '39156-5' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-49ec87ae-11fd-4bfc-85e3-da4369919fb9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='39156-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1231"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='kg/m2' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'kg/m2' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='kg/m2' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8d871d2d-06c9-4e88-b5af-c51b1e96025e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1230"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bb1f633a-6313-48a1-a947-b4ba761a9cb9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1229"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fc8785c7-2fcd-487e-af13-8b84bd78807a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer"
                 priority="1228"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='CONTAINER' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'CONTAINER' zijn. (@classCode='CONTAINER' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]] is mandatory [min 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&gt;=1 and not(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-73cf15f9-6ca6-4a2d-9333-dcafa17634ec-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:code"
                 priority="1227"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='75367002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '75367002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='75367002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9ebe7a20-c9cb-4535-a1d1-151bcca82c6d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1226"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-400fe5c1-62f3-4695-9390-069e8c32dae8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1225"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fdc0e276-bfe2-4306-94dd-fbc7b51a2088-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1224"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b618bb90-5cdd-4c2e-ac80-1f9277d86336-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1223"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='271649006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '271649006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='271649006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cacf6f1d-488c-440b-a469-2a4073169227-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271649006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1222"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'mm[Hg]' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-94d39c1a-6321-4613-b83a-0172fe9c7baf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1221"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5a5cc67c-178c-466b-bf99-e886a724f8f8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1220"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d4f47fd4-2588-4f1a-9809-638b9de23d52-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1219"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ce2b61ec-83fb-4df7-8342-f91a12497201-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1218"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='271650006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '271650006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='271650006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ee3971cc-f322-41e1-b124-0951ed276830-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='75367002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='271650006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1217"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'mm[Hg]' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fe9942c0-0e4a-4878-abb1-6d58573f4343-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1216"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-32d6208d-ac4d-49b1-baf7-17b0d59e3577-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1215"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9d8b9e46-025e-4bba-b807-03091daa1691-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1214"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f15730d5-d12d-4326-947d-319f6dbb2101-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1213"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='883-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '883-9' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='883-9' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e267237b-e67a-43ae-b9a5-a943028eb6fc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='883-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1212"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AB0BloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AB0BloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set AB0BloodGroup AB0 blood group DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ecaac13d-2306-4372-bf66-3ce553fb296d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1211"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-40cb5ef0-f88d-437d-af49-f35d92157634-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1210"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c0e55e41-5d49-4e5c-9154-33ca8b6d97ad-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1209"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1950b022-fd9a-472d-b191-67be97e3d144-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1208"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '115758001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fa7705ec-d15d-4f99-92c6-822f60c1c919-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1207"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RhesusDBloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RhesusDBloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set RhesusDBloodGroup Rhesus D Blood Group DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-db6ba231-7fde-4929-8ff8-d95746219c28-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1206"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f60f3baf-d65d-4e9e-a425-22e27dc692e1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1205"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-93be20bb-1a5d-485b-b504-0545a8c10ffc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1204"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@negationInd)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: attribute @negationInd MOET aanwezig zijn. (string-length(@negationInd)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@negationInd='true' or hl7:value"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er irregulaire antistoffen aanwezig zijn moet value een waarde bevatten of moet @nullFlavor="NA" bevatten (@negationInd='true' or hl7:value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-663bfbc2-7bb5-49f0-8128-5121ddf7e744-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1203"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='312457003' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '312457003' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='312457003' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2aac080a-0de9-43b0-b00d-eaa5881a0f5c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='312457003' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1202"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-BloodGroupAntibodies-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-BloodGroupAntibodies-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set BloodGroupAntibodies Blood Group Antibodies DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4b405363-ab49-4df4-b81b-0c97ae02a1fd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1201"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1988fb50-c088-4702-b5c3-0e98bab6e4a8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1200"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a6a50e4d-d185-4b15-b0c5-19bf08cf851c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1199"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-52eb97a3-e1f7-49ec-beab-4263ceb9ab2c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1198"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '59260-0' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0da73bd1-b8d5-4604-9749-44e4f0e8df7c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1197"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eb4a17f6-3ef5-47d9-b13a-91d39bd6711a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='59260-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1196"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mmol/L' and (matches($theValue, '^[-+]?[0-9]*\.[0-9]{1,1}$'))))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'mmol/L' gebruiken en exact op 1 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='mmol/L' and (matches($theValue, '^[-+]?[0-9]*\.[0-9]{1,1}$')))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8a6924a7-ba6b-48d6-880f-6c16119fac42-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1195"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-045779ef-c775-4d39-b02c-4b7b46a481aa-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1194"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5ee3b2dd-2399-4e58-8cc6-820b517a6df3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1193"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c02a7bbb-adff-43ab-b262-d1298fc9d372-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1192"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '115758001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-14880aab-6daf-4fb5-bd47-efe3282485d6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:effectiveTime"
                 priority="1191"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cb307985-a1aa-428e-9384-abb937f5ef65-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1190"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RhesusCFactor-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RhesusCFactor-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set RhesusCFactor Rhesus C Factor DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7a4900f6-99d3-4cb1-b596-26c3bfe2d854-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1189"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-478277e4-6131-4903-ad12-b862d937c315-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1188"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-15d47d4e-d740-48a3-a13f-f2e85dee4c32-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1187"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9515d0a1-cea5-4c58-a5d5-170a5477845e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1186"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='165806002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '165806002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='165806002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5cbbc9d7-47f0-4b65-8c9e-10c02cf11e3b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='165806002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1185"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-04b4fdea-ded3-46c8-9366-4512a1246407-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1184"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4b61a75f-ce18-4238-be8c-d7d91062e1e2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1183"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ba3cf23f-e640-4ec6-ada3-1372f9a04edc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer"
                 priority="1182"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='CONTAINER' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'CONTAINER' zijn. (@classCode='CONTAINER' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]] komt te vaak voor [max 1x]. (count(hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d7efd664-7509-4985-b0d6-ce2479527b3b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:code"
                 priority="1181"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='248983002' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '248983002' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='248983002' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d216f119-5089-4fa7-a6a4-4616e9e758c8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1180"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b56f13b3-e85d-47d8-a649-bb1b89c38840-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1179"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3b3a9355-55d5-4b7a-a0f9-ad2f8ddd9321-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1178"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8ad88def-f88f-481f-a5ce-cd26ed112813-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1177"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'X_PREGNBR' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9abfaf3c-4c11-43b3-9018-528bc358892b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='X_PREGNBR' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1176"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f68b0388-9858-4537-92bf-3c458814201a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1175"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b5fb839f-4a1c-40dc-a8b9-81d9ccbe8655-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1174"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dd3aee15-a2b5-4dd3-836e-f9b271656878-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1172"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship is mandatory [min 1x]. (count(hl7:inboundRelationship)&gt;=1 and not(hl7:inboundRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship komt te vaak voor [max 1x]. (count(hl7:inboundRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-03550501-8f84-4eef-9619-daf6ec5e1b37-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1171"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a357aed9-b646-427a-b584-a0c80b9bc356-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship"
                 priority="1170"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ebd77bb2-5523-4d77-8ab0-d3c63a42fc64-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation"
                 priority="1169"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0f23fac0-5c08-4968-9285-5478d2c9dfae-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1168"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7352e97b-8f09-4bd5-a74b-e2140b069416-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1167"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als inboundRelationship component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:inboundRelationship)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:inboundRelationship)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als inboundRelationship
                                component worden meegegeven (@value='true' or count(../hl7:inboundRelationship)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-909620c5-7571-4a98-9812-1541a88d7f52-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship"
                 priority="1166"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-003cbfd4-40c0-45bf-96a4-23feb8e5835b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation"
                 priority="1165"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a668798f-5303-449b-b94c-d0e4cd1020f0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:code"
                 priority="1164"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a683ff76-bbab-4a2a-b0ef-405dbae8ac09-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:act[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:inboundRelationship/hl7:observation/hl7:inboundRelationship/hl7:observation/hl7:value"
                 priority="1163"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set VILLijst10002000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-aa634612-84cb-4420-af36-8c22b4d77b75-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1162"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4d212e14-c18d-4774-821c-20f9fa946960-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1161"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a1692020-0ffb-4698-84b2-7e534ac2b4f3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1160"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eab186df-089b-47d3-8570-159c61a718a2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1159"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'TypeDeliv' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dfa9fdde-01c7-484d-a118-d361094ea0e7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1158"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c69f6d21-39e6-41de-8c9e-0fe9a17dec8c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1157"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set TypeBevalling DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-05ae397d-9fed-41ff-8f56-d74c79f6b7af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1156"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c9fca529-ff0e-4b79-8bd3-2607935caebb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1155"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1abeded9-76a7-4d78-a9fd-af0e27a21667-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1154"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c888c8ce-836a-479b-9226-b534aab98b3a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1153"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='366323009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '366323009' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='366323009' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-386020a6-d267-4061-b835-a17ee6d8e4ca-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='366323009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1152"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='d' and number($theValue)&gt;=0))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'd' gebruiken en in bereik [0..] liggen   ((@nullFlavor or (@unit='d' and number($theValue)&gt;=0)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ed5b9e8d-7433-4f4b-a029-20899b5b0514-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1151"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c6ae75b5-85fb-49ac-a660-611c2c5e583b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1150"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8b1d69e4-82af-4341-b20a-b65ed8a94d83-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1149"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b4b83b3e-07ee-43f2-b77f-ad04288e527b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1148"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN520301' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d177e011-d47e-42da-8bad-2b0a035a1ec5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1147"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4cbc1830-27e2-44a4-ada3-45823b845e6f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1146"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f8cc7e33-6029-41df-a73c-97116884e07f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1145"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-064b8a85-1698-4c9c-a715-9400a9da1207-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1144"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-72b3fa3d-1128-4e8a-9ce4-643db50a8384-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1143"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN530401' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-37c6027d-cca1-44ad-9bd1-ef82c7e281b5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1142"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5d3770c-e832-4ad4-8cea-cd84176086bb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]"
                 priority="1141"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-84aef722-46e3-41f2-8cec-44f7f8413f39-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure"
                 priority="1140"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7efd4ef2-e25f-4d95-aab3-308973c418ac-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:id"
                 priority="1139"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NI'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @nullFlavor MOET 'NI' zijn. (@nullFlavor='NI' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c8b5aa9b-9288-4c13-a52b-1bb0ec9fa54c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:code"
                 priority="1138"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'Baring' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4f03512c-2ac2-40f1-b8e9-3e4db84d2532-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject"
                 priority="1137"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:personalRelationship is mandatory [min 1x]. (count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:personalRelationship komt te vaak voor [max 1x]. (count(hl7:personalRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-56cc70a3-260c-4bdf-bdf6-394ee38ed40e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship"
                 priority="1136"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PRS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PRS' zijn. (@classCode='PRS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ef0f3fb8-7c12-48a7-b030-f6c312815cec-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:code"
                 priority="1135"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'CHILD' codeSystem '2.16.840.1.113883.5.111' zijn. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8c18a969-4ed6-4289-9f01-5d351274d101-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1134"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3a7c8aab-9a39-45fc-a974-e5e6b2f02378-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:organizer[hl7:code[@code='248983002' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:organizer/hl7:component[hl7:procedure[hl7:code[@code = 'Baring']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd"
                 priority="1133"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0ebd02e6-c022-4da6-9be0-1fee9f6897d2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1132"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-edbc44ea-a740-42b0-bc04-3c3f7a484b40-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1131"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e10995a0-4b69-4c88-9961-240936ca51ae-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1130"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-baa9aa78-3e76-47b1-9c88-db96222c59e1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1129"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'Gravidity' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2acf1736-0173-4aca-aba0-ce21124f1c5f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1128"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET in bereik [0..75] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-70228e9e-2121-4634-9c88-1349c15cc53e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1127"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-78d46a28-efc2-4e56-afad-0d4cc584ea7c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1126"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a37e288-8c30-420d-b3b6-0272422171e5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1125"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-07c49448-506e-4eb6-a6ed-ea12fe2cb601-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1124"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'EDD' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6e7cf8d3-c674-4f57-ad30-f821a665114e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1123"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0d4d3103-2474-46db-9d10-fb34039cb51b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1122"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-36ff82d9-9026-4e27-a984-dd7a88480852-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1121"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a9864056-f3aa-4bfe-9dc8-b412c7c339d6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1120"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-11273d00-7aed-4f1a-8faa-baec6e369158-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1119"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3895ec8f-1ca2-4366-8273-85af28f07d59-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1118"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'EDDBasedOn' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-af80dc82-6dd7-4498-9a6c-0b58c4ea4224-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1117"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EDDBasis-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EDDBasis-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set EDDBasis DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7bc909b4-b8a4-497d-877f-189d79228bce-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1116"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-859ae5aa-1d59-48ec-b2c6-b72f183cc53a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1115"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-96d9af9d-ec7b-4e36-9823-675d4d88e744-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1114"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-80ad0052-31c2-408d-8fcd-9f083d0fbf2f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1113"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'ActualEDD' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f3630dc9-d4c5-48a7-a4ea-2eadcfdde10e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1112"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-76ded0c7-4330-4b3f-b73e-4f5f60dbc7aa-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1111"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0b3e6ff7-3e03-4278-97da-8bcd61cd3951-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1110"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ed6e69ff-484d-4132-b013-05cd27d30f15-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1109"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-48898718-0ce4-4e62-8e5f-dd617c3a7101-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1108"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @code/@codeSystem MOET 'Parturit' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1c5369e0-e983-4362-a94e-caac36b28937-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1107"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=30))"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: value MOET in bereik [1..30] liggen   ((@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=30)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-daaa9a50-ccb1-439f-8a43-83e8fdc17496-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1106"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2274842c-3566-4d48-924b-85f09c7289af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1105"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-55618300-d7dc-47a0-a700-9d64f8131ae9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1104"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c697cfd6-10ef-4d2b-9ab0-19b16734b23a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1103"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='224118004' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '224118004' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='224118004' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-177bd24b-744a-48a9-b007-14448827ba2f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='224118004' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1102"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt;= 0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT.NONNEG: null or value &gt;= 0 (@nullFlavor or @value &gt;= 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ec6b686c-642f-4bcd-8825-165553047541-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1101"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bc9884f4-7839-4386-bf96-3483d21dca56-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1100"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4f7d47a5-7ab5-4d86-a279-a373d6ad6bfc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1099"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e4d321db-4e1f-48bd-9de7-d4d994133de2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1098"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'TypeDeliv' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bef47361-155f-4762-a4ae-16e1005913ba-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1097"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cd8ce06f-a096-4794-80f5-c19a5fa3c83c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1096"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set TypeBevalling DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35066dfd-9a1d-417a-af97-4463a9eef9c0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1095"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fa5ecb67-733e-48e9-8056-ca385f8d0405-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1094"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4ff99e92-4b62-43e6-8dcf-1651b1ff3abd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1093"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8c240602-aaaf-4615-8541-a5d325257443-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1092"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN530101' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-54362734-bbe8-4848-a42c-6976a9fc5bb7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1091"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-51667479-49b3-4ebd-97ee-2abd5e8d4e86-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1090"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-25ce5f91-72f8-4ec5-a64c-b0866a897739-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1089"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8f0d2824-7604-47e9-98de-f7fd0fd2da12-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1088"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6df90d43-ae9e-46d8-89d2-c8c625e2007e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1087"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '38386-9' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1e592259-41a4-46f1-be91-acd6c430097b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1086"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-KleurVruchtwater-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-KleurVruchtwater-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set KleurVruchtwater DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9de46eb7-a6f7-4fb3-8f9e-b34ac031ca1b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1085"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7134a549-8d20-47b0-b93f-42c25f26b6b1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1084"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-632d5883-5697-473c-ad40-12fd0c3c3dfd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1083"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:value/@value='true' and hl7:inboundRelationship/@typeCode='COMP'"/>
         <xsl:otherwise>
            <xsl:message>acufdp: If Medicatie nageboortetijdperk = true, a substanceAdministration as a component SHALL
                    be present (hl7:value/@value='true' and hl7:inboundRelationship/@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-09fd79a4-a8e8-42da-9798-f5adc6d46048-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1082"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'Medic3stage' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-32a5d84f-0ad4-4fa6-a73d-fe482369fd8f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1081"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9afe354c-c476-42c3-899d-2b41526cb66b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]"
                 priority="1080"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a6fa2d0c-2418-489f-9475-987d80126e06-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]"
                 priority="1079"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:substanceAdministration)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:substanceAdministration is required [min 1x]. (count(hl7:substanceAdministration)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:substanceAdministration)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:substanceAdministration komt te vaak voor [max 1x]. (count(hl7:substanceAdministration)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35d5d8b8-fe16-4264-ba43-987fee09932d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration"
                 priority="1077"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='SBADM' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'SBADM' zijn. (@classCode='SBADM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:consumable is required [min 1x]. (count(hl7:consumable)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:consumable komt te vaak voor [max 1x]. (count(hl7:consumable)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f223014c-5102-442b-b653-e510a8d3ae8d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable"
                 priority="1076"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='CSM' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'CSM' zijn. (@typeCode='CSM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:medication)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:medication is required [min 1x]. (count(hl7:medication)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:medication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:medication komt te vaak voor [max 1x]. (count(hl7:medication)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-58b4ceb4-1aca-487f-8c97-6f08193b17eb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable/hl7:medication"
                 priority="1075"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ADMM' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'ADMM' zijn. (@classCode='ADMM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administerableMedicine)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:administerableMedicine is required [min 1x]. (count(hl7:administerableMedicine)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administerableMedicine)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:administerableMedicine komt te vaak voor [max 1x]. (count(hl7:administerableMedicine)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-406dbb61-baa4-4b27-ae56-ef4573e258c7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable/hl7:medication/hl7:administerableMedicine"
                 priority="1074"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='MMAT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'MMAT' zijn. (@classCode='MMAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='KIND' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @determinerCode SHALL have value 'KIND' STATIC  (@determinerCode='KIND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-235ffad1-f916-4d4a-87d1-d894e39fd92c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:inboundRelationship[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable/hl7:medication/hl7:administerableMedicine/hl7:code"
                 priority="1073"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-SoortMedNageboorte-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-SoortMedNageboorte-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set SoortMedNageboorte DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8def595b-064e-41b8-be93-65347baa77d4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1072"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2cc7a69c-052e-4af9-87ac-7a9cced05835-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1071"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b71be257-1f3a-47cf-b36c-4ad583d688d3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1070"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a89da403-1123-457b-bf9b-bf6a33759aef-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1069"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'AfterBirthMethod' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0a3c0994-dde3-447e-83a2-0796f3d5e9fb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1068"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-GeboortePlacenta-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-GeboortePlacenta-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set GeboortePlacenta DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-673c1822-7c64-47d0-908b-55156745bbda-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1067"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e926a1b1-a1d0-45de-9887-697ec3268b3f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1066"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-93eece2a-5533-42f5-a500-523e9bf2bacc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1065"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-02c25da7-0616-4d42-8859-07c50699d8d9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1064"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364343000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '364343000' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='364343000' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5762f27-d360-4889-840b-86456316789f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='364343000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1063"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Completenessplacenta-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Completenessplacenta-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set Completenessplacenta Completeness placenta DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bfd34e43-8281-4701-a66b-94a8965464e1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1062"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f75c94f8-8b68-48d5-8c5e-1c5a59f6ded2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1061"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3c9cd899-a1e8-4ce0-8eea-887379f550e2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1060"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-99264f44-a2c0-4b28-8330-6ee0ec7a40a5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1059"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN5703' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ece406e6-3719-4562-8df6-3cee36da5040-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1058"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='ml'))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'ml' gebruiken  ((@nullFlavor or (@unit='ml')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d2217731-5ee7-4e2a-85c4-aed13f221855-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1057"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='false' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'false' STATIC  (@contextConductionInd='false' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-532f5ba6-c5b1-43ea-aa9b-ac5589ddfdbb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1056"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='false' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @contextConductionInd SHALL have value 'false' STATIC  (@contextConductionInd='false' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2860e5b4-afa1-4fd9-a6c7-03de6a839acb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1055"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-aa5f15a4-2e2a-4c09-bd91-e78425439d5e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:id"
                 priority="1054"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0a702c38-d79d-4d67-8e6c-653d4b3af6fb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1053"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'Baring' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e20f5137-b9a8-40f9-a95a-83717949ceeb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject"
                 priority="1052"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:personalRelationship is mandatory [min 1x]. (count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:personalRelationship komt te vaak voor [max 1x]. (count(hl7:personalRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7a6c05fc-96e5-49d4-83dc-76a86c364341-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship"
                 priority="1051"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PRS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PRS' zijn. (@classCode='PRS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-19d52076-8476-403a-ac2d-bf541f996568-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:code"
                 priority="1050"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'CHILD' codeSystem '2.16.840.1.113883.5.111' zijn. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0db67a10-7536-487d-b0cd-fb5564d09408-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1049"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:deceasedInd/@value='false' or hl7:deceasedTime"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Datum perinatale sterfte: if deceasedInd=true an element deceasedTime shall be
                                present (hl7:deceasedInd/@value='false' or hl7:deceasedTime / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:deceasedInd komt te vaak voor [max 1x]. (count(hl7:deceasedInd)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:deceasedTime komt te vaak voor [max 1x]. (count(hl7:deceasedTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b2bd4c60-27a8-4950-baf0-806b75dd05f7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:birthTime"
                 priority="1048"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fc04624b-aee7-494e-a58d-4622ae873409-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd"
                 priority="1047"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d5a92a24-eb03-4737-aa8d-d39eae307a2e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedTime"
                 priority="1046"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ef69030f-f40a-4aee-8926-8ffe1cfa488f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1045"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-58e0e012-d5c4-4ee2-a604-636e86152e2d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1044"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0222a96d-8431-46c7-b9c6-14314ce6cf3a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1043"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ea59bb66-d520-4081-b5c6-441b62dad02d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1042"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '46098-0' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b57ca38f-7610-4c5e-97d2-888d499f72af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1041"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-GenderMedisch-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-GenderMedisch-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set GenderMedisch DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8dfd8d28-5a76-4a3b-94b1-78ae07a48607-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1040"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-499debd7-71ef-4e2e-95aa-f020e2fbb135-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1039"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c11d4d3c-ed3d-46cf-9096-50e018880def-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation"
                 priority="1038"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0fcb52eb-f5bb-492f-827a-cd8d8aebd99d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:code"
                 priority="1037"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '115758001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='115758001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c1320b5a-781d-449f-8e57-1f0aacd959bd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='115758001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:observation/hl7:value"
                 priority="1036"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RhesusDBloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RhesusDBloodGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set RhesusDBloodGroup Rhesus D Blood Group DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8450327e-779e-4423-a31f-103886c73342-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1035"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-93bc84e4-dd36-4473-b631-857ddfa99f05-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1034"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6793d3c0-1dc5-4a5b-9bc2-72ccbd4cdb47-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1033"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:text is required [min 1x]. (count(hl7:text)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:text)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:text komt te vaak voor [max 1x]. (count(hl7:text)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35b11b6d-3fda-4bdb-a16b-6cce73ded41e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1032"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'GUOFind' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-616e94cd-9dcc-4eda-a78c-85096f7010bc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='GUOFind' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:text"
                 priority="1031"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ST' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ST" bevatten (@nullFlavor or @xsi:type='ST' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length(.)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-BIN: there must be a nullFlavor, or text must be non-empty (@nullFlavor or string-length(.)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or text() or hl7:reference"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ED: content is required if not null (@nullFlavor or text() or hl7:reference / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:integrityCheck) or @integrityCheckAlgorithm"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ED: integrityCheckAlgorithm required if integrityCheck (not(hl7:integrityCheck) or @integrityCheckAlgorithm / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-ED: thumbnails do not use reference (not(hl7:thumbnail) or hl7:thumbnail[not(@nullFlavor and hl7:reference)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-ED: thumbnails do not have thumbnails (not(hl7:thumbnail) or hl7:thumbnail[not(hl7:thumbnail)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-ED: compression only on binary ((@compression and (hl7:reference/@value or (@representation='B64' and text()))) or not(@compression) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-ED: value implies mediaType is text/plain (not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-ED: no history or updateMode (count(*[self::hl7:reference or self::hl7:thumbnail][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@value or xml) or not(@charset)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-ED: no charset for value or xml (not(@value or xml) or not(@charset) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-ED: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-ED: no mediaType if null (not(@nullFlavor) or (@nullFlavor and not(@mediaType)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@charset))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-ED: no charset if null (not(@nullFlavor) or (@nullFlavor and not(@charset)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@language))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-ED: no language if null (not(@nullFlavor) or (@nullFlavor and not(@language)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@compression))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-ED: no compression if null (not(@nullFlavor) or (@nullFlavor and not(@compression)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-ED: no integrityCheck if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheck)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-15-ED: no integrityCheckAlgorithm if null (not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-16-ED: no thumbnail if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:thumbnail/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-17-ED: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation) or hl7:thumbnail[not(hl7:translation)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ST: no nested translations (not(hl7:translation) or hl7:thumbnail[not(hl7:translation)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text())))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ST: null or content ((@nullFlavor and empty(text())) or (not(@nullFlavor) and not(empty(text()))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fdf5aeaf-bfb3-432c-a557-2845b38bffcb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1030"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bf71ca98-a1e1-4464-ae2b-49c9fb1616bd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1029"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a11c063-f6cd-4468-9dce-2eafb98e849f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1028"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e94ad8e4-a707-4c7e-88c6-6f5b902800f1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1027"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN530401' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d7eb1865-0d5f-42db-be30-829f682d0de3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1026"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5ee5aa8b-1cf2-4e7d-9099-ecfa51f38b51-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1025"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1b99675b-cfd4-4ea6-9a28-427234350f5c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1024"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-87d443d7-5198-437c-86fa-a2eb99513a9d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1023"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6a13792f-0de0-4504-ba56-cf38a1caafb5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1022"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN5704' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8e85734d-9dbd-4139-a6fc-93befe474900-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1021"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ConditiePerineum-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ConditiePerineum-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set ConditiePerineum DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9fde694f-60e2-4a93-87bf-f875812026a1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1020"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1c816195-6bc6-4e8e-90c6-6da40deca991-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1019"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-85ea5733-cdaa-41f6-86e0-70f4b56485da-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1018"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c523142d-4d8f-4cf5-b37b-a004ef2fd84b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1017"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '8339-4' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3da3a3fc-2824-4e3f-b58d-dd15752263ff-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1016"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches($theValue, '^[-+]?[0-9]*$'))))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET eenheid 'g' gebruiken en in bereik [0..] liggen  en tot op minst 0 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches($theValue, '^[-+]?[0-9]*$')))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d0242cfe-0e81-40c9-9a31-1eb0d12ef1bc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1015"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4099eb68-1172-44c2-841b-20a14a3c5c23-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1014"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-91e00c57-74e6-487a-8ca3-3fe1d71fc937-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1013"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-71bef717-9bd8-4a73-bc0c-40e511ead52a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1012"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET '9274-2' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ffd432a8-694c-41e5-a978-6df3b3c4bd34-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1011"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10))"/>
         <xsl:otherwise>
            <xsl:message>acufdp: value MOET in bereik [0..10] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>acufdp: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0bbed2e3-af8a-4a6d-8c1c-53a50a6fa057-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1010"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-49cf79c7-5b92-42ca-a1d6-28c6278e988f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1009"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-39a9f2ac-a1f8-4c31-960a-44828bbd9cb7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1008"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-90f51da4-36a6-4c8f-ad42-1c0f5be9ad7d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1007"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'CongMalf' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-424dfd48-0789-48fd-a51c-6cceaf587d27-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:uncertaintyCode"
                 priority="1006"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-UncertaintyCode-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-UncertaintyCode-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set UncertaintyCode DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-80b8a1cc-3f6f-4b26-872e-6d45bb8027e0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1005"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-CongenitaleAfwijkingen-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-CongenitaleAfwijkingen-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set CongenitaleAfwijkingen DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fd305e7d-d0a9-4f5a-b793-e265fcc1bedc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1004"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5d8a06f3-1fa7-42df-b9aa-4c97a1f73586-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1003"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e3af3933-e3fd-40c7-975a-dfe2f409d137-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1002"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>acufdp: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e189216f-c029-4153-af05-2c04906d6076-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1001"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code/@codeSystem MOET 'PRN810201' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b336b8de-47fd-4eaf-a427-d498c63161ff-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.61']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:inboundRelationship[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1000"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>acufdp: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-FasePerinatSterfte-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-FasePerinatSterfte-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>acufdp: De waarde van @code MOET worden gekozen uit Value Set FasePerinatSterfte DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>
</xsl:stylesheet>