<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:peri="urn:nictiz-nl:v3/perinatologie"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <xsl:apply-templates select="/" mode="M43"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN template-2.16.840.1.113883.2.4.6.10.90.1Jonge zwangerschapsecho (JZE)-->


	<!--RULE tmp-f1c57b4a-436a-48e8-a953-e685e9e92704-->
<xsl:template match="//hl7:ClinicalDocument" priority="1061" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:realmCode)&gt;=1 and not(hl7:realmCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:realmCode is mandatory [min 1x]. (count(hl7:realmCode)&gt;=1 and not(hl7:realmCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:realmCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:realmCode komt te vaak voor [max 1x]. (count(hl7:realmCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:typeId[@root='2.16.840.1.113883.1.3'])&gt;=1 and not(hl7:typeId[@root='2.16.840.1.113883.1.3']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:typeId[@root='2.16.840.1.113883.1.3'] is mandatory [min 1x]. (count(hl7:typeId[@root='2.16.840.1.113883.1.3'])&gt;=1 and not(hl7:typeId[@root='2.16.840.1.113883.1.3']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:typeId[@root='2.16.840.1.113883.1.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:typeId[@root='2.16.840.1.113883.1.3'] komt te vaak voor [max 1x]. (count(hl7:typeId[@root='2.16.840.1.113883.1.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:title)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:title komt te vaak voor [max 1x]. (count(hl7:title)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 and not(hl7:effectiveTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:effectiveTime is mandatory [min 1x]. (count(hl7:effectiveTime)&gt;=1 and not(hl7:effectiveTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:confidentialityCode)&gt;=1 and not(hl7:confidentialityCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:confidentialityCode is mandatory [min 1x]. (count(hl7:confidentialityCode)&gt;=1 and not(hl7:confidentialityCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:confidentialityCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:confidentialityCode komt te vaak voor [max 1x]. (count(hl7:confidentialityCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCode)&gt;=1 and not(hl7:languageCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:languageCode is mandatory [min 1x]. (count(hl7:languageCode)&gt;=1 and not(hl7:languageCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:languageCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:languageCode komt te vaak voor [max 1x]. (count(hl7:languageCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:setId)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:setId komt te vaak voor [max 1x]. (count(hl7:setId)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:versionNumber)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:versionNumber komt te vaak voor [max 1x]. (count(hl7:versionNumber)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:recordTarget)&gt;=1 and not(hl7:recordTarget/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:recordTarget is mandatory [min 1x]. (count(hl7:recordTarget)&gt;=1 and not(hl7:recordTarget/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:recordTarget)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:recordTarget komt te vaak voor [max 1x]. (count(hl7:recordTarget)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:author is mandatory [min 1x]. (count(hl7:author)&gt;=1 and not(hl7:author/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:custodian)&gt;=1 and not(hl7:custodian/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:custodian is mandatory [min 1x]. (count(hl7:custodian)&gt;=1 and not(hl7:custodian/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:custodian)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:custodian komt te vaak voor [max 1x]. (count(hl7:custodian)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:legalAuthenticator)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:legalAuthenticator komt te vaak voor [max 1x]. (count(hl7:legalAuthenticator)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relatedDocument)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:relatedDocument komt te vaak voor [max 1x]. (count(hl7:relatedDocument)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:documentationOf)&gt;=1 and not(hl7:documentationOf/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:documentationOf is mandatory [min 1x]. (count(hl7:documentationOf)&gt;=1 and not(hl7:documentationOf/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:documentationOf)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:documentationOf komt te vaak voor [max 1x]. (count(hl7:documentationOf)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f4367da3-a1cb-4b90-9bdb-b349e281b462-->
<xsl:template match="//hl7:ClinicalDocument/hl7:realmCode" priority="1060" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NL')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code MOET 'NL' zijn. (@nullFlavor or (@code='NL') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f38a9e4a-f481-47ea-ad5f-5a130c879dba-->
<xsl:template match="//hl7:ClinicalDocument/hl7:typeId[@root='2.16.840.1.113883.1.3']"
                 priority="1059"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@extension='POCD_HD000040'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @extension MOET 'POCD_HD000040' zijn. (@extension='POCD_HD000040' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.1.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.840.1.113883.1.3' hebben. (@root='2.16.840.1.113883.1.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-804d2271-38b7-43fa-9907-233effe2bd2f-->
<xsl:template match="//hl7:ClinicalDocument/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.1']"
                 priority="1058"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.90.1'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.840.1.113883.2.4.6.10.90.1' hebben. (@root='2.16.840.1.113883.2.4.6.10.90.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f9c0a208-efe1-4734-8eb9-5b4ea4b7e638-->
<xsl:template match="//hl7:ClinicalDocument/hl7:id" priority="1057" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-57d1ec57-f4e7-493b-8261-1dfb149410fd-->
<xsl:template match="//hl7:ClinicalDocument/hl7:code" priority="1056" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11525-3' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code/@codeSystem MOET '11525-3' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='11525-3' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-043fb4bd-d930-406e-929d-825c5010656b-->
<xsl:template match="//hl7:ClinicalDocument/hl7:effectiveTime" priority="1055" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{14,14}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATETIME.MIN: null or date precision of time stamp shall be at least YYYYMMDDhhmmss. (@nullFlavor or matches(@value, '^[0-9]{14,14}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8a9b2625-bde6-4de0-902a-30a9dcd47ff0-->
<xsl:template match="//hl7:ClinicalDocument/hl7:confidentialityCode" priority="1054"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Confidentiality-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Confidentiality-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code MOET worden gekozen uit Value Set Confidentiality DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47a079a7-d7d8-430e-8dbb-226f9cb29eec-->
<xsl:template match="//hl7:ClinicalDocument/hl7:languageCode" priority="1053" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1197955b-3902-45e6-b198-b37413c20c5e-->
<xsl:template match="//hl7:ClinicalDocument/hl7:setId" priority="1052" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1ebacf58-abc1-470a-8089-8b12d29aecc4-->
<xsl:template match="//hl7:ClinicalDocument/hl7:versionNumber" priority="1051" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt;= 0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT.NONNEG: null or value &gt;= 0 (@nullFlavor or @value &gt;= 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1))"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): value MOET in bereik [1..] liggen   ((@nullFlavor or (number($theValue)&gt;=1)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(../hl7:setId and ../hl7:versionNumber) or not (../hl7:setId or ../hl7:versionNumber)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Clinical Document setId and versionNumber must be both present or
                        both absent ((../hl7:setId and ../hl7:versionNumber) or not (../hl7:setId or ../hl7:versionNumber) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-817f3f6d-570f-4e60-b509-59c223fa195e-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget" priority="1050" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RCT' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'RCT' zijn. (@typeCode='RCT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientRole)&gt;=1 and not(hl7:patientRole/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:patientRole is mandatory [min 1x]. (count(hl7:patientRole)&gt;=1 and not(hl7:patientRole/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patientRole)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:patientRole komt te vaak voor [max 1x]. (count(hl7:patientRole)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c2bc8eef-e59b-4b71-b4c2-e5035b675511-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole" priority="1049"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PAT' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'PAT' zijn. (@classCode='PAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 and not(hl7:id[@root='2.16.840.1.113883.2.4.6.3']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] is mandatory [min 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 and not(hl7:id[@root='2.16.840.1.113883.2.4.6.3']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:addr komt te vaak voor [max 2x]. (count(hl7:addr)&lt;=2 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:patient is mandatory [min 1x]. (count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:patient komt te vaak voor [max 1x]. (count(hl7:patient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1d44990b-01d2-42f9-91d6-a795a118a4ea-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"
                 priority="1048"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (@root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b4b44b9c-940a-4578-a1ef-9eaf5c40ecba-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:addr"
                 priority="1047"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@use) or string-length(normalize-space(replace (@use, 'HP|PHYS|TMP', '')))=0"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Attribute @use of addr SHALL contain codes HP PHYS PST or TMP
                                only (not(@use) or string-length(normalize-space(replace (@use, 'HP|PHYS|TMP', '')))=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="../hl7:addr[@use='HP' or @use='TMP PHYS']"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Addr SHALL be present with @use HP or TMP PHYS or both (../hl7:addr[@use='HP' or @use='TMP PHYS'] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2fe301a0-5ad3-46d4-a388-18b5d5da4862-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:telecom"
                 priority="1046"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TEL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TEL" bevatten (@nullFlavor or @xsi:type='TEL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e1798753-4cf4-46c1-aaaf-cc9bd2f6305d-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:patient"
                 priority="1045"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name komt te vaak voor [max 2x]. (count(hl7:name)&lt;=2 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:administrativeGenderCode komt te vaak voor [max 1x]. (count(hl7:administrativeGenderCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dca71423-07ee-4842-9a94-0f2433090e71-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name"
                 priority="1044"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-aa2b9fe9-ecdb-4865-bad0-7175285746d1-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:administrativeGenderCode"
                 priority="1043"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code MOET worden gekozen uit Value Set AdministrativeGender DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a78e06cb-9ea8-495f-96db-4c78478b6b34-->
<xsl:template match="//hl7:ClinicalDocument/hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:birthTime"
                 priority="1042"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b55b8a3d-7b13-4a05-957a-95392123656d-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author" priority="1041" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:time is mandatory [min 1x]. (count(hl7:time)&gt;=1 and not(hl7:time/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:time)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:time komt te vaak voor [max 1x]. (count(hl7:time)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor)&gt;=1 and not(hl7:assignedAuthor/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedAuthor is mandatory [min 1x]. (count(hl7:assignedAuthor)&gt;=1 and not(hl7:assignedAuthor/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedAuthor)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedAuthor komt te vaak voor [max 1x]. (count(hl7:assignedAuthor)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e9ef1828-05f5-4def-9796-5141596e1cec-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:time" priority="1040" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dce99e30-f8ef-4d85-adbf-223c3e1b6a24-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor" priority="1039"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.1'])&gt;=1 and not(hl7:id[@root='2.16.528.1.1007.3.1']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.1'] is mandatory [min 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.1'])&gt;=1 and not(hl7:id[@root='2.16.528.1.1007.3.1']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.1'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.1'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.1'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedPerson komt te vaak voor [max 1x]. (count(hl7:assignedPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:representedOrganization komt te vaak voor [max 1x]. (count(hl7:representedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-338b9719-e012-4799-9275-c36bdad3b898-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:id[@root='2.16.528.1.1007.3.1']"
                 priority="1038"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.1'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.528.1.1007.3.1' hebben. (@root='2.16.528.1.1007.3.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9544f147-1afe-4562-9991-6c74ab9d76d6-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:code"
                 priority="1037"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-084fc768-33ee-4f8f-a30f-2fc71e47adc1-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:assignedPerson"
                 priority="1036"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-81048dbf-4887-4957-88d0-086a29a6d936-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:assignedPerson/hl7:name"
                 priority="1035"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2996a5cd-bf32-443e-ba17-7dd3d7cd7022-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:representedOrganization"
                 priority="1034"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.3'])&gt;=1 and not(hl7:id[@root='2.16.528.1.1007.3.3']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.3'] is mandatory [min 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.3'])&gt;=1 and not(hl7:id[@root='2.16.528.1.1007.3.3']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b4d429eb-6acd-4b58-9118-428c7e9fcf41-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1033"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (@root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-710d04e9-4197-42d1-a416-8206ca5e65e4-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:name"
                 priority="1032"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e0ffe056-7a78-4da4-85d2-48a777ac028b-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr"
                 priority="1031"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b208a1e7-71b9-4d66-9d8e-91a52ef9c4ee-->
<xsl:template match="//hl7:ClinicalDocument/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:telecom"
                 priority="1030"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TEL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TEL" bevatten (@nullFlavor or @xsi:type='TEL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-38861ee9-602a-4421-bbfa-90eb5b432ae2-->
<xsl:template match="//hl7:ClinicalDocument/hl7:custodian" priority="1029" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='CST' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'CST' zijn. (@typeCode='CST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedCustodian)&gt;=1 and not(hl7:assignedCustodian/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedCustodian is mandatory [min 1x]. (count(hl7:assignedCustodian)&gt;=1 and not(hl7:assignedCustodian/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedCustodian)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedCustodian komt te vaak voor [max 1x]. (count(hl7:assignedCustodian)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-70c6676d-88b8-4a09-998a-42bff42cabd7-->
<xsl:template match="//hl7:ClinicalDocument/hl7:custodian/hl7:assignedCustodian"
                 priority="1028"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedCustodianOrganization)&gt;=1 and not(hl7:representedCustodianOrganization/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:representedCustodianOrganization is mandatory [min 1x]. (count(hl7:representedCustodianOrganization)&gt;=1 and not(hl7:representedCustodianOrganization/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedCustodianOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:representedCustodianOrganization komt te vaak voor [max 1x]. (count(hl7:representedCustodianOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7fd3da48-06c0-452d-bf2d-d83be68cbc60-->
<xsl:template match="//hl7:ClinicalDocument/hl7:custodian/hl7:assignedCustodian/hl7:representedCustodianOrganization"
                 priority="1027"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.3'])&gt;=1 and not(hl7:id[@root='2.16.528.1.1007.3.3']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.3'] is mandatory [min 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.3'])&gt;=1 and not(hl7:id[@root='2.16.528.1.1007.3.3']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a3a5fabd-db9b-4811-a9d7-45adaa8ef6df-->
<xsl:template match="//hl7:ClinicalDocument/hl7:custodian/hl7:assignedCustodian/hl7:representedCustodianOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1026"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (@root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3446c774-9efc-45fb-97bb-f7cdfaa154a5-->
<xsl:template match="//hl7:ClinicalDocument/hl7:informationRecipient" priority="1025"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRCP' or @typeCode='TRC' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET één van de volgende codes bevatten: 'PRCP', 'TRC'. (@typeCode='PRCP' or @typeCode='TRC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:intendedRecipient)&gt;=1 and not(hl7:intendedRecipient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:intendedRecipient is mandatory [min 1x]. (count(hl7:intendedRecipient)&gt;=1 and not(hl7:intendedRecipient/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:intendedRecipient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:intendedRecipient komt te vaak voor [max 1x]. (count(hl7:intendedRecipient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-71673f19-6a0a-4890-bf9e-675691d7a934-->
<xsl:template match="//hl7:ClinicalDocument/hl7:informationRecipient/hl7:intendedRecipient"
                 priority="1024"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:informationRecipient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:informationRecipient komt te vaak voor [max 1x]. (count(hl7:informationRecipient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:receivedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:receivedOrganization komt te vaak voor [max 1x]. (count(hl7:receivedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2c598fd4-360d-43b2-9165-964280e2b03e-->
<xsl:template match="//hl7:ClinicalDocument/hl7:informationRecipient/hl7:intendedRecipient/hl7:informationRecipient"
                 priority="1023"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2ad7407d-cc90-4c35-a8e0-db7fc2669bf6-->
<xsl:template match="//hl7:ClinicalDocument/hl7:informationRecipient/hl7:intendedRecipient/hl7:receivedOrganization"
                 priority="1022"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.528.1.1007.3.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.528.1.1007.3.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8de77ef1-6c37-4ff3-8520-dcd2f8e54960-->
<xsl:template match="//hl7:ClinicalDocument/hl7:informationRecipient/hl7:intendedRecipient/hl7:receivedOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1021"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (@root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-16160d14-ee23-4e8b-a22e-c78732cdc957-->
<xsl:template match="//hl7:ClinicalDocument/hl7:authenticator" priority="1020" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUTHEN' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'AUTHEN' zijn. (@typeCode='AUTHEN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-35496b40-b95a-4e27-bb8d-4fd12974df33-->
<xsl:template match="//hl7:ClinicalDocument/hl7:legalAuthenticator" priority="1019"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextControlCode='OP' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @contextControlCode MOET 'OP' zijn. (@contextControlCode='OP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='LA' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'LA' zijn. (@typeCode='LA' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e206d21f-8062-4da5-8906-04b504a00f5f-->
<xsl:template match="//hl7:ClinicalDocument/hl7:relatedDocument" priority="1018" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RPLC' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'RPLC' zijn. (@typeCode='RPLC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-17e6b033-949e-4942-a321-e5d8e589458b-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf" priority="1017" mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='DOC' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'DOC' zijn. (@typeCode='DOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:serviceEvent)&gt;=1 and not(hl7:serviceEvent/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:serviceEvent is mandatory [min 1x]. (count(hl7:serviceEvent)&gt;=1 and not(hl7:serviceEvent/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:serviceEvent)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:serviceEvent komt te vaak voor [max 1x]. (count(hl7:serviceEvent)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f07d8b64-2961-4d69-af05-64ef2de616ab-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent"
                 priority="1016"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:performer is required [min 1x]. (count(hl7:performer)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e133ebe3-5a19-4ef4-a644-a32b947ace47-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:id"
                 priority="1015"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-40d71493-8a64-4603-86fd-c4c484079bd3-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:code"
                 priority="1014"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-TypeExam-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-TypeExam-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code MOET worden gekozen uit Value Set TypeExam DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-44949941-534e-4dd5-9483-8a6aba600e28-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:effectiveTime"
                 priority="1013"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0bdcd59c-b1ae-439d-99ac-986cf6b9b9d1-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer"
                 priority="1012"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedEntity is required [min 1x]. (count(hl7:assignedEntity)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedEntity komt te vaak voor [max 1x]. (count(hl7:assignedEntity)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a31ea9d8-d733-4c83-b974-51a73d196b79-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity"
                 priority="1011"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedPerson)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedPerson is required [min 1x]. (count(hl7:assignedPerson)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:assignedPerson komt te vaak voor [max 1x]. (count(hl7:assignedPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:representedOrganization is required [min 1x]. (count(hl7:representedOrganization)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:representedOrganization komt te vaak voor [max 1x]. (count(hl7:representedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-691c3048-163b-464a-ac98-76cfc53d727f-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:id[@root='2.16.528.1.1007.3.1']"
                 priority="1010"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.1'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.528.1.1007.3.1' hebben. (@root='2.16.528.1.1007.3.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4186efaa-7c19-4c0c-a0e5-ab0332fbee58-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1009"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (@root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7796f77e-efff-4edc-b987-247f493803a4-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:code"
                 priority="1008"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bb993e96-d63b-4638-a66e-48b361b65048-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:addr"
                 priority="1007"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-705e4bbb-b9a5-44e5-8e20-755411528d1c-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:telecom"
                 priority="1006"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TEL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TEL" bevatten (@nullFlavor or @xsi:type='TEL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="urlScheme" select="substring-before(@value,':')"/>
      <xsl:variable name="urlStr" select="substring-after(@value,':')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-URL: elements of type URL SHALL have a @value attribute. (@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value=iri-to-uri(@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-URL: @value must be a valid URI, e.g. '<xsl:text/>
               <xsl:value-of select="iri-to-uri(@value)"/>
               <xsl:text/>'. (@value=iri-to-uri(@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor and hl7:usablePeriod)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TEL: not null and usablePeriod (not(@nullFlavor and hl7:usablePeriod) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-940f18d6-5137-4200-896b-767d36259776-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:assignedPerson"
                 priority="1005"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0255986c-8e3b-4170-ae6e-92dd6824298d-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:assignedPerson/hl7:name"
                 priority="1004"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-617c6594-d2ef-47ce-84df-0731a9ec46e6-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:representedOrganization"
                 priority="1003"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.1'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:id[@root='2.16.840.1.113883.2.4.6.1'] is required [min 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.1'])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): element hl7:addr is required [min 1x]. (count(hl7:addr)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0712e3f9-64f4-439a-90ff-11f5b0ecf109-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1002"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (@root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-00a6e7a5-97e9-4551-8345-d85027f304eb-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:representedOrganization/hl7:name"
                 priority="1001"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a1f4f5c0-7dd7-435f-91d9-81367c884dbe-->
<xsl:template match="//hl7:ClinicalDocument/hl7:documentationOf/hl7:serviceEvent/hl7:performer/hl7:assignedEntity/hl7:representedOrganization/hl7:addr"
                 priority="1000"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>(TMP cdajze1b): Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
</xsl:stylesheet>