<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:peri="urn:nictiz-nl:v3/perinatologie"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <xsl:apply-templates select="/" mode="M43"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


<!--PATTERN template-2.16.840.1.113883.2.4.6.10.90.51Uitkomst bericht fase 1c vanuit 1e lijn naar registraties-->


	<!--RULE tmp-4f4bd505-8dcb-42f6-9fb5-e595df273623-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']"
                 priority="1460"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51']/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51'] is mandatory [min 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51'])&gt;=1 and not(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51']/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51'] komt te vaak voor [max 1x]. (count(hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:subject is required [min 1x]. (count(hl7:subject)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:subject komt te vaak voor [max 1x]. (count(hl7:subject)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:performer is required [min 1x]. (count(hl7:performer)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] is required [min 1x]. (count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] is mandatory [min 1x]. (count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&gt;=1 and not(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=9"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] komt te vaak voor [max 9x]. (count(hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=9 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-581019bf-ef6c-460e-8b3b-c51629190794-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:templateId[@root='2.16.840.1.113883.2.4.6.10.90.51']"
                 priority="1459"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.10.90.51'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.840.1.113883.2.4.6.10.90.51' hebben. (@root='2.16.840.1.113883.2.4.6.10.90.51' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5942463c-491d-4fef-8338-1b9ffeee2608-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:id"
                 priority="1458"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e9d31f97-14af-4073-9667-e309f0abd86f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:statusCode"
                 priority="1457"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fb7b5e5c-f2d7-4983-a267-a512c79c790e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:effectiveTime"
                 priority="1456"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:low is mandatory [min 1x]. (count(hl7:low)&gt;=1 and not(hl7:low/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6d74d614-3231-4604-89d5-1f3ceb20fde4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:effectiveTime/hl7:low"
                 priority="1455"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a96c4356-8158-4892-a747-90160822ed1c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject"
                 priority="1454"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:patient is mandatory [min 1x]. (count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:patient komt te vaak voor [max 1x]. (count(hl7:patient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b128ce28-7b75-4ef8-b769-9049ec033576-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient"
                 priority="1453"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PAT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PAT' zijn. (@classCode='PAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: identification mother requires either a BSN or a local id or both (count(hl7:id)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] is required [min 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id[@root='2.16.840.1.113883.2.4.6.3'] komt te vaak voor [max 1x]. (count(hl7:id[@root='2.16.840.1.113883.2.4.6.3'])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:statusCode is mandatory [min 1x]. (count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Person)&gt;=1 and not(hl7:Person/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Person is mandatory [min 1x]. (count(hl7:Person)&gt;=1 and not(hl7:Person/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Person)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Person komt te vaak voor [max 1x]. (count(hl7:Person)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8e6df360-6b48-4073-a117-b62a68568dc0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3'][@root='2.16.840.1.113883.2.4.6.3']"
                 priority="1452"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.BSN: Burgerservicenummer @root MOET 2.16.840.1.113883.2.4.6.3 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.BSN: Burgerservicenummer MOET 9 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.3') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.3') or (         (   number(substring(@extension,1,1))*9 )+         (   number(substring(@extension,2,1))*8 )+         (   number(substring(@extension,3,1))*7 )+         (   number(substring(@extension,4,1))*6 )+         (   number(substring(@extension,5,1))*5 )+         (   number(substring(@extension,6,1))*4 )+         (   number(substring(@extension,7,1))*3 )+         (   number(substring(@extension,8,1))*2 )+         (   number(substring(@extension,9,1))*-1) ) mod 11=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-II.NL.BSN: Burgerservicenummer voldoet niet aan modulo 11 proef (not(@root='2.16.840.1.113883.2.4.6.3') or ( ( number(substring(@extension,1,1))*9 )+ ( number(substring(@extension,2,1))*8 )+ ( number(substring(@extension,3,1))*7 )+ ( number(substring(@extension,4,1))*6 )+ ( number(substring(@extension,5,1))*5 )+ ( number(substring(@extension,6,1))*4 )+ ( number(substring(@extension,7,1))*3 )+ ( number(substring(@extension,8,1))*2 )+ ( number(substring(@extension,9,1))*-1) ) mod 11=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.3'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.840.1.113883.2.4.6.3' hebben. (@root='2.16.840.1.113883.2.4.6.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: attribute @extension MOET aanwezig zijn. (string-length(@extension)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4e115ab6-442c-4e44-b117-472f71094ccf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:id"
                 priority="1451"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@root)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: attribute @root MOET aanwezig zijn. (string-length(@root)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@extension)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: attribute @extension MOET aanwezig zijn. (string-length(@extension)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-05014430-6e00-4780-a5a0-b6efede78a23-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:addr"
                 priority="1450"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @use='HP' or @use='PHYS' or @use='TMP' or @use='HP PHYS' or @use='TMP PHYS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @use MOET één van de volgende codes bevatten: 'HP', 'PHYS', 'TMP', 'HP PHYS', 'TMP PHYS'. (@nullFlavor or @use='HP' or @use='PHYS' or @use='TMP' or @use='HP PHYS' or @use='TMP PHYS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode is mandatory [min 1x]. (count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode komt te vaak voor [max 1x]. (count(hl7:postalCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bdbb938b-d2e9-4b07-a81e-0510599654dc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:statusCode"
                 priority="1449"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f89458c4-b0ef-49a5-beb6-7cf45b685f1d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:Person"
                 priority="1448"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:deceasedInd/@value='false' or hl7:deceasedTime"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Datum maternale sterfte: if deceasedInd=true an element deceasedTime shall be present (hl7:deceasedInd/@value='false' or hl7:deceasedTime / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name komt te vaak voor [max 2x]. (count(hl7:name)&lt;=2 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&gt;=1 and not(hl7:deceasedInd/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:deceasedInd is mandatory [min 1x]. (count(hl7:deceasedInd)&gt;=1 and not(hl7:deceasedInd/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedInd)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:deceasedInd komt te vaak voor [max 1x]. (count(hl7:deceasedInd)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:deceasedTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:deceasedTime komt te vaak voor [max 1x]. (count(hl7:deceasedTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:ethnicGroupCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:ethnicGroupCode is required [min 1x]. (count(hl7:ethnicGroupCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:ethnicGroupCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:ethnicGroupCode komt te vaak voor [max 1x]. (count(hl7:ethnicGroupCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-689d569c-8924-4b44-91e4-23ef29373c7d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:Person/hl7:name"
                 priority="1447"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @use='OR' or @use='L' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @use MOET één van de volgende codes bevatten: 'OR', 'L'. (@nullFlavor or @use='OR' or @use='L' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-02999c3a-ee92-46c0-8138-bd541fe265c6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:Person/hl7:birthTime"
                 priority="1446"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0dfc3ecc-2dbb-4498-9d13-d396c70d9f8f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:Person/hl7:deceasedInd"
                 priority="1445"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1b21b362-2443-4b2d-96a3-d659d70dbb54-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:Person/hl7:deceasedTime"
                 priority="1444"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bf3614c4-a39e-421f-bc4f-281c62c2e4ac-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:subject/hl7:patient/hl7:Person/hl7:ethnicGroupCode"
                 priority="1443"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EthnicGroup-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EthnicGroup-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set EthnicGroup DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-16de2581-c15b-4a48-a186-6417ac92662a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer"
                 priority="1442"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PPRF' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PPRF' zijn. (@typeCode='PPRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:responsibleParty is required [min 1x]. (count(hl7:responsibleParty)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-68d885e5-6e42-4e6c-a5ba-dcc42c2261a9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty"
                 priority="1441"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:id[@root='2.16.528.1.1007.3.1']|hl7:id[@root='2.16.840.1.113883.2.4.6.1']|hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.2'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: keuze (hl7:id[@root='2.16.528.1.1007.3.1'] of hl7:id[@root='2.16.840.1.113883.2.4.6.1'] of hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.2']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:agentPerson is mandatory [min 1x]. (count(hl7:agentPerson)&gt;=1 and not(hl7:agentPerson/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&gt;=1 and not(hl7:representedOrganization/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:representedOrganization is mandatory [min 1x]. (count(hl7:representedOrganization)&gt;=1 and not(hl7:representedOrganization/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:representedOrganization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:representedOrganization komt te vaak voor [max 1x]. (count(hl7:representedOrganization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-dd1b9865-141b-47fe-98fd-a74131c80d68-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:id[@root='2.16.528.1.1007.3.1']"
                 priority="1440"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.1' or @root='2.16.528.1.1007.3.2'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.UZI: UZI-nummer @root MOET 2.16.528.1.1007.3.1 (Personen) of 2.16.528.1.1007.3.2 (Systemen) zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.1' or @root='2.16.528.1.1007.3.2' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.UZI: UZI-nummer persoon MOET 9 cijfers lang zijn (not(@root='2.16.528.1.1007.3.1') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-II.NL.UZI: UZI-nummer systeem MOET 9 cijfers lang zijn (not(@root='2.16.528.1.1007.3.2') or matches(@extension,'^[0-9]{9}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.1'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.528.1.1007.3.1' hebben. (@root='2.16.528.1.1007.3.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2651f217-adc3-44ad-b453-ca2c5fab37a1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1439"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.AGB: AGB-code @root MOET 2.16.840.1.113883.2.4.6.1 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.AGB: AGB-code moet 8 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (@root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-882734b6-0c69-4e4c-a05b-21d03e899863-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.2']"
                 priority="1438"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.3.22.98.2'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.840.1.113883.2.4.3.22.98.2' hebben. (@root='2.16.840.1.113883.2.4.3.22.98.2' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e33b9ad0-92e6-4e6d-a171-a8c53257a1b0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:code"
                 priority="1437"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:translation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:translation komt te vaak voor [max 1x]. (count(hl7:translation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d746817f-c410-4a39-b658-d00e92fc8f0e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:code/hl7:translation"
                 priority="1436"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerTypeLVR-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerTypeLVR-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerTypeLVR DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-46e9fdb4-ec8e-4cc9-8cd5-885815b900c9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:agentPerson/hl7:name"
                 priority="1435"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ea5f49ce-ea10-48d0-b2bb-8eeee01b1f40-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization"
                 priority="1434"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:id[@root='2.16.840.1.113883.2.4.6.1']|hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']|hl7:id[@root='2.16.528.1.1007.3.3'])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: keuze (hl7:id[@root='2.16.840.1.113883.2.4.6.1'] of hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1'] of hl7:id[@root='2.16.528.1.1007.3.3']) bevat te weinig elementen [min 1x] ($elmcount&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name is mandatory [min 1x]. (count(hl7:name)&gt;=1 and not(hl7:name/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr is mandatory [min 1x]. (count(hl7:addr)&gt;=1 and not(hl7:addr/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3fc9552e-db39-4e73-94d5-8354920558d9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:id"
                 priority="1433"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c72fed72-4bf4-4502-b260-ec36370c6a86-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.6.1']"
                 priority="1432"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.AGB: AGB-code @root MOET 2.16.840.1.113883.2.4.6.1 zijn indien niet null (@nullFlavor or @root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.AGB: AGB-code moet 8 cijfers lang zijn (not(@root='2.16.840.1.113883.2.4.6.1') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.6.1'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.840.1.113883.2.4.6.1' hebben. (@root='2.16.840.1.113883.2.4.6.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e82be1ef-d4cc-46ef-8238-eadb6c60a7de-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.840.1.113883.2.4.3.22.98.1']"
                 priority="1431"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.840.1.113883.2.4.3.22.98.1'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.840.1.113883.2.4.3.22.98.1' hebben. (@root='2.16.840.1.113883.2.4.3.22.98.1' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c468ce6b-262c-40e5-916b-d01dc7bc59dc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:id[@root='2.16.528.1.1007.3.3']"
                 priority="1430"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II.NL.URA: UZI-registerabonneenummer @root MOET 2.16.528.1.1007.3.3 zijn indien niet null (@nullFlavor or @root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II.NL.URA: UZI-registerabonneenummer MOET 8 cijfers lang zijn (not(@root='2.16.528.1.1007.3.3') or matches(@extension,'^[0-9]{8}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@root='2.16.528.1.1007.3.3'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root MOET de waarde '2.16.528.1.1007.3.3' hebben. (@root='2.16.528.1.1007.3.3' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @root attribuut MOET een syntactisch correcte UUID of OID zijn. (matches(@root, '^[0-2](\.(0|[1-9][0-9]*))*$') or matches(@root, '^[0-9a-zA-Z]{8}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{4}-[0-9a-zA-Z]{12}$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-33b3ef7d-9550-407c-ac37-d04cf1f7c5a1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:code"
                 priority="1429"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ZorgaanbiederType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-05cd6957-4cb7-4f0f-afb6-8cdc32d390c7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:name"
                 priority="1428"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a68335a2-b2b1-44e3-95e9-4c9f7d7db260-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:performer/hl7:responsibleParty/hl7:representedOrganization/hl7:addr"
                 priority="1427"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4ba65ce4-80aa-4d86-ba1d-4c2f5c8f2f56-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1426"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fefb32ac-6993-43c6-8115-51a3a69bc271-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1425"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:actList)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:actList komt te vaak voor [max 1x]. (count(hl7:actList)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-003b78bd-9fb9-434f-a032-2d3191631d09-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList"
                 priority="1423"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component)&gt;=1 and not(hl7:component/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:component is mandatory [min 1x]. (count(hl7:component)&gt;=1 and not(hl7:component/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:component komt te vaak voor [max 1x]. (count(hl7:component)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-106d878a-2201-45fa-b131-2924e118ad21-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:code"
                 priority="1422"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a7adb77b-a39d-454f-8576-9501efe713c3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component"
                 priority="1421"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ad25dc84-0d69-4615-b7f8-fb35916bf3d4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation"
                 priority="1420"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a1b9e4f1-78af-4279-a51f-17c96482e8b8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:code"
                 priority="1419"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c6bc9fd0-ffae-4250-9ea8-a2ac1cb0a8df-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:value"
                 priority="1418"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:targetOf)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als targetOf component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:targetOf)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:targetOf)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als targetOf
                                component worden meegegeven (@value='true' or count(../hl7:targetOf)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3834ddb1-86f0-4be9-8bb5-ca6512bf70d3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf"
                 priority="1417"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8b6d36ca-1775-488c-8b55-c331d52b8b14-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf/hl7:observation"
                 priority="1416"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-613604fb-99e8-4ddc-8b84-790eba9d1ee9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf/hl7:observation/hl7:code"
                 priority="1415"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'VERLIND' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0bfbaf83-4205-474a-991b-7668250faedc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='VERLIND' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf/hl7:observation/hl7:value"
                 priority="1414"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst10002000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set VILLijst10002000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-73d94f32-d607-4e24-8f76-c227a1e73c02-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1413"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ebc5d98d-457f-49f8-9124-93e77d2f6ce2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1412"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:actList)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:actList komt te vaak voor [max 1x]. (count(hl7:actList)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f8a6028e-39c8-4cf2-b34c-5e6974b94b71-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList"
                 priority="1410"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='LIST' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'LIST' zijn. (@classCode='LIST' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component)&gt;=1 and not(hl7:component/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:component is mandatory [min 1x]. (count(hl7:component)&gt;=1 and not(hl7:component/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:component)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:component komt te vaak voor [max 1x]. (count(hl7:component)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-499148b8-c0bd-4f53-8635-5fc0510e3c6f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:code"
                 priority="1409"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-63918a59-54c3-428e-af7d-68e3c018356b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component"
                 priority="1408"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation is mandatory [min 1x]. (count(hl7:observation)&gt;=1 and not(hl7:observation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-df1191a1-6964-4787-a941-92d8137ff155-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation"
                 priority="1407"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ec8f3d10-d421-4b3c-9b34-ef2ad0e2ecac-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:code"
                 priority="1406"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cd649fe3-e4df-4fbf-baa5-89099a551b3e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:value"
                 priority="1405"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value='false' or count(../hl7:targetOf)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el:  Als er sprake van ziekten en bijzonderheden is dan moet een lijst soort ziekten
                                als targetOf component worden meegegeven (@nullFlavor or @value='false' or count(../hl7:targetOf)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@value='true' or count(../hl7:targetOf)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el:  Als er geen sprake van ziekten en bijzonderheden is dan mag er geen lijst soort ziekten als targetOf
                                component worden meegegeven (@value='true' or count(../hl7:targetOf)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-790608cc-1b96-4d6c-b535-3dad62527249-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf"
                 priority="1404"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-01277cd8-790b-4d8d-9560-407c4c2db0ce-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf/hl7:observation"
                 priority="1403"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1a299c6d-5dff-48cd-8251-163dbf8c9163-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf/hl7:observation/hl7:code"
                 priority="1402"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'OBSTANAM' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d94817db-866f-4b8c-883a-ac0770f827c8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation2[hl7:actList[hl7:code[@code='OBSTANAM' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:actList/hl7:component/hl7:observation/hl7:targetOf/hl7:observation/hl7:value"
                 priority="1401"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CD" bevatten (@nullFlavor or @xsi:type='CD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst3000-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst3000-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set VILLijst3000 DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0ddf9abf-c278-410f-8ef2-90c3dd8e4787-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1400"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ddd83da3-009f-4e0e-8be0-d8e828a1a239-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1399"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3fcc3471-20b7-4319-94ad-813f5f21332d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1398"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ca1aa742-911d-4d37-9ddd-869a3d82e65a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1397"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN2102' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1a955a2a-f066-44dd-b79c-e142862357f0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN2102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1396"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-PeriodeZorgverlening-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-PeriodeZorgverlening-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set PeriodeZorgverlening DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-26492e0a-1e52-417a-8bcf-9903b06c52c8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]"
                 priority="1395"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='REFR' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'REFR' zijn. (@typeCode='REFR' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5761de74-5bd6-4fff-8847-ed48d6d10480-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]"
                 priority="1394"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='REFR' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'REFR' zijn. (@typeCode='REFR' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ae01f88f-6f3a-43d8-a047-f1ff3ddb6417-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act"
                 priority="1393"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PCPR' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PCPR' zijn. (@classCode='PCPR' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='RQO' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'RQO' zijn. (@moodCode='RQO' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:author)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:author komt te vaak voor [max 1x]. (count(hl7:author)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cbf5a830-a97b-489f-a93f-502ccedeb1eb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:code"
                 priority="1392"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='OBS' and @codeSystem='2.16.840.1.113883.5.4')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'OBS' codeSystem '2.16.840.1.113883.5.4' zijn. (@nullFlavor or (@code='OBS' and @codeSystem='2.16.840.1.113883.5.4') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f473201f-d2d5-4b49-b927-04e16837a37f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:author"
                 priority="1391"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='AUT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'AUT' zijn. (@typeCode='AUT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 is mandatory [min 1x]. (count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 komt te vaak voor [max 1x]. (count(hl7:assignedEntity1)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9f28af79-d791-410c-b063-bd3cd3ee6542-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:author/hl7:assignedEntity1"
                 priority="1390"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Organization)&gt;=1 and not(hl7:Organization/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Organization is mandatory [min 1x]. (count(hl7:Organization)&gt;=1 and not(hl7:Organization/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Organization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Organization komt te vaak voor [max 1x]. (count(hl7:Organization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7fe90249-d3ad-438c-8c0e-56b5f6b3ea8f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:author/hl7:assignedEntity1/hl7:code"
                 priority="1389"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EchelonOvername-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EchelonOvername-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set EchelonOvername DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-870e1e0e-73b4-4430-81d0-6c8540341083-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:author/hl7:assignedEntity1/hl7:Organization"
                 priority="1388"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-592a2380-abf9-4ba6-b618-f82061422210-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:author/hl7:assignedEntity1/hl7:Organization/hl7:id"
                 priority="1387"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-69835364-772c-42da-9964-5e58f68366a4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:targetOf"
                 priority="1386"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:priorityNumber)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:priorityNumber komt te vaak voor [max 1x]. (count(hl7:priorityNumber)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f7c71c72-6512-4c7c-8195-3cbf0048a0c5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:targetOf/hl7:priorityNumber"
                 priority="1385"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt;= 0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT.NONNEG: null or value &gt;= 0 (@nullFlavor or @value &gt;= 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=2))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [1..2] liggen   ((@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=2)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-90d5e242-7c6b-4034-a90e-f92dcc61c553-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:targetOf/hl7:observation"
                 priority="1384"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ac93b421-5a03-4251-801a-3409eeedc71e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:targetOf/hl7:observation/hl7:code"
                 priority="1383"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='RefInReas' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'RefInReas' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='RefInReas' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-22b730b4-8f48-4570-acb2-a229cc08d1f3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:targetOf/hl7:observation/hl7:value"
                 priority="1382"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-VILLijst-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-VILLijst-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set VILLijst DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:translation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:translation komt te vaak voor [max 1x]. (count(hl7:translation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6971c337-bd65-4ce8-863b-ec8bc9f94ea9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='OBS' and @codeSystem='2.16.840.1.113883.5.4']]]/hl7:act/hl7:targetOf/hl7:observation/hl7:value/hl7:translation"
                 priority="1381"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RedenOvernameLVR-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RedenOvernameLVR-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set RedenOvernameLVR DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5724d882-72a1-499b-842c-fd97b30b86c7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='364320009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1380"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-08f3b917-43fe-462d-ad67-52bd47ac0467-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='364320009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1379"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2a237340-07f0-437c-a842-45d72b45a155-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='364320009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:act"
                 priority="1378"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='COND' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'COND' zijn. (@classCode='COND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b632d325-600e-49f8-8a6c-8be928ee23d3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='364320009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:act/hl7:code"
                 priority="1377"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='364320009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '364320009' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='364320009' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-faef1373-edc3-46ff-b02d-4fd6123d0143-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='364320009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:act/hl7:effectiveTime"
                 priority="1376"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1196bea1-6ed8-49c6-a935-b1f9f46b24ad-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1375"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-844b06dd-8f8c-44bd-807b-ad24a12181f0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1374"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c5cea3cd-a39c-4db3-be25-3f590c9d94a6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1373"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-300c9703-37ff-4c67-bccd-ca00f6ea39b5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1372"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'Gravidity' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7bcb8e74-d585-4a5e-8c9b-ca528de5f2f4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Gravidity' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1371"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [0..75] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=75)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ba72580f-dba8-4757-a61b-68dbb66a92f1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1370"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fcd62967-015b-49e0-af38-8b9531c8866d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1369"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a8392b30-f1c3-41af-94f7-ddd80f8c0c7e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1368"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fd5daccf-3b5a-42fe-bd8b-5082073d0d98-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1367"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'NFetusMax' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2752be86-5832-4454-82f6-ec8d0771b657-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1366"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2bf4db58-b310-42c3-90b5-a752e495b6cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusMax' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1365"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=9))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [1..9] liggen   ((@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=9)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6b75c52f-9e31-42e9-8c39-3aa679155370-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1364"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-39e3e510-ddbb-4f93-962e-74512d897fa0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1363"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5e1b1779-04c9-4ee0-bd7e-512852ca4521-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1362"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3e643466-8ee4-429f-9358-a3c63c15f88a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1361"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'NFetusCur' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-72314387-2f7e-4520-895a-7f421e88cbb3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1360"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7fb4ebba-9121-4b8f-81f4-71884a31bafe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NFetusCur' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1359"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=9))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [0..9] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=9)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d26a04b1-c9bf-457f-8616-b640adfc2352-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1358"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b718953b-49d8-40f7-8d32-653aeb1fb647-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1357"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7165e251-211d-4fdd-a3b6-70b6d6950947-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1356"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e65068e3-1363-4011-b02e-8cfae3505981-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1355"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'EDD' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-52a75169-0866-4496-a7d4-380f53bf0c27-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1354"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3ce0fbf3-82fa-468f-9a23-93af54961435-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1353"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b1d0d836-19b5-40c5-bc50-1c6b6802e02a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1352"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47004cfd-512a-4bdb-8c7b-27c3e4f02468-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1351"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-14aacb6b-0ec4-462c-a4f4-27745bcfdb03-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1350"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0215d974-d1e5-4db8-a1ee-62fc6ad7cbe8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1349"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'EDDBasedOn' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ad52e2b0-7f58-426e-8311-b5266542fa5a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='EDDBasedOn' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1348"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EDDBasis-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EDDBasis-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set EDDBasis DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3d145c79-3ea8-4e03-a525-bc3ec5629f0e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1347"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2b87a22c-5013-422f-b336-567ea13d2f46-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1346"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5aa6d57b-eb2e-48c6-8363-6365516262b8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1345"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bd566efa-070e-4e21-b84d-e23ae6e6e35f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1344"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'ActualEDD' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3f1c664a-5f4d-4c67-9993-fbe94ebf37b2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='EDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='ActualEDD' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1343"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-689de0b5-e1aa-42c4-91a3-00b59bf32ad9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1342"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ee207ebe-268d-43f9-85c9-f27a3410343a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1341"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&gt;=1 and not(hl7:act/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:act is mandatory [min 1x]. (count(hl7:act)&gt;=1 and not(hl7:act/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-42296699-c5e3-44ba-9c7f-daed0a129a33-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act"
                 priority="1339"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='COND' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'COND' zijn. (@classCode='COND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-612bc019-8666-4c22-b01f-6a64b246c712-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:id"
                 priority="1338"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3ff8ccbf-f857-4d11-a4c7-16416b66afd6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:act[hl7:code[@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:act/hl7:code"
                 priority="1337"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'LVR1AdmNr' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='LVR1AdmNr' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a52bd8b-ddd4-47b7-80e2-66e39500077c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1336"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-63d95cae-35c4-4d2f-b920-717ea62c5a56-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1335"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bf865b90-c919-401d-b87a-f82ab27630ed-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1334"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:value/@value='false' or count(hl7:targetOf[hl7:procedure[hl7:code[@code='61285001'][@codeSystem='2.16.840.1.113883.6.96']]])&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Ovulatie-inductie
                    toegepast: required if Subfertiliteitsbehandeling value = true (hl7:value/@value='false' or count(hl7:targetOf[hl7:procedure[hl7:code[@code='61285001'][@codeSystem='2.16.840.1.113883.6.96']]])&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:value/@value='false' or count(hl7:targetOf[hl7:procedure[hl7:code[@code='63487001'][@codeSystem='2.16.840.1.113883.6.96']]])&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Geassisteerde
                    conceptie: required if Subfertiliteitsbehandeling value = true (hl7:value/@value='false' or count(hl7:targetOf[hl7:procedure[hl7:code[@code='63487001'][@codeSystem='2.16.840.1.113883.6.96']]])&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:value/@value='false' or count(hl7:targetOf[hl7:procedure[hl7:code[@code='176843009'][@codeSystem='2.16.840.1.113883.6.96']]])&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Eiceldonatie
                    toegepast: required if Subfertiliteitsbehandeling value = true (hl7:value/@value='false' or count(hl7:targetOf[hl7:procedure[hl7:code[@code='176843009'][@codeSystem='2.16.840.1.113883.6.96']]])&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8a40ed37-64d1-49d0-b250-6a2ef982444f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1333"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN3206' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-723c2a60-975f-4da0-8a0e-7deb151d5b36-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1332"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7f12b464-b856-4e22-b037-73908f770616-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1331"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d74bd77b-e576-462f-9ea8-0abb87cc501a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1330"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&gt;=1 and not(hl7:procedure/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure is mandatory [min 1x]. (count(hl7:procedure)&gt;=1 and not(hl7:procedure/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-93e99173-f074-451a-b950-1d1ef55a68ca-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure"
                 priority="1328"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@negationInd)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: attribute @negationInd MOET aanwezig zijn. (string-length(@negationInd)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f223aaa2-13ff-4057-b9f0-10c6d9c6db09-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:id"
                 priority="1327"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NI'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @nullFlavor MOET 'NI' zijn. (@nullFlavor='NI' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1c877a9d-6f68-41e3-aad5-051ae6d582b4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='61285001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:code"
                 priority="1326"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='61285001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '61285001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='61285001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eb73b14e-3dec-44df-b932-2b8cdca1dde6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='63487001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1325"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8319c6fe-b073-4f05-b2f2-69863a03cc8f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='63487001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1324"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&gt;=1 and not(hl7:procedure/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure is mandatory [min 1x]. (count(hl7:procedure)&gt;=1 and not(hl7:procedure/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d61a1ada-39fe-4989-a381-eeaddc631f5a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='63487001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure"
                 priority="1322"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@negationInd)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: attribute @negationInd MOET aanwezig zijn. (string-length(@negationInd)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:methodCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:methodCode is required [min 1x]. (count(hl7:methodCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:methodCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:methodCode komt te vaak voor [max 1x]. (count(hl7:methodCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c8ef5eb2-d513-4936-9e60-a024f57f1b58-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='63487001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:id"
                 priority="1321"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5c4dc148-cbd4-4521-93e1-adcaa0de18ea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='63487001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:code"
                 priority="1320"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='63487001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '63487001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='63487001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-30f2a23f-abf8-4798-a1e2-50ebb3bcda78-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='63487001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:methodCode"
                 priority="1319"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-GeassConceptie-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-GeassConceptie-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set GeassConceptie DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-08966d87-ba61-402b-8b36-ee76c506e72a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1318"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cc4409e8-181e-4941-a32a-45a59c7a8990-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1317"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&gt;=1 and not(hl7:procedure/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure is mandatory [min 1x]. (count(hl7:procedure)&gt;=1 and not(hl7:procedure/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1a9d6fa3-0024-4054-9e53-4e7f42b3f92d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure"
                 priority="1315"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(@negationInd)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: attribute @negationInd MOET aanwezig zijn. (string-length(@negationInd)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-34cb6e6a-367f-4171-a690-a1d0949fe933-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:id"
                 priority="1314"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NI'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @nullFlavor MOET 'NI' zijn. (@nullFlavor='NI' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a95fefd-2d7d-403e-b725-44db64938a95-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:code"
                 priority="1313"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='176843009' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '176843009' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='176843009' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c96bf4c3-6cc2-431f-aa8e-f0272ec2717f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1312"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9520b65e-0a83-43c0-b97b-c91dd9afe57b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1311"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9493746d-b18d-4f9d-9b26-666aeebd86d0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure"
                 priority="1309"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&gt;=1 and not(hl7:subject/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:subject is mandatory [min 1x]. (count(hl7:subject)&gt;=1 and not(hl7:subject/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:subject)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:subject komt te vaak voor [max 1x]. (count(hl7:subject)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-694c5302-404d-4cd9-9f03-e8a35e945831-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:id"
                 priority="1308"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NA'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @nullFlavor MOET 'NA' zijn. (@nullFlavor='NA' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9574d41e-b98d-47b3-93e1-bf473cf7c2db-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:code"
                 priority="1307"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='177037000' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '177037000' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='177037000' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-aa6be4d3-2d7c-4fce-b814-e0e2f831512d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:subject"
                 priority="1306"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:patient is mandatory [min 1x]. (count(hl7:patient)&gt;=1 and not(hl7:patient/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:patient)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:patient komt te vaak voor [max 1x]. (count(hl7:patient)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-942bf447-00d5-49dc-855c-1b45d06874c7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:subject/hl7:patient"
                 priority="1305"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:statusCode is mandatory [min 1x]. (count(hl7:statusCode)&gt;=1 and not(hl7:statusCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Person)&gt;=1 and not(hl7:Person/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Person is mandatory [min 1x]. (count(hl7:Person)&gt;=1 and not(hl7:Person/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Person)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Person komt te vaak voor [max 1x]. (count(hl7:Person)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-70fada75-543f-4c2e-a87a-a8952f24826d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:subject/hl7:patient/hl7:id"
                 priority="1304"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor='NA'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @nullFlavor MOET 'NA' zijn. (@nullFlavor='NA' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-251709d3-cf09-463a-9924-72178d97c9cd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:subject/hl7:patient/hl7:statusCode"
                 priority="1303"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CS" bevatten (@nullFlavor or @xsi:type='CS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CS: @code/@typeCode and @nullFlavor are mutually exclusive ((@nullFlavor and not(@code or @typeCode)) or (not(@nullFlavor) and (@code or @typeCode)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystem)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CS: cannot have codeSystem (not(@codeSystem) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CS: cannot have codeSystemName (not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CS: cannot have codeSystemVersion (not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CS: cannot have displayName (not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CS: cannot have originalText (not(hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CS: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CS: cannot have translation (not(hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='completed')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET 'completed' zijn. (@nullFlavor or (@code='completed') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-31221850-b9c3-456e-8ee4-fa0f402fef33-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:subject/hl7:patient/hl7:Person"
                 priority="1302"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c387d144-065a-4da3-996a-258660f0466d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN3206' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='176843009' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='177037000' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:subject/hl7:patient/hl7:Person/hl7:birthTime"
                 priority="1301"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-34b6bdc0-de78-45bf-93cb-0549bd5aa0ef-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1300"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fdbfac81-45ff-4097-bf8f-53d2fc72daac-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1299"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-88ae3e77-45c7-4fe8-847d-c0b58125d4de-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1297"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5b97b950-01c7-4132-8c12-e87a90246606-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1296"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'Amnionic' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e0690661-3a30-4e86-972c-4420a9217f50-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Amnionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1295"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Amnioniciteit-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Amnioniciteit-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set Amnioniciteit DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8df0775a-caff-48a3-af8a-b98e6b7c971a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1294"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-98821744-cf36-4980-bcfe-6db31582df29-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1293"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7639766c-c2b7-4f5a-9d36-424fddda8ae6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1292"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-27c0fcdf-03aa-4f5a-a36f-47267f9f4bba-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1291"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'Chorionic' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0b171278-f8da-4c33-b5b4-203ddcb432bc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Chorionic' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1290"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Chorioniciteit-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Chorioniciteit-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set Chorioniciteit DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-11d9dd5f-14b2-4c95-bad9-25fe3bdc2f80-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1289"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b3f180b2-49d4-4cf9-9208-02a207c8ffa4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1288"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5a1332ca-e58e-4bd4-bdc7-0993a049e297-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1287"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-32440373-227c-4fe2-994d-a4ccbfccc676-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1286"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: De waarde van @code/@codeSystem MOET 'Parturit' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1754a817-5a1f-44fb-8d00-3217b7ad0187-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Parturit' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1285"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=30))"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: value MOET in bereik [1..30] liggen   ((@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=30)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>Pariteit: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-50323d87-fc3b-4f62-9185-994a97fdb775-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1284"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7481256a-389e-46a4-8a1b-df4834f25cf4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1283"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation is required [min 1x]. (count(hl7:observation)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f77e855f-458c-4624-be53-f92c87417713-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1281"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-544ed664-b3ec-4b32-a81f-72f3a406adf2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1280"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '56077-1' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6abbf735-5b55-463e-ba7b-f64d37747ccd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='56077-1' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1279"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='kg' and number($theValue)&gt;=25 and number($theValue)&lt;=249.9))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET eenheid 'kg' gebruiken en in bereik [25..249.9] liggen   ((@nullFlavor or (@unit='kg' and number($theValue)&gt;=25 and number($theValue)&lt;=249.9)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-60307dbc-63aa-4a32-b574-278f4ab11608-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1278"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-476ac77a-1fa8-4e07-bdff-f5e4042e68d4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1277"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation is required [min 1x]. (count(hl7:observation)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:observation)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:observation komt te vaak voor [max 1x]. (count(hl7:observation)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-daf268c5-e9f7-4b6f-9843-7024d3b25bb8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1275"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4b10a0b8-1a72-4ce6-b917-2a4181005485-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1274"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'X_IVDIASTPREG' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fafa97df-e776-444e-b22b-bdc7eb37285e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1273"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_PQ" bevatten (@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@unit and hl7:high/@unit) or         hl7:low/@unit = hl7:high/@unit"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_PQ: units in low and high must be equal (not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         not(hl7:low/@unit = hl7:high/@unit) or         number(hl7:low/@value) &lt; number(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_PQ:
        low/@value must be lower than high/@value (not(hl7:low/@value and hl7:high/@value) or not(hl7:low/@unit = hl7:high/@unit) or number(hl7:low/@value) &lt; number(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center) or (hl7:center and not(hl7:low or hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_PQ: center may not be used together with low or high (not(hl7:center) or (hl7:center and not(hl7:low or hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/low @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="hl7:low/@value"/>
               <xsl:text/>
       (not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/high @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="hl7:high/@value"/>
               <xsl:text/>
       (not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/center @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="hl7:center/@value"/>
               <xsl:text/>
       (not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:high is required [min 1x]. (count(hl7:high)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-afb61687-b142-48d8-80d8-e2819bcd7f39-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='X_IVDIASTPREG' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value/hl7:high"
                 priority="1272"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=10))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET eenheid 'mm[Hg]' gebruiken en in bereik [10..] liggen   ((@nullFlavor or (@unit='mm[Hg]' and number($theValue)&gt;=10)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0c32ed98-7293-4f99-b5d9-154885a3b0ee-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1271"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-55c51ec0-7f57-4f4f-a6f4-b0430e0485b8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1270"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-517d5e05-48cc-4913-8d31-27e4fb370652-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1269"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="elmcount"
                    select="count(hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]|hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$elmcount&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: keuze (hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]] of hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]]) bevat te veel elementen [max 1x] ($elmcount&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e255e501-eb49-4017-ac82-b01f01786a99-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1268"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN420204-bl' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b6c584b6-523d-44d5-a971-c4c23602ce71-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1267"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-53c751f2-7011-4f6c-b361-d05bc2afbba3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1266"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2a4d1641-3bcd-4268-864a-1cfcec604912-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1265"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fd933874-8c5c-4095-952f-13035f5c50c2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1264"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-594f228d-150d-40cd-90d8-e0aee268697e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1263"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8091ca59-921f-40a9-bad1-9af77483be77-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1262"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '2889-4' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a1283ea1-4d46-41b2-bdf9-267c3c6424c9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1261"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "IVL_PQ" bevatten (@nullFlavor or @xsi:type='IVL_PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL: null violation. Cannot have @nullFlavor
        and @value or child elements, or the other way around ((@nullFlavor and not(@value|@unit|*)) or (not(@nullFlavor) and (@value|@unit|hl7:low|hl7:center|hl7:high|hl7:width)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL: null violation. Cannot have @nullFlavor and @value on any child elements (not(*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:*[@nullFlavor and (@value|@unit)])"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL: null violation. Child element has @nullFlavor and @value (not(hl7:*[@nullFlavor and (@value|@unit)]) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="         @nullFlavor or         (not(@nullFlavor) and @value and not(*)) or         (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or         (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or         (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-IVL: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, or center element with other elements, or width element with
        both low and high elements (@nullFlavor or (not(@nullFlavor) and @value and not(*)) or (not(@nullFlavor) and not(@value) and (hl7:low|hl7:center|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and (hl7:*[not(@nullFlavor)])) or (not(@nullFlavor) and not(@value) and hl7:center and not(hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and not(@value) and not(hl7:center) and hl7:width and not(hl7:low and hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-IVL: no updateMode on IVL attributes (count(*[@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-IVL: low/@value must not be equal to high/@value (not(hl7:low/@value and hl7:high/@value) or hl7:low/@value != hl7:high/@value / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width) or         hl7:width[not(@unit)] or         hl7:width[@value and @unit]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQR: width element: no unit without value (not(hl7:width) or hl7:width[not(@unit)] or hl7:width[@value and @unit] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:width/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQR: width element: no translation (not(hl7:width/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@unit and hl7:high/@unit) or         hl7:low/@unit = hl7:high/@unit"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-IVL_PQ: units in low and high must be equal (not(hl7:low/@unit and hl7:high/@unit) or hl7:low/@unit = hl7:high/@unit / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value and hl7:high/@value) or         not(hl7:low/@unit = hl7:high/@unit) or         number(hl7:low/@value) &lt; number(hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-IVL_PQ:
        low/@value must be lower than high/@value (not(hl7:low/@value and hl7:high/@value) or not(hl7:low/@unit = hl7:high/@unit) or number(hl7:low/@value) &lt; number(hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center) or (hl7:center and not(hl7:low or hl7:high))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-IVL_PQ: center may not be used together with low or high (not(hl7:center) or (hl7:center and not(hl7:low or hl7:high)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/low @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="hl7:low/@value"/>
               <xsl:text/>
       (not(hl7:low/@value) or matches(hl7:low/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/high @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="hl7:high/@value"/>
               <xsl:text/>
       (not(hl7:high/@value) or matches(hl7:high/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/center @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="hl7:center/@value"/>
               <xsl:text/>
       (not(hl7:center/@value) or matches(hl7:center/@value, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:high is required [min 1x]. (count(hl7:high)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-88f7a65d-1f90-46d2-910e-b730d9f8ea20-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='2889-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value/hl7:high"
                 priority="1260"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='mg/24h'))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET eenheid 'mg/24h' gebruiken  ((@nullFlavor or (@unit='mg/24h')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fc42a033-c539-4ff6-9111-9a52f3b80337-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1259"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7501e5a2-8d9f-4115-a765-acf1e1df4b55-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1258"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRT' zijn. (@typeCode='SPRT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d2efb348-71fc-458f-83c2-64c3517f4bf7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1257"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5ef6ef0c-2060-404c-90ca-f242b7149c8b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1256"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '20454-5' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-13ff375e-dbc3-404a-b0eb-02407dd9d71d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN420204-bl' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:targetOf[hl7:observation[hl7:code[@code='20454-5' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1255"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ProteineTestStripResult-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ProteineTestStripResult-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ProteineTestStripResult DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d5a45347-beb7-4a9b-935a-133506a8cd8c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1254"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-19d96016-00b4-4fc8-a684-974173a7081e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1253"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5460f03f-84a5-4bd9-b397-a40eb70948b7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1252"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='INT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'INT' zijn. (@moodCode='INT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a426fd09-9073-4ec8-8a26-72e403759e08-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1251"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN4209' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a3d691c-683b-4ce9-a2b0-90a10f6518cc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location"
                 priority="1250"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='ELOC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'ELOC' zijn. (@typeCode='ELOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:healthCareFacility)&gt;=1 and not(hl7:healthCareFacility/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:healthCareFacility is mandatory [min 1x]. (count(hl7:healthCareFacility)&gt;=1 and not(hl7:healthCareFacility/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:healthCareFacility)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:healthCareFacility komt te vaak voor [max 1x]. (count(hl7:healthCareFacility)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6f4f10c7-9a24-4fe9-9c28-e1ee10077e1b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location/hl7:healthCareFacility"
                 priority="1249"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DSDLOC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'DSDLOC' zijn. (@classCode='DSDLOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-059dc955-dbfc-498d-8225-c76b330288a1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN4209' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location/hl7:healthCareFacility/hl7:code"
                 priority="1248"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ToekomstPlaatsBaring-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ToekomstPlaatsBaring-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ToekomstPlaatsBaring DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-489b0122-cb25-4860-8ebe-c107d608005b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1247"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-70e70099-4fe6-4cfe-a72b-47a94d3df0d1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1246"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c52d4a20-2e51-4e73-946c-58afb3d719e6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1245"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1619e0d6-b968-4bb1-8c1c-60d9edd0ba24-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1244"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'KraamZorg' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d73e0acd-374a-48b5-a337-6dc3467a2df8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='KraamZorg' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1243"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-39afbc94-d2ef-4142-9173-25e14d351f04-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1242"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7b95209e-23ae-45d3-a96f-16615f5a45c9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1241"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a7818db1-cd82-4325-b409-cc246509c734-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1240"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6e48e25a-cd8e-418f-9426-944a8d3c2989-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1239"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'IUVD1contr' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6538337b-0d24-4bba-8a30-54663ace3fb4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='IUVD1contr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1238"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-20e65c96-7d7a-4dda-a183-fd24fb49db8a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1237"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5cfaddd6-f959-4d85-9136-9878d9737baa-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1236"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5089ede-f73b-40c2-91ec-d5af3c26a6a8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1235"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3159ecf6-b657-4326-b14e-b9f7b19f02b0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1234"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'NBorn16' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9133b2bc-5a83-46cd-a0c0-c44553b5d76c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='NBorn16' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1233"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=9))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [0..9] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=9)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4182e800-10c1-4e05-b95e-7e5e00a45901-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1232"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-93f2a0a6-a424-4f98-9e90-d3ee8f97474f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1231"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure is required [min 1x]. (count(hl7:procedure)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:procedure)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:procedure komt te vaak voor [max 1x]. (count(hl7:procedure)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-be8655b0-c01b-4c95-abbb-d8d5816dcf68-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1229"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='INT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'INT' zijn. (@moodCode='INT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8bec8c22-581d-44ea-bd15-92083f34384a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1228"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN5104' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-bdd7cb38-c659-4d28-94d8-10604201d286-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location"
                 priority="1227"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='ELOC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'ELOC' zijn. (@typeCode='ELOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:healthCareFacility)&gt;=1 and not(hl7:healthCareFacility/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:healthCareFacility is mandatory [min 1x]. (count(hl7:healthCareFacility)&gt;=1 and not(hl7:healthCareFacility/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:healthCareFacility)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:healthCareFacility komt te vaak voor [max 1x]. (count(hl7:healthCareFacility)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2aad4176-819e-43b6-81d9-8cb1df001e73-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location/hl7:healthCareFacility"
                 priority="1226"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DSDLOC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'DSDLOC' zijn. (@classCode='DSDLOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0a3e3af5-18f8-4ee1-a971-e971d19df559-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN5104' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location/hl7:healthCareFacility/hl7:code"
                 priority="1225"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ToekomstPlaatsBaring-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ToekomstPlaatsBaring-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ToekomstPlaatsBaring DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cf4ad855-ec85-431b-ad72-53a4849d18ce-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1224"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-34c246f5-40f8-46e5-9a1f-42bb2c6f1005-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1223"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e2e290cf-588d-4b15-b4e1-8aa8aff56f12-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1222"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b0c22e74-f279-4a47-909f-bfd44c741b26-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1221"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'TypeDeliv' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8bea7a23-9175-4188-a16e-fa4858439883-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1220"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-47899d89-baf4-4231-ae3d-edfddeeea633-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='TypeDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1219"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-TypeBevalling-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set TypeBevalling DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-463d160c-720a-425b-a782-9060409ff1ee-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1218"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-75820b5f-f437-4354-93dc-1b527ae8ca4b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1217"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-76281ff1-18f4-4212-a244-de1cf6e101d3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1216"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9185616a-2f8a-49f2-9551-4e2606a2a6ec-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1215"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN5102' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5d2cc78-bce2-4158-baff-00cc95bd78b8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1214"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RisicoBaring-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RisicoBaring-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set RisicoBaring DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4daebc2b-eb5d-44d6-9f59-a07767f10690-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1213"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-052660a6-d452-48a0-a0eb-284964763358-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1212"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-31171f84-3fd2-4eea-9ce9-fb63fd6a9dd9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1211"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] is required [min 1x]. (count(hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d9f3159b-a2c2-4ee8-bcc4-5dcd0364bfd2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1210"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'BeginDeliv' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-81350f3a-6233-45a7-a4d0-ad3ddf2e800b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1209"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-WijzeBaringBegin-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-WijzeBaringBegin-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set WijzeBaringBegin DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-488bfd70-649e-4e4c-ab75-0315d826687c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1208"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4d851651-7a05-4729-aa90-7438a336f968-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1207"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-af686115-dbfe-4fda-a5bf-d60f48f03b23-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1206"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:methodCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:methodCode is required [min 1x]. (count(hl7:methodCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:methodCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:methodCode komt te vaak voor [max 1x]. (count(hl7:methodCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] is required [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b05c6da9-d3a5-46ab-b8ce-018bbc5d9de2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1205"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN520102' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e1782cbf-79b3-422b-a5cd-ef7454dcf79d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:methodCode"
                 priority="1204"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-InterventieBaring-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-InterventieBaring-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set InterventieBaring DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3da5617e-26e7-4e59-8c68-459e83ab5308-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1203"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1d9fea35-2401-4c42-9468-163c0a0115e3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1202"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RSON' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'RSON' zijn. (@typeCode='RSON' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-50cba61d-e2e9-4fa8-bddb-3aa29db69912-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1201"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-916334d4-d03a-49d6-a175-3c7cff24e545-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1200"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN520103' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1dec5e9f-3643-449c-b40d-75a380bcfd1c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='BeginDeliv' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN520102' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN520103' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1199"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-MotivatieInterventie-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-MotivatieInterventie-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set MotivatieInterventie DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b126f481-549b-48e4-bbe4-780cae3ebf32-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1198"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b541413d-f3ce-43d7-a191-034270f43609-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1197"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c0672cf3-8654-4b7e-9b1d-fd3cc9de9658-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1196"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-16c9713e-bda3-4d61-bde5-1d77b49cc0c4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:id"
                 priority="1195"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-942142e1-a9f6-4b5c-8527-8a9c506d9a0a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1194"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN540101' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ac7bbcd4-0df6-49fb-b1c6-02279c40a82c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='PRN540101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:methodCode"
                 priority="1193"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AmniotomieMoment-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AmniotomieMoment-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set AmniotomieMoment DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-89763d61-52e5-469a-9976-70f7db486a13-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1192"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b900283d-38e8-408f-9d00-f1e5a3edde3c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1191"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f0a3c25a-e749-486d-a6c4-9bfacb7d9baf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1190"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-92e46906-96d9-447b-ba1a-d9c99f968b4d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1189"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN520301' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6413b411-b147-40f8-9edb-f9261cfcc6a6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN520301' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1188"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-72417a65-87bf-4bec-be90-152fc0f3f7cf-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1187"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4a2b353a-b63b-464b-9da4-5934df4cd254-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1186"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eee2bd45-6441-4563-a8c9-6b9c1482bb3f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1185"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime is required [min 1x]. (count(hl7:effectiveTime)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e94e935b-95cf-4564-816c-e4bd836d147b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1184"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN530101' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e36df5a3-4ca3-459c-b164-93ff2082f05a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN530101' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:effectiveTime"
                 priority="1183"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-03f27d6e-2c44-4c4f-8d77-674414ea1f8a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1182"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-433ce6af-a88f-496d-987d-7f88789434ba-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1181"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a74aad2e-9763-43c1-a3ac-8ed872c13c68-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1180"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5d8fa705-100d-44a4-ad81-684cfad7d9aa-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1179"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '38386-9' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b4b2357a-bb75-4ff4-8444-f8faac99ff01-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='38386-9' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1178"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-KleurVruchtwater-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-KleurVruchtwater-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set KleurVruchtwater DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b99d2c64-5b60-469a-8100-d9d6ef224066-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1177"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-30c56199-6fb7-4511-be6d-f9cc95d816c8-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1176"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-805aa49f-a884-4894-ac95-8c26d63df00b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1175"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:value/@value='true' and hl7:targetOf/@typeCode='COMP'"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: If Medicatie nageboortetijdperk = true, a substanceAdministration as a component SHALL be
                    present (hl7:value/@value='true' and hl7:targetOf/@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-94f27474-6e82-4fbb-9d9a-580544fe40ee-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1174"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'Medic3stage' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1b50de5a-ad6f-4221-97c8-55816945a9ac-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1173"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6621028e-4239-490c-a039-28d1831c6c40-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]"
                 priority="1172"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-60976fe7-bcc4-42bd-a214-848d30f2f868-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]"
                 priority="1171"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:substanceAdministration)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:substanceAdministration is required [min 1x]. (count(hl7:substanceAdministration)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:substanceAdministration)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:substanceAdministration komt te vaak voor [max 1x]. (count(hl7:substanceAdministration)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fedba36a-76b6-4674-9cec-e597262f372d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration"
                 priority="1169"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='SBADM' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'SBADM' zijn. (@classCode='SBADM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:consumable is required [min 1x]. (count(hl7:consumable)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:consumable)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:consumable komt te vaak voor [max 1x]. (count(hl7:consumable)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f1b4ba67-dbd1-4865-b05d-5e6f2c0d031f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable"
                 priority="1168"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='CSM' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'CSM' zijn. (@typeCode='CSM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:medication)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:medication is required [min 1x]. (count(hl7:medication)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:medication)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:medication komt te vaak voor [max 1x]. (count(hl7:medication)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1237c31f-8108-43a0-921f-499c3d794905-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable/hl7:medication"
                 priority="1167"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ADMM' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ADMM' zijn. (@classCode='ADMM' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administerableMedicine)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:administerableMedicine is required [min 1x]. (count(hl7:administerableMedicine)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administerableMedicine)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:administerableMedicine komt te vaak voor [max 1x]. (count(hl7:administerableMedicine)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-389e19c9-0940-4a3e-896d-2d4b505cc14e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable/hl7:medication/hl7:administerableMedicine"
                 priority="1166"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='MMAT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'MMAT' zijn. (@classCode='MMAT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='KIND' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'KIND' STATIC  (@determinerCode='KIND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6768ec9b-ede3-4eef-bf7a-1a3a7dd3309b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='Medic3stage' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:targetOf[hl7:substanceAdministration[hl7:code[(@code='1' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7') or (@code='2' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.4.7')]]]/hl7:substanceAdministration/hl7:consumable/hl7:medication/hl7:administerableMedicine/hl7:code"
                 priority="1165"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-SoortMedNageboorte-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-SoortMedNageboorte-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set SoortMedNageboorte DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4dd4d437-4329-4aba-98a4-e3b10b2b7c4a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1164"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9bfb3d62-5ade-48b3-aa12-d91ab6fd2090-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1163"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3e2b8539-83e4-4d1b-b168-9352b2721299-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1162"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b8ac70f6-3252-4846-b437-34181dc983c3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1161"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'AfterBirthMethod' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7b96dbeb-8ef9-460f-bf34-95b90bcd1d22-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='AfterBirthMethod' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1160"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-GeboortePlacenta-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-GeboortePlacenta-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set GeboortePlacenta DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-04988b88-d21a-461b-970a-97dfe56f4b6c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1159"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9f364ca0-e290-4ed9-8813-c80c1706c61c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1158"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f5f02c70-8e4c-4624-8278-64f66e8f6ea0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1157"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-19a368db-bce6-4fcd-a675-93adcbca6eed-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1156"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN5703' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c756ea4a-b224-4123-a5ee-77a737774881-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN5703' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1155"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='ml'))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET eenheid 'ml' gebruiken  ((@nullFlavor or (@unit='ml')) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5c1ae079-26c8-4d84-be54-6876e25dff2c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1154"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ae927b8d-53c8-4c28-97a3-b6abb5f6db6d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1153"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='true' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'true' STATIC  (@contextConductionInd='true' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3cf466f4-72db-47af-801e-3956805845fa-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1152"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8be39c4d-7347-460f-ae22-d77c7359e136-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1151"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN550403' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8d69d0ff-427e-4bda-8b61-8b25c845e064-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:observation[hl7:code[@code='PRN550403' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1150"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-PartusassKraamzorg-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-PartusassKraamzorg-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set PartusassKraamzorg DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9eb66cb3-cc32-4f99-924a-0aebee78e8ee-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1149"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='false' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'false' STATIC  (@contextConductionInd='false' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ec724994-fbbf-418d-b51e-d7a58ed7a682-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1148"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PERT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PERT' zijn. (@typeCode='PERT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@contextConductionInd='false' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @contextConductionInd SHALL have value 'false' STATIC  (@contextConductionInd='false' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-30bc6467-b647-4fa6-9a5d-ecad473dcfb5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1147"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd/@value='false' or hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201'][@codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el:  If deceasedInd=true, Fase perinatale sterfte is mandatory (hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd/@value='false' or hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201'][@codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:location)&gt;=1 and not(hl7:location/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:location is mandatory [min 1x]. (count(hl7:location)&gt;=1 and not(hl7:location/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:location)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:location komt te vaak voor [max 1x]. (count(hl7:location)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&gt;=1 and not(hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-64966508-ab62-439f-a0ec-f6066c5e30ff-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:id"
                 priority="1146"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cfaf171f-f15c-42a7-91a7-91cccbe2004d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1145"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'Baring' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-fdfffd25-8138-4b4b-8790-950a3d869a0f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject"
                 priority="1144"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SBJ' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SBJ' zijn. (@typeCode='SBJ' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:personalRelationship is mandatory [min 1x]. (count(hl7:personalRelationship)&gt;=1 and not(hl7:personalRelationship/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:personalRelationship)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:personalRelationship komt te vaak voor [max 1x]. (count(hl7:personalRelationship)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-55d3b4f9-f859-4874-9166-add6abfa6339-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship"
                 priority="1143"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PRS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PRS' zijn. (@classCode='PRS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:relationshipHolder is mandatory [min 1x]. (count(hl7:relationshipHolder)&gt;=1 and not(hl7:relationshipHolder/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:relationshipHolder)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:relationshipHolder komt te vaak voor [max 1x]. (count(hl7:relationshipHolder)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ac6eca96-644b-4e88-9233-de0f0986f81e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:code"
                 priority="1142"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'CHILD' codeSystem '2.16.840.1.113883.5.111' zijn. (@nullFlavor or (@code='CHILD' and @codeSystem='2.16.840.1.113883.5.111') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8b3d4959-0d29-429e-ab33-7e9a3aace2b5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder"
                 priority="1141"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Identification child requires at least a local id and optional in addition a BSN / PRN-Id (count(hl7:id)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:deceasedInd/@value='false' or hl7:deceasedTime"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Datum perinatale sterfte: if deceasedInd=true an element deceasedTime shall be present (hl7:deceasedInd/@value='false' or hl7:deceasedTime / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:multipleBirthInd/@value='false' or string-length(hl7:multipleBirthOrderNumber/@value)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Rangnummer (HL7): if multipleBirthInd=true an element
                            multipleBirthOrderNumber shall be present and valued (hl7:multipleBirthInd/@value='false' or string-length(hl7:multipleBirthOrderNumber/@value)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name komt te vaak voor [max 2x]. (count(hl7:name)&lt;=2 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode)&gt;=1 and not(hl7:administrativeGenderCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:administrativeGenderCode is mandatory [min 1x]. (count(hl7:administrativeGenderCode)&gt;=1 and not(hl7:administrativeGenderCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:administrativeGenderCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:administrativeGenderCode komt te vaak voor [max 1x]. (count(hl7:administrativeGenderCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:birthTime is mandatory [min 1x]. (count(hl7:birthTime)&gt;=1 and not(hl7:birthTime/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:birthTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:birthTime komt te vaak voor [max 1x]. (count(hl7:birthTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:multipleBirthInd)&gt;=1 and not(hl7:multipleBirthInd/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:multipleBirthInd is mandatory [min 1x]. (count(hl7:multipleBirthInd)&gt;=1 and not(hl7:multipleBirthInd/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:multipleBirthInd)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:multipleBirthInd komt te vaak voor [max 1x]. (count(hl7:multipleBirthInd)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:multipleBirthOrderNumber)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:multipleBirthOrderNumber komt te vaak voor [max 1x]. (count(hl7:multipleBirthOrderNumber)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b655eb64-c56d-4164-b26b-b075f2866704-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:id"
                 priority="1140"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7d005315-6bf0-4aa7-95bb-0d73948592d9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:name"
                 priority="1139"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f8a2618d-79b9-4291-9b9c-fae0bbd366f2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:administrativeGenderCode"
                 priority="1138"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AdministrativeGender-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set AdministrativeGender DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-94fee759-9588-4115-8b82-5f8160bf28bc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:birthTime"
                 priority="1137"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-36eab315-0f8e-4ce9-9534-d234a9d8d2ca-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedInd"
                 priority="1136"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-033cf51c-fdc5-4013-b1a2-605017395602-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:deceasedTime"
                 priority="1135"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-56961dd4-8f98-42d8-9323-695e75aaf12e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:multipleBirthInd"
                 priority="1134"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='BL' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "BL" bevatten (@nullFlavor or @xsi:type='BL' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-00842052-9b3f-4341-956d-c9287b875851-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:multipleBirthOrderNumber"
                 priority="1133"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @value &gt;= 0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT.NONNEG: null or value &gt;= 0 (@nullFlavor or @value &gt;= 0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f4c7c7bc-2bc1-4c74-9b0a-99379ff9192f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:addr"
                 priority="1132"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode is mandatory [min 1x]. (count(hl7:postalCode)&gt;=1 and not(hl7:postalCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode komt te vaak voor [max 1x]. (count(hl7:postalCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-911dee99-a19b-49f1-b941-3c7a64fa96ae-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:asOtherIDs"
                 priority="1131"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='IDENT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'IDENT' zijn. (@classCode='IDENT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is mandatory [min 1x]. (count(hl7:id)&gt;=1 and not(hl7:id/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-57c57da0-4db0-4af5-be98-27ba6d1299af-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:subject/hl7:personalRelationship/hl7:relationshipHolder/hl7:asOtherIDs/hl7:id"
                 priority="1130"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6b27e672-3323-4fc6-9be4-2abdbba3c0f2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:performer"
                 priority="1129"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:responsibleParty is mandatory [min 1x]. (count(hl7:responsibleParty)&gt;=1 and not(hl7:responsibleParty/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:responsibleParty)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:responsibleParty komt te vaak voor [max 1x]. (count(hl7:responsibleParty)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-53a900cf-cfe2-4400-88f6-e11eed506aeb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:performer/hl7:responsibleParty"
                 priority="1128"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:agentPerson is required [min 1x]. (count(hl7:agentPerson)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:agentPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:agentPerson komt te vaak voor [max 1x]. (count(hl7:agentPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-100ef26c-1b82-49d5-8ea5-83cdcad50efe-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:performer/hl7:responsibleParty/hl7:code"
                 priority="1127"
                 mode="M43">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-RolZorgverlener-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-RolZorgverlener-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set RolZorgverlener DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-174edc65-9455-4a12-8382-1811ae364c1d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:responsibleParty"
                 priority="1126"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='RESP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'RESP' zijn. (@typeCode='RESP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity)&gt;=1 and not(hl7:assignedEntity/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity is mandatory [min 1x]. (count(hl7:assignedEntity)&gt;=1 and not(hl7:assignedEntity/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity komt te vaak voor [max 1x]. (count(hl7:assignedEntity)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e55ec15f-6c91-438b-a534-e95e5ac398e6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:responsibleParty/hl7:assignedEntity"
                 priority="1125"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-65051b6b-e1a3-4f12-b99b-10f6f9484dc4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:responsibleParty/hl7:assignedEntity/hl7:code"
                 priority="1124"
                 mode="M43">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-Eindverantwoordelijke-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-Eindverantwoordelijke-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set Eindverantwoordelijke DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d400b13d-5a1b-428a-bb76-2b1fdd1a7cfb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location"
                 priority="1123"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='ELOC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'ELOC' zijn. (@typeCode='ELOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:healthCareFacility)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:healthCareFacility is required [min 1x]. (count(hl7:healthCareFacility)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:healthCareFacility)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:healthCareFacility komt te vaak voor [max 1x]. (count(hl7:healthCareFacility)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a34adbbc-d7e1-4ec7-bde0-2d1a692ed68c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location/hl7:healthCareFacility"
                 priority="1122"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DSDLOC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'DSDLOC' zijn. (@classCode='DSDLOC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-58edce09-ef2e-40e4-8a77-fb96baedd883-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:location/hl7:healthCareFacility/hl7:code"
                 priority="1121"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-WerkelijkePlaatsBaring-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-WerkelijkePlaatsBaring-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set WerkelijkePlaatsBaring DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a600c6de-6c36-4465-aa33-681fce62ffad-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1120"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eed37fe5-7b24-4ed7-a9b4-d9e08d2af9b4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1119"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-80b2f790-cd73-4c50-934e-952c154e4f1d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1118"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-40be8ed0-a2f1-4e10-acc4-922694ddb584-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1117"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '46098-0' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-31a47567-46e6-4265-a52d-dc437ea6a5e7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='46098-0' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1116"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-GenderMedisch-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-GenderMedisch-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set GenderMedisch DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-394062db-6665-40f1-b8c0-561da5ee13e0-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1115"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-07be3cfa-455b-44a2-b6a3-85cbe228a4ee-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1114"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-63fa237e-6289-46c1-ba9a-bd40d56832d2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1113"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-96f56ef5-1251-47f4-9e3c-4a4446bc52fb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1112"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'BirthOrderNumber' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a75d1e01-a216-45c9-97cc-31035bdb3b75-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='BirthOrderNumber' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1111"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=9))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [1..9] liggen   ((@nullFlavor or (number($theValue)&gt;=1 and number($theValue)&lt;=9)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b7955941-1892-4095-a8f0-0b32776763f6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1110"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3807cc69-b459-4771-8d3d-0327a6c1aaa9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1109"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eeb334c0-8844-49ed-8024-7873ab136b7b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1108"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9118dc06-0069-4b59-9b68-60391437393f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1107"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '11951-1' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9ff3580b-4797-4cde-a9a6-af4c64928bca-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='11951-1' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1106"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-FoetusVolgletter-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-FoetusVolgletter-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set FoetusVolgletter DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-15766cfc-4f36-4e79-be15-3bcbf5e32cca-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1105"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8475ad7d-6ac6-48fa-a6c2-fd496fb9701a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1104"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-09227af6-3574-4089-9942-57dac8197af5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1103"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-273e4412-bc15-4039-815c-d39e0f9aaef2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1102"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN530401' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-19084322-7534-4f94-8606-a18ae3586e8b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN530401' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1101"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or matches(@value, '^[0-9]{8,8}')"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS.DATE.MIN: null or date precision of time stamp shall be at least YYYYMMDD. (@nullFlavor or matches(@value, '^[0-9]{8,8}') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0f09b52c-f0f8-4c81-bc6b-ef65d3b9a6d1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1100"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-499646ae-da92-4ec1-99a5-f1da71d672f3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1099"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6fc8af6e-b8ad-4cc2-95cc-145fc8590e95-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1098"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-59ba4a80-3051-4187-85cc-22da99fb01f6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1097"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN5704' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9ead5748-c12d-4d81-b384-a5055b377320-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN5704' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1096"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ConditiePerineum-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ConditiePerineum-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ConditiePerineum DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c4a5dde3-673c-45e6-86cc-318bf4696fca-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1095"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2d5cec62-2463-46c9-bf5b-33238c1e978c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]"
                 priority="1094"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-cd31b64b-26d0-4048-a754-24c65f992c45-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure"
                 priority="1093"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PROC' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PROC' zijn. (@classCode='PROC' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-010b4e49-5d75-4148-b10e-9cef2dc5a383-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:id"
                 priority="1092"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-818b1412-c5d6-4432-9157-314449a376d7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:code"
                 priority="1091"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN540701' codeSystem '2.16.840.1.113883.2.4.3.22.1.3' zijn. (@nullFlavor or (@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2813f10d-eb1b-4502-b2f1-646bbb81c64e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='PRN540701' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetSiteCode"
                 priority="1090"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-EpisiotomieType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-EpisiotomieType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set EpisiotomieType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3e8ffc1c-24de-47aa-96e9-5f93139b5609-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1089"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3ba460d0-2321-460d-a868-600927e71ad5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1088"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f1b3847c-6602-45ca-9210-ff0450918ee3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1087"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:effectiveTime)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:effectiveTime komt te vaak voor [max 1x]. (count(hl7:effectiveTime)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4c7ccd1b-448c-4256-9983-b1eed6d3320f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1086"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'Outcome' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4408a5da-2166-4c58-8687-a9c9ef527465-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:effectiveTime"
                 priority="1085"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e62f4fd4-aced-41e0-ad52-7d6bf8360e47-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='Outcome' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1084"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-TypeUitkomst-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-TypeUitkomst-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set TypeUitkomst DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9641212f-f17c-4985-ac3a-d1f1fc5df58b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1083"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5b129cb4-b848-456e-9351-99725868e78e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1082"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-42391940-bb73-46fd-ac10-a8971f817fc1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1081"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-54f9eb31-8032-42bd-a3e8-242b9d78af1b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1080"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '8339-4' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-81126d36-84be-42bb-ada9-fc86baf3e36e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='8339-4' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1079"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PQ' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PQ" bevatten (@nullFlavor or @xsi:type='PQ' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-PQ: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(hl7:translation))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-PQ: no translation if null (not(@nullFlavor) or (@nullFlavor and not(hl7:translation)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches($theValue, '^[-+]?[0-9]*$'))))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET eenheid 'g' gebruiken en in bereik [0..] liggen  en tot op minst 0 decimalen nauwkeurig zijn  ((@nullFlavor or (@unit='g' and number($theValue)&gt;=0 and (matches($theValue, '^[-+]?[0-9]*$')))) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok"
                    select="matches($theValue, '^[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid PQ number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theUnit" select="@unit"/>
      <xsl:variable name="UCUMtest"
                    select="document('include/voc-ucum.xml')/*/ucum[@unit=$theUnit]/@message"/>

		    <!--ASSERT warning-->
<xsl:choose>
         <xsl:when test="$UCUMtest='OK' or string-length($UCUMtest)=0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value/@unit (PQ) SHALL be a valid UCUM unit (<xsl:text/>
               <xsl:value-of select="$UCUMtest"/>
               <xsl:text/>). ($UCUMtest='OK' or string-length($UCUMtest)=0 / warning)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0915b266-d879-4625-8391-de3ee6c93481-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1078"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8989f924-a72d-4e45-8d33-b11f9ccd352d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1077"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0ad07b1d-9580-4a27-b73f-95d840b2b659-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1076"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-1afa1987-2d05-4388-a595-134830226ff1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1075"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '9272-6' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-295c0b27-20a0-41cd-b387-e3313906e620-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9272-6' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1074"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [0..10] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8ab03c9a-bb1b-4943-8e89-83bf7032e6a7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1073"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a7448d2e-112a-42ff-b36b-f124ab95f65d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1072"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7fe7a8be-ee5a-477b-a0d4-03b06fc8ef12-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation"
                 priority="1071"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5374fbbe-b1cd-44b2-b7af-fa021b257709-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:code"
                 priority="1070"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '9274-2' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6f7f2cbe-bd3f-4b04-885c-b0649ed0e995-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='9274-2' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:observation/hl7:value"
                 priority="1069"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='INT' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "INT" bevatten (@nullFlavor or @xsi:type='INT' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-INT: no uncertainty (not(hl7:uncertainty) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-INT: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10))"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: value MOET in bereik [0..10] liggen   ((@nullFlavor or (number($theValue)&gt;=0 and number($theValue)&lt;=10)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="digitok" select="matches($theValue, '^-?[1-9][0-9]*$|^+?[0-9]*$')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$digitok"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @value is not a valid INT number <xsl:text/>
               <xsl:value-of select="$theValue"/>
               <xsl:text/>
       ($digitok / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0e0e468c-305d-4b55-86cf-b453a20ddaf2-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1068"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7f8cbe1e-34a7-42d1-88ed-17264f3ac4f9-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1067"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7c906ee4-8754-4def-89c0-cf3a91a50141-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1066"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c98dabd9-2a8d-4c76-9fe0-fd995ecd61b6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1065"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'CongMalf' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e9767b4a-4d4a-41c5-ae48-29fc30105402-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:uncertaintyCode"
                 priority="1064"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-UncertaintyCode-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-UncertaintyCode-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set UncertaintyCode DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-73618759-4d76-46b1-b894-833a281a0e5f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='CongMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1063"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-CongenitaleAfwijkingen-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-CongenitaleAfwijkingen-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set CongenitaleAfwijkingen DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-363bbb10-c9e7-48be-9f01-2eda963c0890-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1062"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4f326054-a498-459f-b774-5c479ed7db99-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1061"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-55476310-dc0a-4db8-a76f-9a8e175f2a18-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1060"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:uncertaintyCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:uncertaintyCode komt te vaak voor [max 1x]. (count(hl7:uncertaintyCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-eb1883c0-4f0e-449c-bf78-60890361f7c7-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1059"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'ChromMalf' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ea2be9af-1bc3-4595-8950-e549ea026c9a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:uncertaintyCode"
                 priority="1058"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-UncertaintyCode-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-UncertaintyCode-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set UncertaintyCode DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e8aa985a-e03d-4bae-b0c0-8b83d9b1e713-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ChromMalf' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1057"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ChromosomaleAfwijkingen-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ChromosomaleAfwijkingen-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ChromosomaleAfwijkingen DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9df641ee-5bee-46f6-a662-f2aea2835a02-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1056"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-03cc85b7-5b6d-428e-9682-6eea277e585d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1055"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-09bfc2f6-dee5-4a49-a4bb-041c8d3f73c3-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1054"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4f4ea0d8-1db4-4009-91ea-f551dac5f1eb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1053"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'LigGbrt' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b22bd615-8fd0-4ae2-895e-577478555b35-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='LigGbrt' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1052"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-LiggingBijGeboorte-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-LiggingBijGeboorte-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set LiggingBijGeboorte DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b79db7cd-f2ec-4523-b83b-4ad13d42101e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1051"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b3b28091-6280-4324-8de8-e72e5acb9bef-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]"
                 priority="1050"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b53a6723-0fc6-41a7-8264-f680c9eb86ba-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation"
                 priority="1049"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is required [min 1x]. (count(hl7:value)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:performer)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:performer komt te vaak voor [max 1x]. (count(hl7:performer)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f088dfeb-98ec-4e90-bf5a-8df85f6b0035-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:code"
                 priority="1048"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'ZorgverlBetr' codeSystem '2.16.840.1.113883.2.4.4.13' zijn. (@nullFlavor or (@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-023935eb-efa2-4420-82b8-3401d2bf4e34-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:value"
                 priority="1047"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-AndereZorgverlenerBetrokken-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-AndereZorgverlenerBetrokken-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set AndereZorgverlenerBetrokken DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f4d742f1-8eb2-4157-a077-537c9916fbcd-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:performer"
                 priority="1046"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='SPRF' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'SPRF' zijn. (@typeCode='SPRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 is mandatory [min 1x]. (count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 komt te vaak voor [max 1x]. (count(hl7:assignedEntity1)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-700eef46-bc4b-4c9f-bc39-6897b9ffa75d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:performer/hl7:time"
                 priority="1045"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:low is required [min 1x]. (count(hl7:low)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:low)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:low komt te vaak voor [max 1x]. (count(hl7:low)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:high)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:high komt te vaak voor [max 1x]. (count(hl7:high)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-abada845-23a5-4b8d-80bd-d03882b3ea01-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:performer/hl7:time/hl7:low"
                 priority="1044"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5af924f9-addc-472f-8b57-83ad15810a7c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:performer/hl7:time/hl7:high"
                 priority="1043"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c5533495-529b-45c4-b0f2-a21f1d9fd7ad-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='ZorgverlBetr' and @codeSystem='2.16.840.1.113883.2.4.4.13']]]/hl7:observation/hl7:performer/hl7:assignedEntity1/hl7:code"
                 priority="1042"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='01.019' and @codeSystem='2.16.840.1.113883.2.4.15.111')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '01.019' codeSystem '2.16.840.1.113883.2.4.15.111' zijn. (@nullFlavor or (@code='01.019' and @codeSystem='2.16.840.1.113883.2.4.15.111') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-f61386d3-06f6-459a-956d-4a614e065374-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1041"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-4c7f2783-0f2e-484f-bec1-2b4f2457ee94-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]"
                 priority="1040"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-41011765-b322-4ff6-9bf4-c9962e6ba020-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation"
                 priority="1039"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='OBS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'OBS' zijn. (@classCode='OBS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value is mandatory [min 1x]. (count(hl7:value)&gt;=1 and not(hl7:value/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:value)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:value komt te vaak voor [max 1x]. (count(hl7:value)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-aff67dc5-c569-44be-84fc-9b5570b6136b-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:code"
                 priority="1038"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'PRN810201' codeSystem '2.16.840.1.113883.2.4.3.22.1.1' zijn. (@nullFlavor or (@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-37de3b1c-6e10-4cb6-8227-6c9ef1dc87ea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:observation[hl7:code[@code='PRN810201' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.1']]]/hl7:observation/hl7:value"
                 priority="1037"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-FasePerinatSterfte-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-FasePerinatSterfte-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set FasePerinatSterfte DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-440f0e3b-f13f-49d6-94d1-dc1167cd5e5d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1036"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-b51a3269-829b-4f48-b92e-38793a04522c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1035"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-815dbb75-682c-4aed-8bb3-bd80a39b5f72-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure"
                 priority="1034"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='SPECCOLLECT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'SPECCOLLECT' zijn. (@classCode='SPECCOLLECT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:approachSiteCode)&gt;=1 and not(hl7:approachSiteCode/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:approachSiteCode is mandatory [min 1x]. (count(hl7:approachSiteCode)&gt;=1 and not(hl7:approachSiteCode/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:approachSiteCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:approachSiteCode komt te vaak voor [max 1x]. (count(hl7:approachSiteCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]])&gt;=1 and not(hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]] is mandatory [min 1x]. (count(hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]])&gt;=1 and not(hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]] komt te vaak voor [max 1x]. (count(hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]])&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-7348fe14-c786-4b2e-a8b2-cab494f610dc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:code"
                 priority="1033"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='82078001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '82078001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='82078001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-d54dbc78-c5cd-44e2-af7e-861d763f7247-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:effectiveTime"
                 priority="1032"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='TS' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "TS" bevatten (@nullFlavor or @xsi:type='TS' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-QTY: no uncertainty (not(hl7:uncertainty/@expression) and not(hl7:uncertainty/@uncertainty) and not(hl7:uncertainty/@originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-QTY: no history or updateMode (count(*[self::hl7:originalText or self::hl7:uncertainty or self::hl7:expression][@validTimeLow or @validTimeHigh or @updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or @value) and not(@nullFlavor and @value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-TS: null or value ((@nullFlavor or @value) and not(@nullFlavor and @value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-429718ae-f62b-4dfb-9fa4-fab06d6b48cc-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:approachSiteCode"
                 priority="1031"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='408728001' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '408728001' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='408728001' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-94db38cd-2835-4235-87d7-e817de27791a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer"
                 priority="1030"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 is mandatory [min 1x]. (count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 komt te vaak voor [max 1x]. (count(hl7:assignedEntity1)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-2c74c549-41ee-4afd-a158-9ad590ec9411-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1"
                 priority="1029"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is required [min 1x]. (count(hl7:code)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedPerson)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedPerson is required [min 1x]. (count(hl7:assignedPerson)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedPerson)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedPerson komt te vaak voor [max 1x]. (count(hl7:assignedPerson)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Organization)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Organization is required [min 1x]. (count(hl7:Organization)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Organization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Organization komt te vaak voor [max 1x]. (count(hl7:Organization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-627ad59b-e678-4b78-8a1a-bddc42761c6f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:id"
                 priority="1028"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-6d3674d8-7abd-4429-b65a-cbf7e77fb2e5-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:code"
                 priority="1027"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgverlenerType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ZorgverlenerType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9b2acc4b-fbd5-4a32-a90e-a407592d6c17-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:assignedPerson"
                 priority="1026"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='PSN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'PSN' zijn. (@classCode='PSN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-65dbc9f3-3bc5-4e3b-aabb-961e92bba579-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:assignedPerson/hl7:name"
                 priority="1025"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='PN' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "PN" bevatten (@nullFlavor or @xsi:type='PN' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-e9d49616-5164-4a15-8862-e809ca1ba754-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:Organization"
                 priority="1024"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr is required [min 1x]. (count(hl7:addr)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5160bdb4-9bab-4b09-bd92-2dcee0881a1e-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:Organization/hl7:id"
                 priority="1023"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='II' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "II" bevatten (@nullFlavor or @xsi:type='II' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (not(@nullFlavor) and @root)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-II: @root is required if not null (@nullFlavor or (not(@nullFlavor) and @root) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@root))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-II: no @root if null (not(@nullFlavor) or (@nullFlavor and not(@root)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-II: no @identifierName if null (not(@nullFlavor) or (@nullFlavor and not(@identifierName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayable))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-II: no @displayable if null (not(@nullFlavor) or (@nullFlavor and not(@displayable)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@reliability))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-II: no @reliability if null (not(@nullFlavor) or (@nullFlavor and not(@reliability)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-II: no @assigningAuthorityName if null (not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@root) &lt;= 128)">
         <xsl:message>dtr1-8-II: @root is longer than 128 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@root) &lt;= 128) / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(string-length(@extension) &lt;= 64)">
         <xsl:message>dtr1-9-II: @extension s longer than 64 characters. Please write a note to the authors of this rule if this is found to be not
        sufficient (not(string-length(@extension) &lt;= 64) / warning)</xsl:message>
      </xsl:if>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-a5950e4c-68a3-4ddf-bfd3-9687753c53b1-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:Organization/hl7:code"
                 priority="1022"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-ZorgaanbiederType-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set ZorgaanbiederType DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c9fcd3da-ce7e-4e83-8e15-6a8dec903554-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:Organization/hl7:name"
                 priority="1021"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='ON' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "ON" bevatten (@nullFlavor or @xsi:type='ON' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(@nullFlavor or * or text()) and not(@nullFlavor and (* or text()))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-EN: either null or content ((@nullFlavor or * or text()) and not(@nullFlavor and (* or text())) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-EN:
        name must consist of elements or just a string name (no mixed content) ((count(*)&gt;0 and not(text()[string-length(normalize-space(.))&gt;0])) or (count(*)=0 and string-length(normalize-space(text()[1]))&gt;0) or @nullFlavor / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="*[normalize-space(.)='']">
         <xsl:message>dtr1-3-EN: empty name particles should not be present. (*[normalize-space(.)=''] / warning)</xsl:message>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="substring(normalize-space(.),1,1)='&#34;'">
         <xsl:message>dtr1-4-EN: Use of quotes at the beginning of a name are probably not correct. (substring(normalize-space(.),1,1)='"' / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:family)=0 and count(hl7:given)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ON: no parts may be person name type particles (count(hl7:family)=0 and count(hl7:given)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(*)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-ON: organization names SHALL be element content (not(*) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ba1b003d-b43d-408a-abe5-41627ab2fe27-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:performer/hl7:assignedEntity1/hl7:Organization/hl7:addr"
                 priority="1020"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='AD' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "AD" bevatten (@nullFlavor or @xsi:type='AD' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-AD: address shall be text only or element only (no mixed content) ((count(*)&gt;0 and string-length(normalize-space(text()[1]))=0) or count(*)=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-AD: no useablePeriod if null (not(@nullFlavor) or (not(hl7:thumbnail) or hl7:useablePeriod/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(*[self::hl7:useablePeriod][@updateMode])=0"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-AD: updateMode shall not be used on address elements (count(*[self::hl7:useablePeriod][@updateMode])=0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) )"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-AD: null or content (( @nullFlavor and empty(text()) ) or ( not(@nullFlavor) and not(empty(text())) ) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or          string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-AD: useablePeriod/low/@value must have the same precision as useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or string-length(hl7:useablePeriod/hl7:low/@value) = string-length(hl7:useablePeriod/hl7:high/@value) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or         number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-AD: useablePeriod/low/@value must be before useablePeriod/high/@value (not(hl7:useablePeriod/hl7:low/@value and hl7:useablePeriod/hl7:high/@value) or number(substring(concat(hl7:useablePeriod/hl7:low/@value,'00000000000000'),1,14)) &lt; number(substring(concat(hl7:useablePeriod/hl7:high/@value,'00000000000000'),1,14)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="tum" select="'^(us|ms|s|min|h|d|wk|mo|a|)$'"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="matches(hl7:useablePeriod/hl7:width/@unit, $tum)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-AD: for useablePeriod/width only us (microseconds), ms (milliseconds), s (seconds), min (minute), h (hours), d (day), wk (week),
        mo (month) or a (year) are allowed (matches(hl7:useablePeriod/hl7:width/@unit, $tum) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:houseNumber)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:houseNumber is required [min 1x]. (count(hl7:houseNumber)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:houseNumber)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:houseNumber komt te vaak voor [max 1x]. (count(hl7:houseNumber)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode is required [min 1x]. (count(hl7:postalCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode komt te vaak voor [max 1x]. (count(hl7:postalCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-ee45f825-031d-4d69-8687-5cca79da727f-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1019"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='ELNK' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'ELNK' zijn. (@typeCode='ELNK' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-82859959-3fa6-4658-955b-72e965ce590c-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]"
                 priority="1018"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&gt;=1 and not(hl7:act/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:act is mandatory [min 1x]. (count(hl7:act)&gt;=1 and not(hl7:act/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:act)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:act komt te vaak voor [max 1x]. (count(hl7:act)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='ELNK' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'ELNK' zijn. (@typeCode='ELNK' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-679f5a8e-777c-45f0-bdb7-f0902beeb939-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act"
                 priority="1016"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACT' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ACT' zijn. (@classCode='ACT' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='RQO' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'RQO' zijn. (@moodCode='RQO' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:statusCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:statusCode komt te vaak voor [max 1x]. (count(hl7:statusCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c630d09e-3897-4699-9537-3fae4982a171-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:code"
                 priority="1015"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'X-LAB-ORDER' codeSystem '2.16.840.1.113883.6.1' zijn. (@nullFlavor or (@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9452d4cc-4349-494e-b63a-38515d2786d6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:statusCode"
                 priority="1014"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='active')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET 'active' zijn. (@nullFlavor or (@code='active') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-18059718-81b6-4085-97d4-4c6ce5809f5a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:performer"
                 priority="1013"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRF' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PRF' zijn. (@typeCode='PRF' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 is mandatory [min 1x]. (count(hl7:assignedEntity1)&gt;=1 and not(hl7:assignedEntity1/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:assignedEntity1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:assignedEntity1 komt te vaak voor [max 1x]. (count(hl7:assignedEntity1)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-5519f47f-8e91-4054-9d3a-412773256813-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:performer/hl7:assignedEntity1"
                 priority="1012"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ASSIGNED' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ASSIGNED' zijn. (@classCode='ASSIGNED' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Organization)&gt;=1 and not(hl7:Organization/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Organization is mandatory [min 1x]. (count(hl7:Organization)&gt;=1 and not(hl7:Organization/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:Organization)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:Organization komt te vaak voor [max 1x]. (count(hl7:Organization)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-9a54a61d-5e79-4fa4-9d2b-77f0233026df-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:performer/hl7:assignedEntity1/hl7:Organization"
                 priority="1011"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ORG' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ORG' zijn. (@classCode='ORG' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='INSTANCE' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'INSTANCE' STATIC  (@determinerCode='INSTANCE' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id is required [min 1x]. (count(hl7:id)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name is required [min 1x]. (count(hl7:name)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:name)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:name komt te vaak voor [max 1x]. (count(hl7:name)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr is required [min 1x]. (count(hl7:addr)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:addr)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:addr komt te vaak voor [max 1x]. (count(hl7:addr)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8aa23091-0063-4ae0-8f95-bbe0b8e1c90a-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:performer/hl7:assignedEntity1/hl7:Organization/hl7:code"
                 priority="1010"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='L1' and @codeSystem='2.16.840.1.113883.2.4.15.1060')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET 'L1' codeSystem '2.16.840.1.113883.2.4.15.1060' zijn. (@nullFlavor or (@code='L1' and @codeSystem='2.16.840.1.113883.2.4.15.1060') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-82413bb2-e7b3-4981-85bb-eb02ed29d966-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:procedure[hl7:code[@code='82078001' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:procedure/hl7:targetOf[hl7:act[hl7:code[@code='X-LAB-ORDER' and @codeSystem='2.16.840.1.113883.6.1']]]/hl7:act/hl7:performer/hl7:assignedEntity1/hl7:Organization/hl7:addr"
                 priority="1009"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:houseNumber)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:houseNumber is required [min 1x]. (count(hl7:houseNumber)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:houseNumber)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:houseNumber komt te vaak voor [max 1x]. (count(hl7:houseNumber)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode is required [min 1x]. (count(hl7:postalCode)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:postalCode)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:postalCode komt te vaak voor [max 1x]. (count(hl7:postalCode)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-c5b2cb40-6d2d-42c4-a46a-662442d33705-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1008"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-67d6d17e-aede-4670-b4b5-75b9cd4008ea-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]"
                 priority="1007"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:supply)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:supply is required [min 1x]. (count(hl7:supply)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:supply)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:supply komt te vaak voor [max 1x]. (count(hl7:supply)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='COMP' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'COMP' zijn. (@typeCode='COMP' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-8b168565-a9cb-46a4-8c23-1abdcce74c08-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:supply"
                 priority="1005"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='DIET' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'DIET' zijn. (@classCode='DIET' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@moodCode='EVN' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @moodCode MOET 'EVN' zijn. (@moodCode='EVN' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:id)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:id komt te vaak voor [max 1x]. (count(hl7:id)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:product)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:product is required [min 1x]. (count(hl7:product)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:product)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:product komt te vaak voor [max 1x]. (count(hl7:product)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-3612bc27-4919-426e-b149-b396b32ebced-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:supply/hl7:code"
                 priority="1004"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or (@code='230126006' and @codeSystem='2.16.840.1.113883.6.96')"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code/@codeSystem MOET '230126006' codeSystem '2.16.840.1.113883.6.96' zijn. (@nullFlavor or (@code='230126006' and @codeSystem='2.16.840.1.113883.6.96') / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-69cc8754-2d4f-4e29-8de3-a3465dfb8fdb-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:supply/hl7:product"
                 priority="1003"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@typeCode='PRD' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @typeCode MOET 'PRD' zijn. (@typeCode='PRD' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:product1)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:product1 is required [min 1x]. (count(hl7:product1)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:product1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:product1 komt te vaak voor [max 1x]. (count(hl7:product1)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-60b0c48d-6f32-469f-a483-6ac64679d2a6-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:supply/hl7:product/hl7:product1"
                 priority="1002"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='ACCESS' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'ACCESS' zijn. (@classCode='ACCESS' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:playingMaterial)&gt;=1 "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:playingMaterial is required [min 1x]. (count(hl7:playingMaterial)&gt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:playingMaterial)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:playingMaterial komt te vaak voor [max 1x]. (count(hl7:playingMaterial)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-195c10b8-b8d0-4eb7-9b77-fc9a1737145d-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:supply/hl7:product/hl7:product1/hl7:playingMaterial"
                 priority="1001"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@classCode='FOOD' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @classCode MOET 'FOOD' zijn. (@classCode='FOOD' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@determinerCode='KIND' "/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: @determinerCode SHALL have value 'KIND' STATIC  (@determinerCode='KIND' / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code is mandatory [min 1x]. (count(hl7:code)&gt;=1 and not(hl7:code/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(hl7:code)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: element hl7:code komt te vaak voor [max 1x]. (count(hl7:code)&lt;=1 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>

	  <!--RULE tmp-0f291fca-daf2-4476-9def-fb7bf580d9e4-->
<xsl:template match="*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.90.51']/hl7:pertinentInformation3[hl7:procedure[hl7:code[@code='Baring' and @codeSystem='2.16.840.1.113883.2.4.3.22.1.3']]]/hl7:procedure/hl7:targetOf[hl7:supply[hl7:code[@code='230126006' and @codeSystem='2.16.840.1.113883.6.96']]]/hl7:supply/hl7:product/hl7:product1/hl7:playingMaterial/hl7:code"
                 priority="1000"
                 mode="M43">

		<!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @xsi:type='CE' or not(@xsi:type)"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: Indien er een @xsi:type instructie aanwezig is MOET deze de waarde "CE" bevatten (@nullFlavor or @xsi:type='CE' or not(@xsi:type) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(descendant-or-self::hl7:*[@nullFlavor]) or         descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or         (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or         (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)]"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-ANY: if there is a nullFlavor, there shall be no other attribute or element, unless it's nullFlavor='OTH' (@codeSystem or &lt;originalText&gt; may have a value), or nullFlavor 'UNC'
        (@extension may have a value) (not(descendant-or-self::hl7:*[@nullFlavor]) or descendant-or-self::hl7:*[(@nullFlavor and count(@* except (@xsi:type|@xsi:nil|@classCode|@typeCode|@determinerCode|@moodCode))=1 and count(node())=0) or (@nullFlavor='OTH' and (@codeSystem or hl7:originalText) and count(@* except (@xsi:type|@xsi:nil|@codeSystem))=1) or (@nullFlavor='UNC' and (@extension) and count(@* except (@xsi:type|@extension))=1)] / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CD: null or code and/or originalText (@nullFlavor or @code or (hl7:originalText and not(hl7:originalText/@nullFlavor)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-2-CD: code requires codeSystem (@codeSystem or not(@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-3-CD: codeSystemName only if codeSystem (@codeSystem or not(@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@codeSystem or not(@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-4-CD: codeSystemVersion only if codeSystem (@codeSystem or not(@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@code or not(@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-5-CD: displayName only if code (@code or not(@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@code))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-6-CD: no code if null (not(@nullFlavor) or (@nullFlavor and not(@code)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(@nullFlavor) or (@nullFlavor and not(@displayName))"/>
         <xsl:otherwise>
            <xsl:message>dtr1-7-CD: no displayName if null (not(@nullFlavor) or (@nullFlavor and not(@displayName)) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="code" select="@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:originalText)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-8-CD: no originalText on translations (not(hl7:translation/hl7:originalText) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/hl7:translation)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-9-CD: no translation on translations (not(hl7:translation/hl7:translation) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:translation/@nullFlavor)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-10-CD: no null on translations (not(hl7:translation/@nullFlavor) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@code)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-11-CD: translation code requires codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@code) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-12-CD: translation codeSystemName only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-13-CD: translation codeSystemVersion only if codeSystem (hl7:translation/@codeSystem or not(hl7:translation/@codeSystemVersion) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="hl7:translation/@code or not(hl7:translation/@displayName)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-14-CD: translation displayName only if code (hl7:translation/@code or not(hl7:translation/@displayName) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="matches(@displayName,'[\r\n\t]')">
         <xsl:message>dtr1-15-CD: it looks like there are formatting instructions in attribute @displayName. Please note that this may lead to
        interoperability problems. (matches(@displayName,'[\r\n\t]') / warning)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(hl7:qualifier)"/>
         <xsl:otherwise>
            <xsl:message>dtr1-1-CE: cannot have qualifier (not(hl7:qualifier) / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theValue" select="@value"/>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="displayNamesFound"
                    select="concat((document('include/voc-BabyVoedingSoort-DYNAMIC.xml')/*/valueSet/conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]/@displayName[1]), '')"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="concat((document('include/voc-BabyVoedingSoort-DYNAMIC.xml')/*/valueSet/conceptList/exception[@codeSystem = '2.16.840.1.113883.5.1008'][@code = $theNullFlavor]/@displayName[1]), '')"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0"/>
         <xsl:otherwise>
            <xsl:message>uitkomst-1c-1el: De waarde van @code MOET worden gekozen uit Value Set BabyVoedingSoort DYNAMIC. (@nullFlavor or string-length($displayNamesFound)&gt;0 or string-length($validNullFlavorsFound)&gt;0 / error)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*" mode="M43"/>
   </xsl:template>
</xsl:stylesheet>